/* Generated by Cython 0.25.2 */

#define PY_SSIZE_T_CLEAN
#include "Python.h"
#ifndef Py_PYTHON_H
    #error Python headers needed to compile C extensions, please install development version of Python.
#elif PY_VERSION_HEX < 0x02060000 || (0x03000000 <= PY_VERSION_HEX && PY_VERSION_HEX < 0x03020000)
    #error Cython requires Python 2.6+ or Python 3.2+.
#else
#define CYTHON_ABI "0_25_2"
#include <stddef.h>
#ifndef offsetof
  #define offsetof(type, member) ( (size_t) & ((type*)0) -> member )
#endif
#if !defined(WIN32) && !defined(MS_WINDOWS)
  #ifndef __stdcall
    #define __stdcall
  #endif
  #ifndef __cdecl
    #define __cdecl
  #endif
  #ifndef __fastcall
    #define __fastcall
  #endif
#endif
#ifndef DL_IMPORT
  #define DL_IMPORT(t) t
#endif
#ifndef DL_EXPORT
  #define DL_EXPORT(t) t
#endif
#ifndef HAVE_LONG_LONG
  #if PY_VERSION_HEX >= 0x03030000 || (PY_MAJOR_VERSION == 2 && PY_VERSION_HEX >= 0x02070000)
    #define HAVE_LONG_LONG
  #endif
#endif
#ifndef PY_LONG_LONG
  #define PY_LONG_LONG LONG_LONG
#endif
#ifndef Py_HUGE_VAL
  #define Py_HUGE_VAL HUGE_VAL
#endif
#ifdef PYPY_VERSION
  #define CYTHON_COMPILING_IN_PYPY 1
  #define CYTHON_COMPILING_IN_PYSTON 0
  #define CYTHON_COMPILING_IN_CPYTHON 0
  #undef CYTHON_USE_TYPE_SLOTS
  #define CYTHON_USE_TYPE_SLOTS 0
  #undef CYTHON_USE_ASYNC_SLOTS
  #define CYTHON_USE_ASYNC_SLOTS 0
  #undef CYTHON_USE_PYLIST_INTERNALS
  #define CYTHON_USE_PYLIST_INTERNALS 0
  #undef CYTHON_USE_UNICODE_INTERNALS
  #define CYTHON_USE_UNICODE_INTERNALS 0
  #undef CYTHON_USE_UNICODE_WRITER
  #define CYTHON_USE_UNICODE_WRITER 0
  #undef CYTHON_USE_PYLONG_INTERNALS
  #define CYTHON_USE_PYLONG_INTERNALS 0
  #undef CYTHON_AVOID_BORROWED_REFS
  #define CYTHON_AVOID_BORROWED_REFS 1
  #undef CYTHON_ASSUME_SAFE_MACROS
  #define CYTHON_ASSUME_SAFE_MACROS 0
  #undef CYTHON_UNPACK_METHODS
  #define CYTHON_UNPACK_METHODS 0
  #undef CYTHON_FAST_THREAD_STATE
  #define CYTHON_FAST_THREAD_STATE 0
  #undef CYTHON_FAST_PYCALL
  #define CYTHON_FAST_PYCALL 0
#elif defined(PYSTON_VERSION)
  #define CYTHON_COMPILING_IN_PYPY 0
  #define CYTHON_COMPILING_IN_PYSTON 1
  #define CYTHON_COMPILING_IN_CPYTHON 0
  #ifndef CYTHON_USE_TYPE_SLOTS
    #define CYTHON_USE_TYPE_SLOTS 1
  #endif
  #undef CYTHON_USE_ASYNC_SLOTS
  #define CYTHON_USE_ASYNC_SLOTS 0
  #undef CYTHON_USE_PYLIST_INTERNALS
  #define CYTHON_USE_PYLIST_INTERNALS 0
  #ifndef CYTHON_USE_UNICODE_INTERNALS
    #define CYTHON_USE_UNICODE_INTERNALS 1
  #endif
  #undef CYTHON_USE_UNICODE_WRITER
  #define CYTHON_USE_UNICODE_WRITER 0
  #undef CYTHON_USE_PYLONG_INTERNALS
  #define CYTHON_USE_PYLONG_INTERNALS 0
  #ifndef CYTHON_AVOID_BORROWED_REFS
    #define CYTHON_AVOID_BORROWED_REFS 0
  #endif
  #ifndef CYTHON_ASSUME_SAFE_MACROS
    #define CYTHON_ASSUME_SAFE_MACROS 1
  #endif
  #ifndef CYTHON_UNPACK_METHODS
    #define CYTHON_UNPACK_METHODS 1
  #endif
  #undef CYTHON_FAST_THREAD_STATE
  #define CYTHON_FAST_THREAD_STATE 0
  #undef CYTHON_FAST_PYCALL
  #define CYTHON_FAST_PYCALL 0
#else
  #define CYTHON_COMPILING_IN_PYPY 0
  #define CYTHON_COMPILING_IN_PYSTON 0
  #define CYTHON_COMPILING_IN_CPYTHON 1
  #ifndef CYTHON_USE_TYPE_SLOTS
    #define CYTHON_USE_TYPE_SLOTS 1
  #endif
  #if PY_MAJOR_VERSION < 3
    #undef CYTHON_USE_ASYNC_SLOTS
    #define CYTHON_USE_ASYNC_SLOTS 0
  #elif !defined(CYTHON_USE_ASYNC_SLOTS)
    #define CYTHON_USE_ASYNC_SLOTS 1
  #endif
  #if PY_VERSION_HEX < 0x02070000
    #undef CYTHON_USE_PYLONG_INTERNALS
    #define CYTHON_USE_PYLONG_INTERNALS 0
  #elif !defined(CYTHON_USE_PYLONG_INTERNALS)
    #define CYTHON_USE_PYLONG_INTERNALS 1
  #endif
  #ifndef CYTHON_USE_PYLIST_INTERNALS
    #define CYTHON_USE_PYLIST_INTERNALS 1
  #endif
  #ifndef CYTHON_USE_UNICODE_INTERNALS
    #define CYTHON_USE_UNICODE_INTERNALS 1
  #endif
  #if PY_VERSION_HEX < 0x030300F0
    #undef CYTHON_USE_UNICODE_WRITER
    #define CYTHON_USE_UNICODE_WRITER 0
  #elif !defined(CYTHON_USE_UNICODE_WRITER)
    #define CYTHON_USE_UNICODE_WRITER 1
  #endif
  #ifndef CYTHON_AVOID_BORROWED_REFS
    #define CYTHON_AVOID_BORROWED_REFS 0
  #endif
  #ifndef CYTHON_ASSUME_SAFE_MACROS
    #define CYTHON_ASSUME_SAFE_MACROS 1
  #endif
  #ifndef CYTHON_UNPACK_METHODS
    #define CYTHON_UNPACK_METHODS 1
  #endif
  #ifndef CYTHON_FAST_THREAD_STATE
    #define CYTHON_FAST_THREAD_STATE 1
  #endif
  #ifndef CYTHON_FAST_PYCALL
    #define CYTHON_FAST_PYCALL 1
  #endif
#endif
#if !defined(CYTHON_FAST_PYCCALL)
#define CYTHON_FAST_PYCCALL  (CYTHON_FAST_PYCALL && PY_VERSION_HEX >= 0x030600B1)
#endif
#if CYTHON_USE_PYLONG_INTERNALS
  #include "longintrepr.h"
  #undef SHIFT
  #undef BASE
  #undef MASK
#endif
#if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX < 0x02070600 && !defined(Py_OptimizeFlag)
  #define Py_OptimizeFlag 0
#endif
#define __PYX_BUILD_PY_SSIZE_T "n"
#define CYTHON_FORMAT_SSIZE_T "z"
#if PY_MAJOR_VERSION < 3
  #define __Pyx_BUILTIN_MODULE_NAME "__builtin__"
  #define __Pyx_PyCode_New(a, k, l, s, f, code, c, n, v, fv, cell, fn, name, fline, lnos)\
          PyCode_New(a+k, l, s, f, code, c, n, v, fv, cell, fn, name, fline, lnos)
  #define __Pyx_DefaultClassType PyClass_Type
#else
  #define __Pyx_BUILTIN_MODULE_NAME "builtins"
  #define __Pyx_PyCode_New(a, k, l, s, f, code, c, n, v, fv, cell, fn, name, fline, lnos)\
          PyCode_New(a, k, l, s, f, code, c, n, v, fv, cell, fn, name, fline, lnos)
  #define __Pyx_DefaultClassType PyType_Type
#endif
#ifndef Py_TPFLAGS_CHECKTYPES
  #define Py_TPFLAGS_CHECKTYPES 0
#endif
#ifndef Py_TPFLAGS_HAVE_INDEX
  #define Py_TPFLAGS_HAVE_INDEX 0
#endif
#ifndef Py_TPFLAGS_HAVE_NEWBUFFER
  #define Py_TPFLAGS_HAVE_NEWBUFFER 0
#endif
#ifndef Py_TPFLAGS_HAVE_FINALIZE
  #define Py_TPFLAGS_HAVE_FINALIZE 0
#endif
#ifndef METH_FASTCALL
  #define METH_FASTCALL 0x80
  typedef PyObject *(*__Pyx_PyCFunctionFast) (PyObject *self, PyObject **args,
                                              Py_ssize_t nargs, PyObject *kwnames);
#else
  #define __Pyx_PyCFunctionFast _PyCFunctionFast
#endif
#if CYTHON_FAST_PYCCALL
#define __Pyx_PyFastCFunction_Check(func)\
    ((PyCFunction_Check(func) && (METH_FASTCALL == (PyCFunction_GET_FLAGS(func) & ~(METH_CLASS | METH_STATIC | METH_COEXIST)))))
#else
#define __Pyx_PyFastCFunction_Check(func) 0
#endif
#if PY_VERSION_HEX > 0x03030000 && defined(PyUnicode_KIND)
  #define CYTHON_PEP393_ENABLED 1
  #define __Pyx_PyUnicode_READY(op)       (likely(PyUnicode_IS_READY(op)) ?\
                                              0 : _PyUnicode_Ready((PyObject *)(op)))
  #define __Pyx_PyUnicode_GET_LENGTH(u)   PyUnicode_GET_LENGTH(u)
  #define __Pyx_PyUnicode_READ_CHAR(u, i) PyUnicode_READ_CHAR(u, i)
  #define __Pyx_PyUnicode_MAX_CHAR_VALUE(u)   PyUnicode_MAX_CHAR_VALUE(u)
  #define __Pyx_PyUnicode_KIND(u)         PyUnicode_KIND(u)
  #define __Pyx_PyUnicode_DATA(u)         PyUnicode_DATA(u)
  #define __Pyx_PyUnicode_READ(k, d, i)   PyUnicode_READ(k, d, i)
  #define __Pyx_PyUnicode_WRITE(k, d, i, ch)  PyUnicode_WRITE(k, d, i, ch)
  #define __Pyx_PyUnicode_IS_TRUE(u)      (0 != (likely(PyUnicode_IS_READY(u)) ? PyUnicode_GET_LENGTH(u) : PyUnicode_GET_SIZE(u)))
#else
  #define CYTHON_PEP393_ENABLED 0
  #define PyUnicode_1BYTE_KIND  1
  #define PyUnicode_2BYTE_KIND  2
  #define PyUnicode_4BYTE_KIND  4
  #define __Pyx_PyUnicode_READY(op)       (0)
  #define __Pyx_PyUnicode_GET_LENGTH(u)   PyUnicode_GET_SIZE(u)
  #define __Pyx_PyUnicode_READ_CHAR(u, i) ((Py_UCS4)(PyUnicode_AS_UNICODE(u)[i]))
  #define __Pyx_PyUnicode_MAX_CHAR_VALUE(u)   ((sizeof(Py_UNICODE) == 2) ? 65535 : 1114111)
  #define __Pyx_PyUnicode_KIND(u)         (sizeof(Py_UNICODE))
  #define __Pyx_PyUnicode_DATA(u)         ((void*)PyUnicode_AS_UNICODE(u))
  #define __Pyx_PyUnicode_READ(k, d, i)   ((void)(k), (Py_UCS4)(((Py_UNICODE*)d)[i]))
  #define __Pyx_PyUnicode_WRITE(k, d, i, ch)  (((void)(k)), ((Py_UNICODE*)d)[i] = ch)
  #define __Pyx_PyUnicode_IS_TRUE(u)      (0 != PyUnicode_GET_SIZE(u))
#endif
#if CYTHON_COMPILING_IN_PYPY
  #define __Pyx_PyUnicode_Concat(a, b)      PyNumber_Add(a, b)
  #define __Pyx_PyUnicode_ConcatSafe(a, b)  PyNumber_Add(a, b)
#else
  #define __Pyx_PyUnicode_Concat(a, b)      PyUnicode_Concat(a, b)
  #define __Pyx_PyUnicode_ConcatSafe(a, b)  ((unlikely((a) == Py_None) || unlikely((b) == Py_None)) ?\
      PyNumber_Add(a, b) : __Pyx_PyUnicode_Concat(a, b))
#endif
#if CYTHON_COMPILING_IN_PYPY && !defined(PyUnicode_Contains)
  #define PyUnicode_Contains(u, s)  PySequence_Contains(u, s)
#endif
#if CYTHON_COMPILING_IN_PYPY && !defined(PyByteArray_Check)
  #define PyByteArray_Check(obj)  PyObject_TypeCheck(obj, &PyByteArray_Type)
#endif
#if CYTHON_COMPILING_IN_PYPY && !defined(PyObject_Format)
  #define PyObject_Format(obj, fmt)  PyObject_CallMethod(obj, "__format__", "O", fmt)
#endif
#if CYTHON_COMPILING_IN_PYPY && !defined(PyObject_Malloc)
  #define PyObject_Malloc(s)   PyMem_Malloc(s)
  #define PyObject_Free(p)     PyMem_Free(p)
  #define PyObject_Realloc(p)  PyMem_Realloc(p)
#endif
#if CYTHON_COMPILING_IN_PYSTON
  #define __Pyx_PyCode_HasFreeVars(co)  PyCode_HasFreeVars(co)
  #define __Pyx_PyFrame_SetLineNumber(frame, lineno) PyFrame_SetLineNumber(frame, lineno)
#else
  #define __Pyx_PyCode_HasFreeVars(co)  (PyCode_GetNumFree(co) > 0)
  #define __Pyx_PyFrame_SetLineNumber(frame, lineno)  (frame)->f_lineno = (lineno)
#endif
#define __Pyx_PyString_FormatSafe(a, b)   ((unlikely((a) == Py_None)) ? PyNumber_Remainder(a, b) : __Pyx_PyString_Format(a, b))
#define __Pyx_PyUnicode_FormatSafe(a, b)  ((unlikely((a) == Py_None)) ? PyNumber_Remainder(a, b) : PyUnicode_Format(a, b))
#if PY_MAJOR_VERSION >= 3
  #define __Pyx_PyString_Format(a, b)  PyUnicode_Format(a, b)
#else
  #define __Pyx_PyString_Format(a, b)  PyString_Format(a, b)
#endif
#if PY_MAJOR_VERSION < 3 && !defined(PyObject_ASCII)
  #define PyObject_ASCII(o)            PyObject_Repr(o)
#endif
#if PY_MAJOR_VERSION >= 3
  #define PyBaseString_Type            PyUnicode_Type
  #define PyStringObject               PyUnicodeObject
  #define PyString_Type                PyUnicode_Type
  #define PyString_Check               PyUnicode_Check
  #define PyString_CheckExact          PyUnicode_CheckExact
#endif
#if PY_MAJOR_VERSION >= 3
  #define __Pyx_PyBaseString_Check(obj) PyUnicode_Check(obj)
  #define __Pyx_PyBaseString_CheckExact(obj) PyUnicode_CheckExact(obj)
#else
  #define __Pyx_PyBaseString_Check(obj) (PyString_Check(obj) || PyUnicode_Check(obj))
  #define __Pyx_PyBaseString_CheckExact(obj) (PyString_CheckExact(obj) || PyUnicode_CheckExact(obj))
#endif
#ifndef PySet_CheckExact
  #define PySet_CheckExact(obj)        (Py_TYPE(obj) == &PySet_Type)
#endif
#define __Pyx_TypeCheck(obj, type) PyObject_TypeCheck(obj, (PyTypeObject *)type)
#define __Pyx_PyException_Check(obj) __Pyx_TypeCheck(obj, PyExc_Exception)
#if PY_MAJOR_VERSION >= 3
  #define PyIntObject                  PyLongObject
  #define PyInt_Type                   PyLong_Type
  #define PyInt_Check(op)              PyLong_Check(op)
  #define PyInt_CheckExact(op)         PyLong_CheckExact(op)
  #define PyInt_FromString             PyLong_FromString
  #define PyInt_FromUnicode            PyLong_FromUnicode
  #define PyInt_FromLong               PyLong_FromLong
  #define PyInt_FromSize_t             PyLong_FromSize_t
  #define PyInt_FromSsize_t            PyLong_FromSsize_t
  #define PyInt_AsLong                 PyLong_AsLong
  #define PyInt_AS_LONG                PyLong_AS_LONG
  #define PyInt_AsSsize_t              PyLong_AsSsize_t
  #define PyInt_AsUnsignedLongMask     PyLong_AsUnsignedLongMask
  #define PyInt_AsUnsignedLongLongMask PyLong_AsUnsignedLongLongMask
  #define PyNumber_Int                 PyNumber_Long
#endif
#if PY_MAJOR_VERSION >= 3
  #define PyBoolObject                 PyLongObject
#endif
#if PY_MAJOR_VERSION >= 3 && CYTHON_COMPILING_IN_PYPY
  #ifndef PyUnicode_InternFromString
    #define PyUnicode_InternFromString(s) PyUnicode_FromString(s)
  #endif
#endif
#if PY_VERSION_HEX < 0x030200A4
  typedef long Py_hash_t;
  #define __Pyx_PyInt_FromHash_t PyInt_FromLong
  #define __Pyx_PyInt_AsHash_t   PyInt_AsLong
#else
  #define __Pyx_PyInt_FromHash_t PyInt_FromSsize_t
  #define __Pyx_PyInt_AsHash_t   PyInt_AsSsize_t
#endif
#if PY_MAJOR_VERSION >= 3
  #define __Pyx_PyMethod_New(func, self, klass) ((self) ? PyMethod_New(func, self) : PyInstanceMethod_New(func))
#else
  #define __Pyx_PyMethod_New(func, self, klass) PyMethod_New(func, self, klass)
#endif
#if CYTHON_USE_ASYNC_SLOTS
  #if PY_VERSION_HEX >= 0x030500B1
    #define __Pyx_PyAsyncMethodsStruct PyAsyncMethods
    #define __Pyx_PyType_AsAsync(obj) (Py_TYPE(obj)->tp_as_async)
  #else
    typedef struct {
        unaryfunc am_await;
        unaryfunc am_aiter;
        unaryfunc am_anext;
    } __Pyx_PyAsyncMethodsStruct;
    #define __Pyx_PyType_AsAsync(obj) ((__Pyx_PyAsyncMethodsStruct*) (Py_TYPE(obj)->tp_reserved))
  #endif
#else
  #define __Pyx_PyType_AsAsync(obj) NULL
#endif
#ifndef CYTHON_RESTRICT
  #if defined(__GNUC__)
    #define CYTHON_RESTRICT __restrict__
  #elif defined(_MSC_VER) && _MSC_VER >= 1400
    #define CYTHON_RESTRICT __restrict
  #elif defined (__STDC_VERSION__) && __STDC_VERSION__ >= 199901L
    #define CYTHON_RESTRICT restrict
  #else
    #define CYTHON_RESTRICT
  #endif
#endif
#ifndef CYTHON_UNUSED
# if defined(__GNUC__)
#   if !(defined(__cplusplus)) || (__GNUC__ > 3 || (__GNUC__ == 3 && __GNUC_MINOR__ >= 4))
#     define CYTHON_UNUSED __attribute__ ((__unused__))
#   else
#     define CYTHON_UNUSED
#   endif
# elif defined(__ICC) || (defined(__INTEL_COMPILER) && !defined(_MSC_VER))
#   define CYTHON_UNUSED __attribute__ ((__unused__))
# else
#   define CYTHON_UNUSED
# endif
#endif
#ifndef CYTHON_MAYBE_UNUSED_VAR
#  if defined(__cplusplus)
     template<class T> void CYTHON_MAYBE_UNUSED_VAR( const T& ) { }
#  else
#    define CYTHON_MAYBE_UNUSED_VAR(x) (void)(x)
#  endif
#endif
#ifndef CYTHON_NCP_UNUSED
# if CYTHON_COMPILING_IN_CPYTHON
#  define CYTHON_NCP_UNUSED
# else
#  define CYTHON_NCP_UNUSED CYTHON_UNUSED
# endif
#endif
#define __Pyx_void_to_None(void_result) ((void)(void_result), Py_INCREF(Py_None), Py_None)

#ifndef __cplusplus
  #error "Cython files generated with the C++ option must be compiled with a C++ compiler."
#endif
#ifndef CYTHON_INLINE
  #if defined(__clang__)
    #define CYTHON_INLINE __inline__ __attribute__ ((__unused__))
  #else
    #define CYTHON_INLINE inline
  #endif
#endif
template<typename T>
void __Pyx_call_destructor(T& x) {
    x.~T();
}
template<typename T>
class __Pyx_FakeReference {
  public:
    __Pyx_FakeReference() : ptr(NULL) { }
    __Pyx_FakeReference(const T& ref) : ptr(const_cast<T*>(&ref)) { }
    T *operator->() { return ptr; }
    T *operator&() { return ptr; }
    operator T&() { return *ptr; }
    template<typename U> bool operator ==(U other) { return *ptr == other; }
    template<typename U> bool operator !=(U other) { return *ptr != other; }
  private:
    T *ptr;
};

#if defined(WIN32) || defined(MS_WINDOWS)
  #define _USE_MATH_DEFINES
#endif
#include <math.h>
#ifdef NAN
#define __PYX_NAN() ((float) NAN)
#else
static CYTHON_INLINE float __PYX_NAN() {
  float value;
  memset(&value, 0xFF, sizeof(value));
  return value;
}
#endif
#if defined(__CYGWIN__) && defined(_LDBL_EQ_DBL)
#define __Pyx_truncl trunc
#else
#define __Pyx_truncl truncl
#endif


#define __PYX_ERR(f_index, lineno, Ln_error) \
{ \
  __pyx_filename = __pyx_f[f_index]; __pyx_lineno = lineno; __pyx_clineno = __LINE__; goto Ln_error; \
}

#if PY_MAJOR_VERSION >= 3
  #define __Pyx_PyNumber_Divide(x,y)         PyNumber_TrueDivide(x,y)
  #define __Pyx_PyNumber_InPlaceDivide(x,y)  PyNumber_InPlaceTrueDivide(x,y)
#else
  #define __Pyx_PyNumber_Divide(x,y)         PyNumber_TrueDivide(x,y)
  #define __Pyx_PyNumber_InPlaceDivide(x,y)  PyNumber_InPlaceTrueDivide(x,y)
#endif

#ifndef __PYX_EXTERN_C
  #ifdef __cplusplus
    #define __PYX_EXTERN_C extern "C"
  #else
    #define __PYX_EXTERN_C extern
  #endif
#endif

#define __PYX_HAVE___qtexec_
#define __PYX_HAVE_API___qtexec_
#include <stdint.h>
#include <QtCore/QtGlobal>
#include <QtCore/Qt>
#include <QtCore/QByteArray>
#include <QtCore/QElapsedTimer>
#include <QtCore/QEvent>
#include <QtCore/QFileSystemWatcher>
#include <QtCore/QLibraryInfo>
#include <QtCore/QList>
#include <QtCore/QStringList>
#include <QtCore/QLocale>
#include <QtCore/QMap>
#include <QtCore/QMetaMethod>
#include <QtCore/QMetaObject>
#include <QtCore/QMetaProperty>
#include <QtCore/QMimeData>
#include <QtCore/QModelIndex>
#include <QtCore/QObject>
#include <QtCore/QPoint>
#include <QtCore/QPointF>
#include <QtCore/QSize>
#include <QtCore/QStandardPaths>
#include <QtCore/QString>
#include <QtCore/QTimer>
#include <QtCore/QTranslator>
#include <QtCore/QUrl>
#include <QtCore/QVariant>
#include <QtGui/QCloseEvent>
#include <QtGui/QColor>
#include <QtGui/QCursor>
#include <QtGui/QDragEnterEvent>
#include <QtGui/QDropEvent>
#include <QtGui/QFont>
#include <QtGui/QIcon>
#include <QtGui/QImage>
#include <QtGui/QKeyEvent>
#include <QtGui/QKeySequence>
#include <QtGui/QMouseEvent>
#include <QtGui/QOpenGLContext>
#include <QtGui/QOpenGLDebugLogger>
#include <QtGui/QOpenGLDebugMessage>
#include <QtGui/QOpenGLFramebufferObjectFormat>
#include <QtGui/QOpenGLFramebufferObject>
#include <QtGui/QOpenGLFunctions>
#include <QtGui/QOpenGLTexture>
#include <QtGui/QPaintEvent>
#include <QtGui/QPixmap>
#include <QtGui/QResizeEvent>
#include <QtGui/QShowEvent>
#include <QtGui/QStandardItem>
#include <QtGui/QStandardItemModel>
#include <QtGui/QSurfaceFormat>
#include <QtGui/QTextDocumentFragment>
#include <QtGui/QTransform>
#include <QtGui/QWheelEvent>
#include <QtCore/QCoreApplication>
#include <QtWidgets/QApplication>
#include <QtWidgets/QWidget>
#include <QtWidgets/QDialog>
#include <QtWidgets/QFileDialog>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QListWidget>
#include <QtWidgets/QListWidgetItem>
#include <QtWidgets/QMainWindow>
#include <QtWidgets/QMessageBox>
#include <QtWidgets/QOpenGLWidget>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSizePolicy>
#include <QtWidgets/QStatusBar>
#include <QtWidgets/QTreeView>
#include <string.h>
#include <stdio.h>
#ifdef _OPENMP
#include <omp.h>
#endif /* _OPENMP */

#ifdef PYREX_WITHOUT_ASSERTIONS
#define CYTHON_WITHOUT_ASSERTIONS
#endif

typedef struct {PyObject **p; const char *s; const Py_ssize_t n; const char* encoding;
                const char is_unicode; const char is_str; const char intern; } __Pyx_StringTabEntry;

#define __PYX_DEFAULT_STRING_ENCODING_IS_ASCII 0
#define __PYX_DEFAULT_STRING_ENCODING_IS_DEFAULT 0
#define __PYX_DEFAULT_STRING_ENCODING ""
#define __Pyx_PyObject_FromString __Pyx_PyBytes_FromString
#define __Pyx_PyObject_FromStringAndSize __Pyx_PyBytes_FromStringAndSize
#define __Pyx_uchar_cast(c) ((unsigned char)c)
#define __Pyx_long_cast(x) ((long)x)
#define __Pyx_fits_Py_ssize_t(v, type, is_signed)  (\
    (sizeof(type) < sizeof(Py_ssize_t))  ||\
    (sizeof(type) > sizeof(Py_ssize_t) &&\
          likely(v < (type)PY_SSIZE_T_MAX ||\
                 v == (type)PY_SSIZE_T_MAX)  &&\
          (!is_signed || likely(v > (type)PY_SSIZE_T_MIN ||\
                                v == (type)PY_SSIZE_T_MIN)))  ||\
    (sizeof(type) == sizeof(Py_ssize_t) &&\
          (is_signed || likely(v < (type)PY_SSIZE_T_MAX ||\
                               v == (type)PY_SSIZE_T_MAX)))  )
#if defined (__cplusplus) && __cplusplus >= 201103L
    #include <cstdlib>
    #define __Pyx_sst_abs(value) std::abs(value)
#elif SIZEOF_INT >= SIZEOF_SIZE_T
    #define __Pyx_sst_abs(value) abs(value)
#elif SIZEOF_LONG >= SIZEOF_SIZE_T
    #define __Pyx_sst_abs(value) labs(value)
#elif defined (_MSC_VER) && defined (_M_X64)
    #define __Pyx_sst_abs(value) _abs64(value)
#elif defined (__STDC_VERSION__) && __STDC_VERSION__ >= 199901L
    #define __Pyx_sst_abs(value) llabs(value)
#elif defined (__GNUC__)
    #define __Pyx_sst_abs(value) __builtin_llabs(value)
#else
    #define __Pyx_sst_abs(value) ((value<0) ? -value : value)
#endif
static CYTHON_INLINE char* __Pyx_PyObject_AsString(PyObject*);
static CYTHON_INLINE char* __Pyx_PyObject_AsStringAndSize(PyObject*, Py_ssize_t* length);
#define __Pyx_PyByteArray_FromString(s) PyByteArray_FromStringAndSize((const char*)s, strlen((const char*)s))
#define __Pyx_PyByteArray_FromStringAndSize(s, l) PyByteArray_FromStringAndSize((const char*)s, l)
#define __Pyx_PyBytes_FromString        PyBytes_FromString
#define __Pyx_PyBytes_FromStringAndSize PyBytes_FromStringAndSize
static CYTHON_INLINE PyObject* __Pyx_PyUnicode_FromString(const char*);
#if PY_MAJOR_VERSION < 3
    #define __Pyx_PyStr_FromString        __Pyx_PyBytes_FromString
    #define __Pyx_PyStr_FromStringAndSize __Pyx_PyBytes_FromStringAndSize
#else
    #define __Pyx_PyStr_FromString        __Pyx_PyUnicode_FromString
    #define __Pyx_PyStr_FromStringAndSize __Pyx_PyUnicode_FromStringAndSize
#endif
#define __Pyx_PyObject_AsSString(s)    ((signed char*) __Pyx_PyObject_AsString(s))
#define __Pyx_PyObject_AsUString(s)    ((unsigned char*) __Pyx_PyObject_AsString(s))
#define __Pyx_PyObject_FromCString(s)  __Pyx_PyObject_FromString((const char*)s)
#define __Pyx_PyBytes_FromCString(s)   __Pyx_PyBytes_FromString((const char*)s)
#define __Pyx_PyByteArray_FromCString(s)   __Pyx_PyByteArray_FromString((const char*)s)
#define __Pyx_PyStr_FromCString(s)     __Pyx_PyStr_FromString((const char*)s)
#define __Pyx_PyUnicode_FromCString(s) __Pyx_PyUnicode_FromString((const char*)s)
#if PY_MAJOR_VERSION < 3
static CYTHON_INLINE size_t __Pyx_Py_UNICODE_strlen(const Py_UNICODE *u)
{
    const Py_UNICODE *u_end = u;
    while (*u_end++) ;
    return (size_t)(u_end - u - 1);
}
#else
#define __Pyx_Py_UNICODE_strlen Py_UNICODE_strlen
#endif
#define __Pyx_PyUnicode_FromUnicode(u)       PyUnicode_FromUnicode(u, __Pyx_Py_UNICODE_strlen(u))
#define __Pyx_PyUnicode_FromUnicodeAndLength PyUnicode_FromUnicode
#define __Pyx_PyUnicode_AsUnicode            PyUnicode_AsUnicode
#define __Pyx_NewRef(obj) (Py_INCREF(obj), obj)
#define __Pyx_Owned_Py_None(b) __Pyx_NewRef(Py_None)
#define __Pyx_PyBool_FromLong(b) ((b) ? __Pyx_NewRef(Py_True) : __Pyx_NewRef(Py_False))
static CYTHON_INLINE int __Pyx_PyObject_IsTrue(PyObject*);
static CYTHON_INLINE PyObject* __Pyx_PyNumber_IntOrLong(PyObject* x);
static CYTHON_INLINE Py_ssize_t __Pyx_PyIndex_AsSsize_t(PyObject*);
static CYTHON_INLINE PyObject * __Pyx_PyInt_FromSize_t(size_t);
#if CYTHON_ASSUME_SAFE_MACROS
#define __pyx_PyFloat_AsDouble(x) (PyFloat_CheckExact(x) ? PyFloat_AS_DOUBLE(x) : PyFloat_AsDouble(x))
#else
#define __pyx_PyFloat_AsDouble(x) PyFloat_AsDouble(x)
#endif
#define __pyx_PyFloat_AsFloat(x) ((float) __pyx_PyFloat_AsDouble(x))
#if PY_MAJOR_VERSION >= 3
#define __Pyx_PyNumber_Int(x) (PyLong_CheckExact(x) ? __Pyx_NewRef(x) : PyNumber_Long(x))
#else
#define __Pyx_PyNumber_Int(x) (PyInt_CheckExact(x) ? __Pyx_NewRef(x) : PyNumber_Int(x))
#endif
#define __Pyx_PyNumber_Float(x) (PyFloat_CheckExact(x) ? __Pyx_NewRef(x) : PyNumber_Float(x))
#if PY_MAJOR_VERSION < 3 && __PYX_DEFAULT_STRING_ENCODING_IS_ASCII
static int __Pyx_sys_getdefaultencoding_not_ascii;
static int __Pyx_init_sys_getdefaultencoding_params(void) {
    PyObject* sys;
    PyObject* default_encoding = NULL;
    PyObject* ascii_chars_u = NULL;
    PyObject* ascii_chars_b = NULL;
    const char* default_encoding_c;
    sys = PyImport_ImportModule("sys");
    if (!sys) goto bad;
    default_encoding = PyObject_CallMethod(sys, (char*) "getdefaultencoding", NULL);
    Py_DECREF(sys);
    if (!default_encoding) goto bad;
    default_encoding_c = PyBytes_AsString(default_encoding);
    if (!default_encoding_c) goto bad;
    if (strcmp(default_encoding_c, "ascii") == 0) {
        __Pyx_sys_getdefaultencoding_not_ascii = 0;
    } else {
        char ascii_chars[128];
        int c;
        for (c = 0; c < 128; c++) {
            ascii_chars[c] = c;
        }
        __Pyx_sys_getdefaultencoding_not_ascii = 1;
        ascii_chars_u = PyUnicode_DecodeASCII(ascii_chars, 128, NULL);
        if (!ascii_chars_u) goto bad;
        ascii_chars_b = PyUnicode_AsEncodedString(ascii_chars_u, default_encoding_c, NULL);
        if (!ascii_chars_b || !PyBytes_Check(ascii_chars_b) || memcmp(ascii_chars, PyBytes_AS_STRING(ascii_chars_b), 128) != 0) {
            PyErr_Format(
                PyExc_ValueError,
                "This module compiled with c_string_encoding=ascii, but default encoding '%.200s' is not a superset of ascii.",
                default_encoding_c);
            goto bad;
        }
        Py_DECREF(ascii_chars_u);
        Py_DECREF(ascii_chars_b);
    }
    Py_DECREF(default_encoding);
    return 0;
bad:
    Py_XDECREF(default_encoding);
    Py_XDECREF(ascii_chars_u);
    Py_XDECREF(ascii_chars_b);
    return -1;
}
#endif
#if __PYX_DEFAULT_STRING_ENCODING_IS_DEFAULT && PY_MAJOR_VERSION >= 3
#define __Pyx_PyUnicode_FromStringAndSize(c_str, size) PyUnicode_DecodeUTF8(c_str, size, NULL)
#else
#define __Pyx_PyUnicode_FromStringAndSize(c_str, size) PyUnicode_Decode(c_str, size, __PYX_DEFAULT_STRING_ENCODING, NULL)
#if __PYX_DEFAULT_STRING_ENCODING_IS_DEFAULT
static char* __PYX_DEFAULT_STRING_ENCODING;
static int __Pyx_init_sys_getdefaultencoding_params(void) {
    PyObject* sys;
    PyObject* default_encoding = NULL;
    char* default_encoding_c;
    sys = PyImport_ImportModule("sys");
    if (!sys) goto bad;
    default_encoding = PyObject_CallMethod(sys, (char*) (const char*) "getdefaultencoding", NULL);
    Py_DECREF(sys);
    if (!default_encoding) goto bad;
    default_encoding_c = PyBytes_AsString(default_encoding);
    if (!default_encoding_c) goto bad;
    __PYX_DEFAULT_STRING_ENCODING = (char*) malloc(strlen(default_encoding_c));
    if (!__PYX_DEFAULT_STRING_ENCODING) goto bad;
    strcpy(__PYX_DEFAULT_STRING_ENCODING, default_encoding_c);
    Py_DECREF(default_encoding);
    return 0;
bad:
    Py_XDECREF(default_encoding);
    return -1;
}
#endif
#endif


/* Test for GCC > 2.95 */
#if defined(__GNUC__)     && (__GNUC__ > 2 || (__GNUC__ == 2 && (__GNUC_MINOR__ > 95)))
  #define likely(x)   __builtin_expect(!!(x), 1)
  #define unlikely(x) __builtin_expect(!!(x), 0)
#else /* !__GNUC__ or GCC < 2.95 */
  #define likely(x)   (x)
  #define unlikely(x) (x)
#endif /* __GNUC__ */

static PyObject *__pyx_m;
static PyObject *__pyx_d;
static PyObject *__pyx_b;
static PyObject *__pyx_empty_tuple;
static PyObject *__pyx_empty_bytes;
static PyObject *__pyx_empty_unicode;
static int __pyx_lineno;
static int __pyx_clineno = 0;
static const char * __pyx_cfilenm= __FILE__;
static const char *__pyx_filename;


static const char *__pyx_f[] = {
  "build/temp.linux-x86_64-3.5/pybiklib/ext/_qtexec_.pyx",
};

/*--- Type declarations ---*/

/* "qt.pxd":23
 * 
 * 
 * ctypedef void CallbackVoid() nogil             # <<<<<<<<<<<<<<
 * ctypedef void CallbackInt(int) nogil
 * ctypedef void CallbackString(const QString &) nogil
 */
typedef void __pyx_t_2qt_CallbackVoid(void);

/* "qt.pxd":24
 * 
 * ctypedef void CallbackVoid() nogil
 * ctypedef void CallbackInt(int) nogil             # <<<<<<<<<<<<<<
 * ctypedef void CallbackString(const QString &) nogil
 * ctypedef void CallbackDebugMessage(const QOpenGLDebugMessage &) nogil
 */
typedef void __pyx_t_2qt_CallbackInt(int);

/* "qt.pxd":25
 * ctypedef void CallbackVoid() nogil
 * ctypedef void CallbackInt(int) nogil
 * ctypedef void CallbackString(const QString &) nogil             # <<<<<<<<<<<<<<
 * ctypedef void CallbackDebugMessage(const QOpenGLDebugMessage &) nogil
 * 
 */
typedef void __pyx_t_2qt_CallbackString(QString const &);

/* "qt.pxd":26
 * ctypedef void CallbackInt(int) nogil
 * ctypedef void CallbackString(const QString &) nogil
 * ctypedef void CallbackDebugMessage(const QOpenGLDebugMessage &) nogil             # <<<<<<<<<<<<<<
 * 
 * 
 */
typedef void __pyx_t_2qt_CallbackDebugMessage(QOpenGLDebugMessage const &);

/* "_qtexec_.pyx":41
 * #puts = print
 * 
 * cdef enum: # #px/             # <<<<<<<<<<<<<<
 * #if True:
 *     DEBUG_MSG = 0x0002
 */
enum  {
  __pyx_e_8_qtexec__DEBUG_MSG = 0x0002,
  __pyx_e_8_qtexec__DEBUG_MSGEXT = 0x0020
};

/* --- Runtime support code (head) --- */
/* Refnanny.proto */
#ifndef CYTHON_REFNANNY
  #define CYTHON_REFNANNY 0
#endif
#if CYTHON_REFNANNY
  typedef struct {
    void (*INCREF)(void*, PyObject*, int);
    void (*DECREF)(void*, PyObject*, int);
    void (*GOTREF)(void*, PyObject*, int);
    void (*GIVEREF)(void*, PyObject*, int);
    void* (*SetupContext)(const char*, int, const char*);
    void (*FinishContext)(void**);
  } __Pyx_RefNannyAPIStruct;
  static __Pyx_RefNannyAPIStruct *__Pyx_RefNanny = NULL;
  static __Pyx_RefNannyAPIStruct *__Pyx_RefNannyImportAPI(const char *modname);
  #define __Pyx_RefNannyDeclarations void *__pyx_refnanny = NULL;
#ifdef WITH_THREAD
  #define __Pyx_RefNannySetupContext(name, acquire_gil)\
          if (acquire_gil) {\
              PyGILState_STATE __pyx_gilstate_save = PyGILState_Ensure();\
              __pyx_refnanny = __Pyx_RefNanny->SetupContext((name), __LINE__, __FILE__);\
              PyGILState_Release(__pyx_gilstate_save);\
          } else {\
              __pyx_refnanny = __Pyx_RefNanny->SetupContext((name), __LINE__, __FILE__);\
          }
#else
  #define __Pyx_RefNannySetupContext(name, acquire_gil)\
          __pyx_refnanny = __Pyx_RefNanny->SetupContext((name), __LINE__, __FILE__)
#endif
  #define __Pyx_RefNannyFinishContext()\
          __Pyx_RefNanny->FinishContext(&__pyx_refnanny)
  #define __Pyx_INCREF(r)  __Pyx_RefNanny->INCREF(__pyx_refnanny, (PyObject *)(r), __LINE__)
  #define __Pyx_DECREF(r)  __Pyx_RefNanny->DECREF(__pyx_refnanny, (PyObject *)(r), __LINE__)
  #define __Pyx_GOTREF(r)  __Pyx_RefNanny->GOTREF(__pyx_refnanny, (PyObject *)(r), __LINE__)
  #define __Pyx_GIVEREF(r) __Pyx_RefNanny->GIVEREF(__pyx_refnanny, (PyObject *)(r), __LINE__)
  #define __Pyx_XINCREF(r)  do { if((r) != NULL) {__Pyx_INCREF(r); }} while(0)
  #define __Pyx_XDECREF(r)  do { if((r) != NULL) {__Pyx_DECREF(r); }} while(0)
  #define __Pyx_XGOTREF(r)  do { if((r) != NULL) {__Pyx_GOTREF(r); }} while(0)
  #define __Pyx_XGIVEREF(r) do { if((r) != NULL) {__Pyx_GIVEREF(r);}} while(0)
#else
  #define __Pyx_RefNannyDeclarations
  #define __Pyx_RefNannySetupContext(name, acquire_gil)
  #define __Pyx_RefNannyFinishContext()
  #define __Pyx_INCREF(r) Py_INCREF(r)
  #define __Pyx_DECREF(r) Py_DECREF(r)
  #define __Pyx_GOTREF(r)
  #define __Pyx_GIVEREF(r)
  #define __Pyx_XINCREF(r) Py_XINCREF(r)
  #define __Pyx_XDECREF(r) Py_XDECREF(r)
  #define __Pyx_XGOTREF(r)
  #define __Pyx_XGIVEREF(r)
#endif
#define __Pyx_XDECREF_SET(r, v) do {\
        PyObject *tmp = (PyObject *) r;\
        r = v; __Pyx_XDECREF(tmp);\
    } while (0)
#define __Pyx_DECREF_SET(r, v) do {\
        PyObject *tmp = (PyObject *) r;\
        r = v; __Pyx_DECREF(tmp);\
    } while (0)
#define __Pyx_CLEAR(r)    do { PyObject* tmp = ((PyObject*)(r)); r = NULL; __Pyx_DECREF(tmp);} while(0)
#define __Pyx_XCLEAR(r)   do { if((r) != NULL) {PyObject* tmp = ((PyObject*)(r)); r = NULL; __Pyx_DECREF(tmp);}} while(0)

/* PyObjectGetAttrStr.proto */
#if CYTHON_USE_TYPE_SLOTS
static CYTHON_INLINE PyObject* __Pyx_PyObject_GetAttrStr(PyObject* obj, PyObject* attr_name) {
    PyTypeObject* tp = Py_TYPE(obj);
    if (likely(tp->tp_getattro))
        return tp->tp_getattro(obj, attr_name);
#if PY_MAJOR_VERSION < 3
    if (likely(tp->tp_getattr))
        return tp->tp_getattr(obj, PyString_AS_STRING(attr_name));
#endif
    return PyObject_GetAttr(obj, attr_name);
}
#else
#define __Pyx_PyObject_GetAttrStr(o,n) PyObject_GetAttr(o,n)
#endif

/* GetBuiltinName.proto */
static PyObject *__Pyx_GetBuiltinName(PyObject *name);

/* IncludeStringH.proto */
#include <string.h>

/* decode_c_string.proto */
static CYTHON_INLINE PyObject* __Pyx_decode_c_string(
         const char* cstring, Py_ssize_t start, Py_ssize_t stop,
         const char* encoding, const char* errors,
         PyObject* (*decode_func)(const char *s, Py_ssize_t size, const char *errors));

/* PyObjectCall.proto */
#if CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE PyObject* __Pyx_PyObject_Call(PyObject *func, PyObject *arg, PyObject *kw);
#else
#define __Pyx_PyObject_Call(func, arg, kw) PyObject_Call(func, arg, kw)
#endif

/* PyThreadStateGet.proto */
#if CYTHON_FAST_THREAD_STATE
#define __Pyx_PyThreadState_declare  PyThreadState *__pyx_tstate;
#define __Pyx_PyThreadState_assign  __pyx_tstate = PyThreadState_GET();
#else
#define __Pyx_PyThreadState_declare
#define __Pyx_PyThreadState_assign
#endif

/* PyErrFetchRestore.proto */
#if CYTHON_FAST_THREAD_STATE
#define __Pyx_ErrRestoreWithState(type, value, tb)  __Pyx_ErrRestoreInState(PyThreadState_GET(), type, value, tb)
#define __Pyx_ErrFetchWithState(type, value, tb)    __Pyx_ErrFetchInState(PyThreadState_GET(), type, value, tb)
#define __Pyx_ErrRestore(type, value, tb)  __Pyx_ErrRestoreInState(__pyx_tstate, type, value, tb)
#define __Pyx_ErrFetch(type, value, tb)    __Pyx_ErrFetchInState(__pyx_tstate, type, value, tb)
static CYTHON_INLINE void __Pyx_ErrRestoreInState(PyThreadState *tstate, PyObject *type, PyObject *value, PyObject *tb);
static CYTHON_INLINE void __Pyx_ErrFetchInState(PyThreadState *tstate, PyObject **type, PyObject **value, PyObject **tb);
#else
#define __Pyx_ErrRestoreWithState(type, value, tb)  PyErr_Restore(type, value, tb)
#define __Pyx_ErrFetchWithState(type, value, tb)  PyErr_Fetch(type, value, tb)
#define __Pyx_ErrRestore(type, value, tb)  PyErr_Restore(type, value, tb)
#define __Pyx_ErrFetch(type, value, tb)  PyErr_Fetch(type, value, tb)
#endif

/* WriteUnraisableException.proto */
static void __Pyx_WriteUnraisable(const char *name, int clineno,
                                  int lineno, const char *filename,
                                  int full_traceback, int nogil);

/* ListCompAppend.proto */
#if CYTHON_USE_PYLIST_INTERNALS && CYTHON_ASSUME_SAFE_MACROS
static CYTHON_INLINE int __Pyx_ListComp_Append(PyObject* list, PyObject* x) {
    PyListObject* L = (PyListObject*) list;
    Py_ssize_t len = Py_SIZE(list);
    if (likely(L->allocated > len)) {
        Py_INCREF(x);
        PyList_SET_ITEM(list, len, x);
        Py_SIZE(list) = len+1;
        return 0;
    }
    return PyList_Append(list, x);
}
#else
#define __Pyx_ListComp_Append(L,x) PyList_Append(L,x)
#endif

/* GetModuleGlobalName.proto */
static CYTHON_INLINE PyObject *__Pyx_GetModuleGlobalName(PyObject *name);

/* PyCFunctionFastCall.proto */
#if CYTHON_FAST_PYCCALL
static CYTHON_INLINE PyObject *__Pyx_PyCFunction_FastCall(PyObject *func, PyObject **args, Py_ssize_t nargs);
#else
#define __Pyx_PyCFunction_FastCall(func, args, nargs)  (assert(0), NULL)
#endif

/* PyFunctionFastCall.proto */
#if CYTHON_FAST_PYCALL
#define __Pyx_PyFunction_FastCall(func, args, nargs)\
    __Pyx_PyFunction_FastCallDict((func), (args), (nargs), NULL)
#if 1 || PY_VERSION_HEX < 0x030600B1
static PyObject *__Pyx_PyFunction_FastCallDict(PyObject *func, PyObject **args, int nargs, PyObject *kwargs);
#else
#define __Pyx_PyFunction_FastCallDict(func, args, nargs, kwargs) _PyFunction_FastCallDict(func, args, nargs, kwargs)
#endif
#endif

/* PyObjectCallMethO.proto */
#if CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE PyObject* __Pyx_PyObject_CallMethO(PyObject *func, PyObject *arg);
#endif

/* PyObjectCallOneArg.proto */
static CYTHON_INLINE PyObject* __Pyx_PyObject_CallOneArg(PyObject *func, PyObject *arg);

/* PyObjectCallNoArg.proto */
#if CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE PyObject* __Pyx_PyObject_CallNoArg(PyObject *func);
#else
#define __Pyx_PyObject_CallNoArg(func) __Pyx_PyObject_Call(func, __pyx_empty_tuple, NULL)
#endif

/* SaveResetException.proto */
#if CYTHON_FAST_THREAD_STATE
#define __Pyx_ExceptionSave(type, value, tb)  __Pyx__ExceptionSave(__pyx_tstate, type, value, tb)
static CYTHON_INLINE void __Pyx__ExceptionSave(PyThreadState *tstate, PyObject **type, PyObject **value, PyObject **tb);
#define __Pyx_ExceptionReset(type, value, tb)  __Pyx__ExceptionReset(__pyx_tstate, type, value, tb)
static CYTHON_INLINE void __Pyx__ExceptionReset(PyThreadState *tstate, PyObject *type, PyObject *value, PyObject *tb);
#else
#define __Pyx_ExceptionSave(type, value, tb)   PyErr_GetExcInfo(type, value, tb)
#define __Pyx_ExceptionReset(type, value, tb)  PyErr_SetExcInfo(type, value, tb)
#endif

/* PyErrExceptionMatches.proto */
#if CYTHON_FAST_THREAD_STATE
#define __Pyx_PyErr_ExceptionMatches(err) __Pyx_PyErr_ExceptionMatchesInState(__pyx_tstate, err)
static CYTHON_INLINE int __Pyx_PyErr_ExceptionMatchesInState(PyThreadState* tstate, PyObject* err);
#else
#define __Pyx_PyErr_ExceptionMatches(err)  PyErr_ExceptionMatches(err)
#endif

/* GetException.proto */
#if CYTHON_FAST_THREAD_STATE
#define __Pyx_GetException(type, value, tb)  __Pyx__GetException(__pyx_tstate, type, value, tb)
static int __Pyx__GetException(PyThreadState *tstate, PyObject **type, PyObject **value, PyObject **tb);
#else
static int __Pyx_GetException(PyObject **type, PyObject **value, PyObject **tb);
#endif

/* StringJoin.proto */
#if PY_MAJOR_VERSION < 3
#define __Pyx_PyString_Join __Pyx_PyBytes_Join
#define __Pyx_PyBaseString_Join(s, v) (PyUnicode_CheckExact(s) ? PyUnicode_Join(s, v) : __Pyx_PyBytes_Join(s, v))
#else
#define __Pyx_PyString_Join PyUnicode_Join
#define __Pyx_PyBaseString_Join PyUnicode_Join
#endif
#if CYTHON_COMPILING_IN_CPYTHON
    #if PY_MAJOR_VERSION < 3
    #define __Pyx_PyBytes_Join _PyString_Join
    #else
    #define __Pyx_PyBytes_Join _PyBytes_Join
    #endif
#else
static CYTHON_INLINE PyObject* __Pyx_PyBytes_Join(PyObject* sep, PyObject* values);
#endif

/* ListAppend.proto */
#if CYTHON_USE_PYLIST_INTERNALS && CYTHON_ASSUME_SAFE_MACROS
static CYTHON_INLINE int __Pyx_PyList_Append(PyObject* list, PyObject* x) {
    PyListObject* L = (PyListObject*) list;
    Py_ssize_t len = Py_SIZE(list);
    if (likely(L->allocated > len) & likely(len > (L->allocated >> 1))) {
        Py_INCREF(x);
        PyList_SET_ITEM(list, len, x);
        Py_SIZE(list) = len+1;
        return 0;
    }
    return PyList_Append(list, x);
}
#else
#define __Pyx_PyList_Append(L,x) PyList_Append(L,x)
#endif

/* Import.proto */
static PyObject *__Pyx_Import(PyObject *name, PyObject *from_list, int level);

/* ImportFrom.proto */
static PyObject* __Pyx_ImportFrom(PyObject* module, PyObject* name);

/* CodeObjectCache.proto */
typedef struct {
    PyCodeObject* code_object;
    int code_line;
} __Pyx_CodeObjectCacheEntry;
struct __Pyx_CodeObjectCache {
    int count;
    int max_count;
    __Pyx_CodeObjectCacheEntry* entries;
};
static struct __Pyx_CodeObjectCache __pyx_code_cache = {0,0,NULL};
static int __pyx_bisect_code_objects(__Pyx_CodeObjectCacheEntry* entries, int count, int code_line);
static PyCodeObject *__pyx_find_code_object(int code_line);
static void __pyx_insert_code_object(int code_line, PyCodeObject* code_object);

/* AddTraceback.proto */
static void __Pyx_AddTraceback(const char *funcname, int c_line,
                               int py_line, const char *filename);

/* CIntToPy.proto */
static CYTHON_INLINE PyObject* __Pyx_PyInt_From_int(int value);

/* CIntFromPy.proto */
static CYTHON_INLINE long __Pyx_PyInt_As_long(PyObject *);

/* CIntToPy.proto */
static CYTHON_INLINE PyObject* __Pyx_PyInt_From_long(long value);

/* CIntFromPy.proto */
static CYTHON_INLINE int __Pyx_PyInt_As_int(PyObject *);

/* CheckBinaryVersion.proto */
static int __Pyx_check_binary_version(void);

/* InitStrings.proto */
static int __Pyx_InitStrings(__Pyx_StringTabEntry *t);


/* Module declarations from 'libc.stdint' */

/* Module declarations from 'libcpp' */

/* Module declarations from 'qt' */

/* Module declarations from 'libc.string' */

/* Module declarations from 'libc.stdio' */

/* Module declarations from '_qtexec_' */
static long __pyx_v_8_qtexec__debug;
static PyObject *__pyx_f_8_qtexec__q2str(QString const &); /*proto*/
static QString __pyx_f_8_qtexec__str2q(PyObject *); /*proto*/
#define __Pyx_MODULE_NAME "_qtexec_"
int __pyx_module_is_main__qtexec_ = 0;

/* Implementation of '_qtexec_' */
static PyObject *__pyx_builtin_print;
static PyObject *__pyx_builtin_range;
static const char __pyx_k_P[] = "{}P";
static const char __pyx_k_d[] = "d";
static const char __pyx_k_i[] = "i";
static const char __pyx_k__2[] = "";
static const char __pyx_k__3[] = "\000";
static const char __pyx_k__5[] = " ";
static const char __pyx_k_os[] = "os";
static const char __pyx_k_qt[] = "qt_";
static const char __pyx_k_app[] = "app";
static const char __pyx_k_arg[] = "arg";
static const char __pyx_k_dos[] = "dos";
static const char __pyx_k_es2[] = "es2";
static const char __pyx_k_ogl[] = "ogl";
static const char __pyx_k_ptr[] = "ptr";
static const char __pyx_k_qtq[] = "qtq";
static const char __pyx_k_qtw[] = "qtw\077\077?";
static const char __pyx_k_sys[] = "sys";
static const char __pyx_k_argc[] = "argc";
static const char __pyx_k_argv[] = "argv";
static const char __pyx_k_es2d[] = "es2d";
static const char __pyx_k_join[] = "join";
static const char __pyx_k_main[] = "__main__";
static const char __pyx_k_ogld[] = "ogld";
static const char __pyx_k_opts[] = "opts";
static const char __pyx_k_pack[] = "pack";
static const char __pyx_k_qtqd[] = "qtqd";
static const char __pyx_k_qtui[] = "_qtui_";
static const char __pyx_k_qtwd[] = "qtwd";
static const char __pyx_k_test[] = "__test__";
static const char __pyx_k_es2os[] = "es2os";
static const char __pyx_k_oglos[] = "oglos";
static const char __pyx_k_print[] = "print";
static const char __pyx_k_pyapp[] = "pyapp";
static const char __pyx_k_qargs[] = "qargs";
static const char __pyx_k_qtq_2[] = "qtq\077\077?";
static const char __pyx_k_qtq_d[] = "qtq\077\077?d";
static const char __pyx_k_qtqos[] = "qtqos";
static const char __pyx_k_qtw_2[] = "qtw";
static const char __pyx_k_qtw_d[] = "qtw\077\077?d";
static const char __pyx_k_qtwos[] = "qtwos";
static const char __pyx_k_range[] = "range";
static const char __pyx_k_utf_8[] = "utf-8";
static const char __pyx_k_config[] = "config_";
static const char __pyx_k_encode[] = "encode";
static const char __pyx_k_es2dos[] = "es2dos";
static const char __pyx_k_format[] = "format";
static const char __pyx_k_import[] = "__import__";
static const char __pyx_k_main_2[] = "main";
static const char __pyx_k_module[] = "module";
static const char __pyx_k_ogldos[] = "ogldos";
static const char __pyx_k_qtexec[] = "_qtexec_";
static const char __pyx_k_qtq_os[] = "qtq\077\077?os";
static const char __pyx_k_qtqdos[] = "qtqdos";
static const char __pyx_k_qtqes2[] = "qtqes2";
static const char __pyx_k_qtqogl[] = "qtqogl";
static const char __pyx_k_qtw_os[] = "qtw\077\077?os";
static const char __pyx_k_qtwdos[] = "qtwdos";
static const char __pyx_k_qtwes2[] = "qtwes2";
static const char __pyx_k_qtwogl[] = "qtwogl";
static const char __pyx_k_struct[] = "struct";
static const char __pyx_k_APPNAME[] = "APPNAME";
static const char __pyx_k_PACKAGE[] = "PACKAGE";
static const char __pyx_k_VERSION[] = "VERSION";
static const char __pyx_k_aliases[] = "aliases";
static const char __pyx_k_depends[] = "depends";
static const char __pyx_k_ptrlist[] = "ptrlist";
static const char __pyx_k_qtq_dos[] = "qtq\077\077?dos";
static const char __pyx_k_qtqes2d[] = "qtqes2d";
static const char __pyx_k_qtqogld[] = "qtqogld";
static const char __pyx_k_qtw_dos[] = "qtw\077\077?dos";
static const char __pyx_k_qtwes2d[] = "qtwes2d";
static const char __pyx_k_qtwogld[] = "qtwogld";
static const char __pyx_k_ui_args[] = "ui_args";
static const char __pyx_k_compiled[] = "__compiled";
static const char __pyx_k_config_2[] = "config";
static const char __pyx_k_exc_info[] = "exc_info";
static const char __pyx_k_language[] = "language";
static const char __pyx_k_pybiklib[] = "pybiklib";
static const char __pyx_k_qtqes2os[] = "qtqes2os";
static const char __pyx_k_qtqoglos[] = "qtqoglos";
static const char __pyx_k_qtwes2os[] = "qtwes2os";
static const char __pyx_k_qtwoglos[] = "qtwoglos";
static const char __pyx_k_DEBUG_MSG[] = "DEBUG_MSG";
static const char __pyx_k_byteslist[] = "byteslist";
static const char __pyx_k_debug_es2[] = "_debug_es2";
static const char __pyx_k_debug_ogl[] = "_debug_ogl";
static const char __pyx_k_qt_qtqes2[] = "_qt_qtqes2";
static const char __pyx_k_qt_qtqogl[] = "_qt_qtqogl";
static const char __pyx_k_qt_qtwes2[] = "_qt_qtwes2";
static const char __pyx_k_qt_qtwogl[] = "_qt_qtwogl";
static const char __pyx_k_qtqes2dos[] = "qtqes2dos";
static const char __pyx_k_qtqogldos[] = "qtqogldos";
static const char __pyx_k_qtwes2dos[] = "qtwes2dos";
static const char __pyx_k_qtwogldos[] = "qtwogldos";
static const char __pyx_k_cb_run_app[] = "cb_run_app";
static const char __pyx_k_excepthook[] = "excepthook";
static const char __pyx_k_glarea_es2[] = "_glarea_es2";
static const char __pyx_k_glarea_ogl[] = "_glarea_ogl";
static const char __pyx_k_gldraw_es2[] = "_gldraw_es2";
static const char __pyx_k_gldraw_ogl[] = "_gldraw_ogl";
static const char __pyx_k_qt_qtqes2d[] = "_qt_qtqes2d";
static const char __pyx_k_qt_qtqogld[] = "_qt_qtqogld";
static const char __pyx_k_qt_qtwes2d[] = "_qt_qtwes2d";
static const char __pyx_k_qt_qtwogld[] = "_qt_qtwogld";
static const char __pyx_k_translator[] = "translator";
static const char __pyx_k_args_buffer[] = "args_buffer";
static const char __pyx_k_argv_buffer[] = "argv_buffer";
static const char __pyx_k_glarea_es2d[] = "_glarea_es2d";
static const char __pyx_k_glarea_ogld[] = "_glarea_ogld";
static const char __pyx_k_gldraw_es2d[] = "_gldraw_es2d";
static const char __pyx_k_gldraw_ogld[] = "_gldraw_ogld";
static const char __pyx_k_qt_qtqes2os[] = "_qt_qtqes2os";
static const char __pyx_k_qt_qtqoglos[] = "_qt_qtqoglos";
static const char __pyx_k_qt_qtwes2os[] = "_qt_qtwes2os";
static const char __pyx_k_qt_qtwoglos[] = "_qt_qtwoglos";
static const char __pyx_k_APPICON_FILE[] = "APPICON_FILE";
static const char __pyx_k_DEBUG_MSGEXT[] = "DEBUG_MSGEXT";
static const char __pyx_k_glarea_es2os[] = "_glarea_es2os";
static const char __pyx_k_glarea_oglos[] = "_glarea_oglos";
static const char __pyx_k_qt_qtqes2dos[] = "_qt_qtqes2dos";
static const char __pyx_k_qt_qtqogldos[] = "_qt_qtqogldos";
static const char __pyx_k_qt_qtwes2dos[] = "_qt_qtwes2dos";
static const char __pyx_k_qt_qtwogldos[] = "_qt_qtwogldos";
static const char __pyx_k_glarea_es2dos[] = "_glarea_es2dos";
static const char __pyx_k_glarea_ogldos[] = "_glarea_ogldos";
static const char __pyx_k_get_gl_variant[] = "get_gl_variant";
static const char __pyx_k_set_debug_flags[] = "set_debug_flags";
static const char __pyx_k_exec_application[] = "exec_application";
static const char __pyx_k_Unknown_arguments[] = "Unknown arguments:";
static const char __pyx_k_cb_after_mainloop[] = "cb_after_mainloop";
static const char __pyx_k_cb_app_post_create[] = "cb_app_post_create";
static const char __pyx_k_cb_before_mainloop[] = "cb_before_mainloop";
static const char __pyx_k_getdefaultencoding[] = "getdefaultencoding";
static const char __pyx_k_Unknown_openGLModuleType[] = "Unknown openGLModuleType";
static const char __pyx_k_tmp[] = "/tmp/build/temp.linux-x86_64-3.5/pybiklib/ext/_qtexec_.pyx";
static PyObject *__pyx_n_s_APPICON_FILE;
static PyObject *__pyx_n_s_APPNAME;
static PyObject *__pyx_n_s_DEBUG_MSG;
static PyObject *__pyx_n_s_DEBUG_MSGEXT;
static PyObject *__pyx_kp_u_P;
static PyObject *__pyx_n_s_PACKAGE;
static PyObject *__pyx_kp_u_Unknown_arguments;
static PyObject *__pyx_kp_u_Unknown_openGLModuleType;
static PyObject *__pyx_n_s_VERSION;
static PyObject *__pyx_kp_u__2;
static PyObject *__pyx_kp_b__3;
static PyObject *__pyx_kp_u__5;
static PyObject *__pyx_n_s_aliases;
static PyObject *__pyx_n_s_app;
static PyObject *__pyx_n_s_arg;
static PyObject *__pyx_n_s_argc;
static PyObject *__pyx_n_s_args_buffer;
static PyObject *__pyx_n_s_argv;
static PyObject *__pyx_n_s_argv_buffer;
static PyObject *__pyx_n_s_byteslist;
static PyObject *__pyx_n_s_cb_after_mainloop;
static PyObject *__pyx_n_s_cb_app_post_create;
static PyObject *__pyx_n_s_cb_before_mainloop;
static PyObject *__pyx_n_s_cb_run_app;
static PyObject *__pyx_n_s_compiled;
static PyObject *__pyx_n_s_config;
static PyObject *__pyx_n_s_config_2;
static PyObject *__pyx_n_u_d;
static PyObject *__pyx_n_u_debug_es2;
static PyObject *__pyx_n_u_debug_ogl;
static PyObject *__pyx_n_s_depends;
static PyObject *__pyx_n_u_dos;
static PyObject *__pyx_n_s_encode;
static PyObject *__pyx_n_u_es2;
static PyObject *__pyx_n_u_es2d;
static PyObject *__pyx_n_u_es2dos;
static PyObject *__pyx_n_u_es2os;
static PyObject *__pyx_n_s_exc_info;
static PyObject *__pyx_n_s_excepthook;
static PyObject *__pyx_n_s_exec_application;
static PyObject *__pyx_n_s_format;
static PyObject *__pyx_n_s_get_gl_variant;
static PyObject *__pyx_n_s_getdefaultencoding;
static PyObject *__pyx_n_u_glarea_es2;
static PyObject *__pyx_n_u_glarea_es2d;
static PyObject *__pyx_n_u_glarea_es2dos;
static PyObject *__pyx_n_u_glarea_es2os;
static PyObject *__pyx_n_u_glarea_ogl;
static PyObject *__pyx_n_u_glarea_ogld;
static PyObject *__pyx_n_u_glarea_ogldos;
static PyObject *__pyx_n_u_glarea_oglos;
static PyObject *__pyx_n_u_gldraw_es2;
static PyObject *__pyx_n_u_gldraw_es2d;
static PyObject *__pyx_n_u_gldraw_ogl;
static PyObject *__pyx_n_u_gldraw_ogld;
static PyObject *__pyx_kp_s_tmp;
static PyObject *__pyx_n_s_i;
static PyObject *__pyx_n_s_import;
static PyObject *__pyx_n_s_join;
static PyObject *__pyx_n_s_language;
static PyObject *__pyx_n_s_main;
static PyObject *__pyx_n_s_main_2;
static PyObject *__pyx_n_s_module;
static PyObject *__pyx_n_u_ogl;
static PyObject *__pyx_n_u_ogld;
static PyObject *__pyx_n_u_ogldos;
static PyObject *__pyx_n_u_oglos;
static PyObject *__pyx_n_s_opts;
static PyObject *__pyx_n_u_os;
static PyObject *__pyx_n_s_pack;
static PyObject *__pyx_n_s_print;
static PyObject *__pyx_n_s_ptr;
static PyObject *__pyx_n_s_ptrlist;
static PyObject *__pyx_n_s_pyapp;
static PyObject *__pyx_n_s_pybiklib;
static PyObject *__pyx_n_s_qargs;
static PyObject *__pyx_n_u_qt;
static PyObject *__pyx_n_u_qt_qtqes2;
static PyObject *__pyx_n_u_qt_qtqes2d;
static PyObject *__pyx_n_u_qt_qtqes2dos;
static PyObject *__pyx_n_u_qt_qtqes2os;
static PyObject *__pyx_n_u_qt_qtqogl;
static PyObject *__pyx_n_u_qt_qtqogld;
static PyObject *__pyx_n_u_qt_qtqogldos;
static PyObject *__pyx_n_u_qt_qtqoglos;
static PyObject *__pyx_n_u_qt_qtwes2;
static PyObject *__pyx_n_u_qt_qtwes2d;
static PyObject *__pyx_n_u_qt_qtwes2dos;
static PyObject *__pyx_n_u_qt_qtwes2os;
static PyObject *__pyx_n_u_qt_qtwogl;
static PyObject *__pyx_n_u_qt_qtwogld;
static PyObject *__pyx_n_u_qt_qtwogldos;
static PyObject *__pyx_n_u_qt_qtwoglos;
static PyObject *__pyx_n_s_qtexec;
static PyObject *__pyx_n_u_qtq;
static PyObject *__pyx_kp_u_qtq_2;
static PyObject *__pyx_kp_u_qtq_d;
static PyObject *__pyx_kp_u_qtq_dos;
static PyObject *__pyx_kp_u_qtq_os;
static PyObject *__pyx_n_u_qtqd;
static PyObject *__pyx_n_u_qtqdos;
static PyObject *__pyx_n_u_qtqes2;
static PyObject *__pyx_n_u_qtqes2d;
static PyObject *__pyx_n_u_qtqes2dos;
static PyObject *__pyx_n_u_qtqes2os;
static PyObject *__pyx_n_u_qtqogl;
static PyObject *__pyx_n_u_qtqogld;
static PyObject *__pyx_n_u_qtqogldos;
static PyObject *__pyx_n_u_qtqoglos;
static PyObject *__pyx_n_u_qtqos;
static PyObject *__pyx_n_u_qtui;
static PyObject *__pyx_kp_u_qtw;
static PyObject *__pyx_n_u_qtw_2;
static PyObject *__pyx_kp_u_qtw_d;
static PyObject *__pyx_kp_u_qtw_dos;
static PyObject *__pyx_kp_u_qtw_os;
static PyObject *__pyx_n_u_qtwd;
static PyObject *__pyx_n_u_qtwdos;
static PyObject *__pyx_n_u_qtwes2;
static PyObject *__pyx_n_u_qtwes2d;
static PyObject *__pyx_n_u_qtwes2dos;
static PyObject *__pyx_n_u_qtwes2os;
static PyObject *__pyx_n_u_qtwogl;
static PyObject *__pyx_n_u_qtwogld;
static PyObject *__pyx_n_u_qtwogldos;
static PyObject *__pyx_n_u_qtwoglos;
static PyObject *__pyx_n_u_qtwos;
static PyObject *__pyx_n_s_range;
static PyObject *__pyx_n_s_set_debug_flags;
static PyObject *__pyx_n_s_struct;
static PyObject *__pyx_n_s_sys;
static PyObject *__pyx_n_s_test;
static PyObject *__pyx_n_s_translator;
static PyObject *__pyx_n_s_ui_args;
static PyObject *__pyx_kp_u_utf_8;
static PyObject *__pyx_pf_8_qtexec__set_debug_flags(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_module); /* proto */
static PyObject *__pyx_pf_8_qtexec__2get_gl_variant(CYTHON_UNUSED PyObject *__pyx_self); /* proto */
static PyObject *__pyx_pf_8_qtexec__4exec_application(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_main); /* proto */
static PyObject *__pyx_int_0;
static PyObject *__pyx_int_1;
static PyObject *__pyx_tuple_;
static PyObject *__pyx_tuple__4;
static PyObject *__pyx_tuple__6;
static PyObject *__pyx_tuple__8;
static PyObject *__pyx_tuple__10;
static PyObject *__pyx_codeobj__7;
static PyObject *__pyx_codeobj__9;
static PyObject *__pyx_codeobj__11;

/* "_qtexec_.pyx":48
 * debug = 0
 * 
 * def set_debug_flags(module):             # <<<<<<<<<<<<<<
 *     global debug
 *     if module.DEBUG_MSG:   debug |= DEBUG_MSG
 */

/* Python wrapper */
static PyObject *__pyx_pw_8_qtexec__1set_debug_flags(PyObject *__pyx_self, PyObject *__pyx_v_module); /*proto*/
static PyMethodDef __pyx_mdef_8_qtexec__1set_debug_flags = {"set_debug_flags", (PyCFunction)__pyx_pw_8_qtexec__1set_debug_flags, METH_O, 0};
static PyObject *__pyx_pw_8_qtexec__1set_debug_flags(PyObject *__pyx_self, PyObject *__pyx_v_module) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("set_debug_flags (wrapper)", 0);
  __pyx_r = __pyx_pf_8_qtexec__set_debug_flags(__pyx_self, ((PyObject *)__pyx_v_module));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_8_qtexec__set_debug_flags(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_module) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  __Pyx_RefNannySetupContext("set_debug_flags", 0);

  /* "_qtexec_.pyx":50
 * def set_debug_flags(module):
 *     global debug
 *     if module.DEBUG_MSG:   debug |= DEBUG_MSG             # <<<<<<<<<<<<<<
 *     if module.DEBUG_MSGEXT: debug |= DEBUG_MSGEXT
 * 
 */
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_module, __pyx_n_s_DEBUG_MSG); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 50, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely(__pyx_t_2 < 0)) __PYX_ERR(0, 50, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (__pyx_t_2) {
    __pyx_v_8_qtexec__debug = (__pyx_v_8_qtexec__debug | __pyx_e_8_qtexec__DEBUG_MSG);
  }

  /* "_qtexec_.pyx":51
 *     global debug
 *     if module.DEBUG_MSG:   debug |= DEBUG_MSG
 *     if module.DEBUG_MSGEXT: debug |= DEBUG_MSGEXT             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_module, __pyx_n_s_DEBUG_MSGEXT); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 51, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely(__pyx_t_2 < 0)) __PYX_ERR(0, 51, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (__pyx_t_2) {
    __pyx_v_8_qtexec__debug = (__pyx_v_8_qtexec__debug | __pyx_e_8_qtexec__DEBUG_MSGEXT);
  }

  /* "_qtexec_.pyx":48
 * debug = 0
 * 
 * def set_debug_flags(module):             # <<<<<<<<<<<<<<
 *     global debug
 *     if module.DEBUG_MSG:   debug |= DEBUG_MSG
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("_qtexec_.set_debug_flags", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "_qtexec_.pyx":57
 * 
 * ##pxm-FUNC P
 * cdef q2str(const QString &qstr):             # <<<<<<<<<<<<<<
 *     cdef QByteArray data = qstr.toUtf8() #px+
 *     return data.data()[:data.size()].decode('utf-8') #px+
 */

static PyObject *__pyx_f_8_qtexec__q2str(QString const &__pyx_v_qstr) {
  QByteArray __pyx_v_data;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  __Pyx_RefNannySetupContext("q2str", 0);

  /* "_qtexec_.pyx":58
 * ##pxm-FUNC P
 * cdef q2str(const QString &qstr):
 *     cdef QByteArray data = qstr.toUtf8() #px+             # <<<<<<<<<<<<<<
 *     return data.data()[:data.size()].decode('utf-8') #px+
 * ##pxm-FUNC P
 */
  __pyx_v_data = __pyx_v_qstr.toUtf8();

  /* "_qtexec_.pyx":59
 * cdef q2str(const QString &qstr):
 *     cdef QByteArray data = qstr.toUtf8() #px+
 *     return data.data()[:data.size()].decode('utf-8') #px+             # <<<<<<<<<<<<<<
 * ##pxm-FUNC P
 * cdef QString str2q(pstr):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_decode_c_string(__pyx_v_data.data(), 0, __pyx_v_data.size(), NULL, NULL, PyUnicode_DecodeUTF8); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 59, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "_qtexec_.pyx":57
 * 
 * ##pxm-FUNC P
 * cdef q2str(const QString &qstr):             # <<<<<<<<<<<<<<
 *     cdef QByteArray data = qstr.toUtf8() #px+
 *     return data.data()[:data.size()].decode('utf-8') #px+
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("_qtexec_.q2str", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "_qtexec_.pyx":61
 *     return data.data()[:data.size()].decode('utf-8') #px+
 * ##pxm-FUNC P
 * cdef QString str2q(pstr):             # <<<<<<<<<<<<<<
 *     data = pstr.encode('utf-8') #px+
 *     return fromUtf8(<char*>data, len(data)) #px+
 */

static QString __pyx_f_8_qtexec__str2q(PyObject *__pyx_v_pstr) {
  PyObject *__pyx_v_data = NULL;
  QString __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  char *__pyx_t_3;
  Py_ssize_t __pyx_t_4;
  __Pyx_RefNannySetupContext("str2q", 0);

  /* "_qtexec_.pyx":62
 * ##pxm-FUNC P
 * cdef QString str2q(pstr):
 *     data = pstr.encode('utf-8') #px+             # <<<<<<<<<<<<<<
 *     return fromUtf8(<char*>data, len(data)) #px+
 * 
 */
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_pstr, __pyx_n_s_encode); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 62, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_tuple_, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 62, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_v_data = __pyx_t_2;
  __pyx_t_2 = 0;

  /* "_qtexec_.pyx":63
 * cdef QString str2q(pstr):
 *     data = pstr.encode('utf-8') #px+
 *     return fromUtf8(<char*>data, len(data)) #px+             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __pyx_t_3 = __Pyx_PyObject_AsString(__pyx_v_data); if (unlikely((!__pyx_t_3) && PyErr_Occurred())) __PYX_ERR(0, 63, __pyx_L1_error)
  __pyx_t_4 = PyObject_Length(__pyx_v_data); if (unlikely(__pyx_t_4 == -1)) __PYX_ERR(0, 63, __pyx_L1_error)
  __pyx_r = QString::fromUtf8(((char *)__pyx_t_3), __pyx_t_4);
  goto __pyx_L0;

  /* "_qtexec_.pyx":61
 *     return data.data()[:data.size()].decode('utf-8') #px+
 * ##pxm-FUNC P
 * cdef QString str2q(pstr):             # <<<<<<<<<<<<<<
 *     data = pstr.encode('utf-8') #px+
 *     return fromUtf8(<char*>data, len(data)) #px+
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_WriteUnraisable("_qtexec_.str2q", __pyx_clineno, __pyx_lineno, __pyx_filename, 0, 0);
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_data);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "_qtexec_.pyx":68
 * #### . ####
 * 
 * def get_gl_variant():             # <<<<<<<<<<<<<<
 *     cdef int i #px+
 *     # This function requires that the app instance is already created
 */

/* Python wrapper */
static PyObject *__pyx_pw_8_qtexec__3get_gl_variant(PyObject *__pyx_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static PyMethodDef __pyx_mdef_8_qtexec__3get_gl_variant = {"get_gl_variant", (PyCFunction)__pyx_pw_8_qtexec__3get_gl_variant, METH_NOARGS, 0};
static PyObject *__pyx_pw_8_qtexec__3get_gl_variant(PyObject *__pyx_self, CYTHON_UNUSED PyObject *unused) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_gl_variant (wrapper)", 0);
  __pyx_r = __pyx_pf_8_qtexec__2get_gl_variant(__pyx_self);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_8_qtexec__2get_gl_variant(CYTHON_UNUSED PyObject *__pyx_self) {
  int __pyx_v_i;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  __Pyx_RefNannySetupContext("get_gl_variant", 0);

  /* "_qtexec_.pyx":71
 *     cdef int i #px+
 *     # This function requires that the app instance is already created
 *     i = openGLModuleType()             # <<<<<<<<<<<<<<
 *     if i == LibGL:
 *         return 'ogl'
 */
  __pyx_v_i = QOpenGLContext::openGLModuleType();

  /* "_qtexec_.pyx":72
 *     # This function requires that the app instance is already created
 *     i = openGLModuleType()
 *     if i == LibGL:             # <<<<<<<<<<<<<<
 *         return 'ogl'
 *     elif i == LibGLES:
 */
  switch (__pyx_v_i) {
    case QOpenGLContext::LibGL:

    /* "_qtexec_.pyx":73
 *     i = openGLModuleType()
 *     if i == LibGL:
 *         return 'ogl'             # <<<<<<<<<<<<<<
 *     elif i == LibGLES:
 *         return 'es2'
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(__pyx_n_u_ogl);
    __pyx_r = __pyx_n_u_ogl;
    goto __pyx_L0;

    /* "_qtexec_.pyx":72
 *     # This function requires that the app instance is already created
 *     i = openGLModuleType()
 *     if i == LibGL:             # <<<<<<<<<<<<<<
 *         return 'ogl'
 *     elif i == LibGLES:
 */
    break;

    /* "_qtexec_.pyx":74
 *     if i == LibGL:
 *         return 'ogl'
 *     elif i == LibGLES:             # <<<<<<<<<<<<<<
 *         return 'es2'
 *     else:
 */
    case QOpenGLContext::LibGLES:

    /* "_qtexec_.pyx":75
 *         return 'ogl'
 *     elif i == LibGLES:
 *         return 'es2'             # <<<<<<<<<<<<<<
 *     else:
 *         print('Unknown openGLModuleType', i)
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(__pyx_n_u_es2);
    __pyx_r = __pyx_n_u_es2;
    goto __pyx_L0;

    /* "_qtexec_.pyx":74
 *     if i == LibGL:
 *         return 'ogl'
 *     elif i == LibGLES:             # <<<<<<<<<<<<<<
 *         return 'es2'
 *     else:
 */
    break;
    default:

    /* "_qtexec_.pyx":77
 *         return 'es2'
 *     else:
 *         print('Unknown openGLModuleType', i)             # <<<<<<<<<<<<<<
 *         return ''
 * 
 */
    __pyx_t_1 = __Pyx_PyInt_From_int(__pyx_v_i); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 77, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_2 = PyTuple_New(2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 77, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_INCREF(__pyx_kp_u_Unknown_openGLModuleType);
    __Pyx_GIVEREF(__pyx_kp_u_Unknown_openGLModuleType);
    PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_kp_u_Unknown_openGLModuleType);
    __Pyx_GIVEREF(__pyx_t_1);
    PyTuple_SET_ITEM(__pyx_t_2, 1, __pyx_t_1);
    __pyx_t_1 = 0;
    __pyx_t_1 = __Pyx_PyObject_Call(__pyx_builtin_print, __pyx_t_2, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 77, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "_qtexec_.pyx":78
 *     else:
 *         print('Unknown openGLModuleType', i)
 *         return ''             # <<<<<<<<<<<<<<
 * 
 * def exec_application(main):
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(__pyx_kp_u__2);
    __pyx_r = __pyx_kp_u__2;
    goto __pyx_L0;
    break;
  }

  /* "_qtexec_.pyx":68
 * #### . ####
 * 
 * def get_gl_variant():             # <<<<<<<<<<<<<<
 *     cdef int i #px+
 *     # This function requires that the app instance is already created
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("_qtexec_.get_gl_variant", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "_qtexec_.pyx":80
 *         return ''
 * 
 * def exec_application(main):             # <<<<<<<<<<<<<<
 *     ##px-
 *     #global app #http://pyqt.sourceforge.net/Docs/PyQt5/gotchas.html#crashes-on-exit
 */

/* Python wrapper */
static PyObject *__pyx_pw_8_qtexec__5exec_application(PyObject *__pyx_self, PyObject *__pyx_v_main); /*proto*/
static PyMethodDef __pyx_mdef_8_qtexec__5exec_application = {"exec_application", (PyCFunction)__pyx_pw_8_qtexec__5exec_application, METH_O, 0};
static PyObject *__pyx_pw_8_qtexec__5exec_application(PyObject *__pyx_self, PyObject *__pyx_v_main) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("exec_application (wrapper)", 0);
  __pyx_r = __pyx_pf_8_qtexec__4exec_application(__pyx_self, ((PyObject *)__pyx_v_main));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_8_qtexec__4exec_application(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_main) {
  PyObject *__pyx_v_byteslist = NULL;
  PyObject *__pyx_v_args_buffer = NULL;
  PyObject *__pyx_v_ptr = NULL;
  PyObject *__pyx_v_ptrlist = NULL;
  PyObject *__pyx_v_arg = NULL;
  PyObject *__pyx_v_struct = NULL;
  PyObject *__pyx_v_argv_buffer = NULL;
  int __pyx_v_argc;
  char **__pyx_v_argv;
  QApplication *__pyx_v_app;
  QStringList __pyx_v_qargs;
  long __pyx_v_i;
  PyObject *__pyx_v_language = NULL;
  QTranslator __pyx_v_translator;
  PyObject *__pyx_v_pyapp = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  Py_ssize_t __pyx_t_7;
  PyObject *(*__pyx_t_8)(PyObject *);
  PyObject *__pyx_t_9 = NULL;
  PyObject *__pyx_t_10 = NULL;
  PyObject *__pyx_t_11 = NULL;
  PyObject *__pyx_t_12 = NULL;
  int __pyx_t_13;
  char *__pyx_t_14;
  int __pyx_t_15;
  Py_ssize_t __pyx_t_16;
  int __pyx_t_17;
  long __pyx_t_18;
  int __pyx_t_19;
  __Pyx_RefNannySetupContext("exec_application", 0);

  /* "_qtexec_.pyx":88
 *     #setAttribute(Qt.AA_UseSoftwareOpenGL)
 * 
 *     try: #px+             # <<<<<<<<<<<<<<
 *         byteslist = [arg.encode(sys.getdefaultencoding()) for arg in main.opts.ui_args] #px+
 *     except Exception: #px+
 */
  {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ExceptionSave(&__pyx_t_1, &__pyx_t_2, &__pyx_t_3);
    __Pyx_XGOTREF(__pyx_t_1);
    __Pyx_XGOTREF(__pyx_t_2);
    __Pyx_XGOTREF(__pyx_t_3);
    /*try:*/ {

      /* "_qtexec_.pyx":89
 * 
 *     try: #px+
 *         byteslist = [arg.encode(sys.getdefaultencoding()) for arg in main.opts.ui_args] #px+             # <<<<<<<<<<<<<<
 *     except Exception: #px+
 *         sys.excepthook(*sys.exc_info()) #px+
 */
      { /* enter inner scope */
        PyObject *__pyx_7genexpr__pyx_v_arg = NULL;
        __pyx_t_4 = PyList_New(0); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 89, __pyx_L13_error)
        __Pyx_GOTREF(__pyx_t_4);
        __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_v_main, __pyx_n_s_opts); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 89, __pyx_L13_error)
        __Pyx_GOTREF(__pyx_t_5);
        __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_n_s_ui_args); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 89, __pyx_L13_error)
        __Pyx_GOTREF(__pyx_t_6);
        __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
        if (likely(PyList_CheckExact(__pyx_t_6)) || PyTuple_CheckExact(__pyx_t_6)) {
          __pyx_t_5 = __pyx_t_6; __Pyx_INCREF(__pyx_t_5); __pyx_t_7 = 0;
          __pyx_t_8 = NULL;
        } else {
          __pyx_t_7 = -1; __pyx_t_5 = PyObject_GetIter(__pyx_t_6); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 89, __pyx_L13_error)
          __Pyx_GOTREF(__pyx_t_5);
          __pyx_t_8 = Py_TYPE(__pyx_t_5)->tp_iternext; if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 89, __pyx_L13_error)
        }
        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
        for (;;) {
          if (likely(!__pyx_t_8)) {
            if (likely(PyList_CheckExact(__pyx_t_5))) {
              if (__pyx_t_7 >= PyList_GET_SIZE(__pyx_t_5)) break;
              #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
              __pyx_t_6 = PyList_GET_ITEM(__pyx_t_5, __pyx_t_7); __Pyx_INCREF(__pyx_t_6); __pyx_t_7++; if (unlikely(0 < 0)) __PYX_ERR(0, 89, __pyx_L13_error)
              #else
              __pyx_t_6 = PySequence_ITEM(__pyx_t_5, __pyx_t_7); __pyx_t_7++; if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 89, __pyx_L13_error)
              __Pyx_GOTREF(__pyx_t_6);
              #endif
            } else {
              if (__pyx_t_7 >= PyTuple_GET_SIZE(__pyx_t_5)) break;
              #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
              __pyx_t_6 = PyTuple_GET_ITEM(__pyx_t_5, __pyx_t_7); __Pyx_INCREF(__pyx_t_6); __pyx_t_7++; if (unlikely(0 < 0)) __PYX_ERR(0, 89, __pyx_L13_error)
              #else
              __pyx_t_6 = PySequence_ITEM(__pyx_t_5, __pyx_t_7); __pyx_t_7++; if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 89, __pyx_L13_error)
              __Pyx_GOTREF(__pyx_t_6);
              #endif
            }
          } else {
            __pyx_t_6 = __pyx_t_8(__pyx_t_5);
            if (unlikely(!__pyx_t_6)) {
              PyObject* exc_type = PyErr_Occurred();
              if (exc_type) {
                if (likely(exc_type == PyExc_StopIteration || PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
                else __PYX_ERR(0, 89, __pyx_L13_error)
              }
              break;
            }
            __Pyx_GOTREF(__pyx_t_6);
          }
          __Pyx_XDECREF_SET(__pyx_7genexpr__pyx_v_arg, __pyx_t_6);
          __pyx_t_6 = 0;
          __pyx_t_9 = __Pyx_PyObject_GetAttrStr(__pyx_7genexpr__pyx_v_arg, __pyx_n_s_encode); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 89, __pyx_L13_error)
          __Pyx_GOTREF(__pyx_t_9);
          __pyx_t_11 = __Pyx_GetModuleGlobalName(__pyx_n_s_sys); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 89, __pyx_L13_error)
          __Pyx_GOTREF(__pyx_t_11);
          __pyx_t_12 = __Pyx_PyObject_GetAttrStr(__pyx_t_11, __pyx_n_s_getdefaultencoding); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 89, __pyx_L13_error)
          __Pyx_GOTREF(__pyx_t_12);
          __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
          __pyx_t_11 = NULL;
          if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_12))) {
            __pyx_t_11 = PyMethod_GET_SELF(__pyx_t_12);
            if (likely(__pyx_t_11)) {
              PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_12);
              __Pyx_INCREF(__pyx_t_11);
              __Pyx_INCREF(function);
              __Pyx_DECREF_SET(__pyx_t_12, function);
            }
          }
          if (__pyx_t_11) {
            __pyx_t_10 = __Pyx_PyObject_CallOneArg(__pyx_t_12, __pyx_t_11); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 89, __pyx_L13_error)
            __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
          } else {
            __pyx_t_10 = __Pyx_PyObject_CallNoArg(__pyx_t_12); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 89, __pyx_L13_error)
          }
          __Pyx_GOTREF(__pyx_t_10);
          __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
          __pyx_t_12 = NULL;
          if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_9))) {
            __pyx_t_12 = PyMethod_GET_SELF(__pyx_t_9);
            if (likely(__pyx_t_12)) {
              PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_9);
              __Pyx_INCREF(__pyx_t_12);
              __Pyx_INCREF(function);
              __Pyx_DECREF_SET(__pyx_t_9, function);
            }
          }
          if (!__pyx_t_12) {
            __pyx_t_6 = __Pyx_PyObject_CallOneArg(__pyx_t_9, __pyx_t_10); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 89, __pyx_L13_error)
            __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
            __Pyx_GOTREF(__pyx_t_6);
          } else {
            #if CYTHON_FAST_PYCALL
            if (PyFunction_Check(__pyx_t_9)) {
              PyObject *__pyx_temp[2] = {__pyx_t_12, __pyx_t_10};
              __pyx_t_6 = __Pyx_PyFunction_FastCall(__pyx_t_9, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 89, __pyx_L13_error)
              __Pyx_XDECREF(__pyx_t_12); __pyx_t_12 = 0;
              __Pyx_GOTREF(__pyx_t_6);
              __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
            } else
            #endif
            #if CYTHON_FAST_PYCCALL
            if (__Pyx_PyFastCFunction_Check(__pyx_t_9)) {
              PyObject *__pyx_temp[2] = {__pyx_t_12, __pyx_t_10};
              __pyx_t_6 = __Pyx_PyCFunction_FastCall(__pyx_t_9, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 89, __pyx_L13_error)
              __Pyx_XDECREF(__pyx_t_12); __pyx_t_12 = 0;
              __Pyx_GOTREF(__pyx_t_6);
              __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
            } else
            #endif
            {
              __pyx_t_11 = PyTuple_New(1+1); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 89, __pyx_L13_error)
              __Pyx_GOTREF(__pyx_t_11);
              __Pyx_GIVEREF(__pyx_t_12); PyTuple_SET_ITEM(__pyx_t_11, 0, __pyx_t_12); __pyx_t_12 = NULL;
              __Pyx_GIVEREF(__pyx_t_10);
              PyTuple_SET_ITEM(__pyx_t_11, 0+1, __pyx_t_10);
              __pyx_t_10 = 0;
              __pyx_t_6 = __Pyx_PyObject_Call(__pyx_t_9, __pyx_t_11, NULL); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 89, __pyx_L13_error)
              __Pyx_GOTREF(__pyx_t_6);
              __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
            }
          }
          __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
          if (unlikely(__Pyx_ListComp_Append(__pyx_t_4, (PyObject*)__pyx_t_6))) __PYX_ERR(0, 89, __pyx_L13_error)
          __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
        }
        __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
        __Pyx_XDECREF(__pyx_7genexpr__pyx_v_arg);
        goto __pyx_L16_exit_scope;
        __pyx_L13_error:;
        __Pyx_XDECREF(__pyx_7genexpr__pyx_v_arg);
        goto __pyx_L3_error;
        __pyx_L16_exit_scope:;
      } /* exit inner scope */
      __pyx_v_byteslist = ((PyObject*)__pyx_t_4);
      __pyx_t_4 = 0;

      /* "_qtexec_.pyx":88
 *     #setAttribute(Qt.AA_UseSoftwareOpenGL)
 * 
 *     try: #px+             # <<<<<<<<<<<<<<
 *         byteslist = [arg.encode(sys.getdefaultencoding()) for arg in main.opts.ui_args] #px+
 *     except Exception: #px+
 */
    }
    __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    goto __pyx_L10_try_end;
    __pyx_L3_error:;
    __Pyx_PyThreadState_assign
    __Pyx_XDECREF(__pyx_t_12); __pyx_t_12 = 0;
    __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
    __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
    __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
    __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;

    /* "_qtexec_.pyx":90
 *     try: #px+
 *         byteslist = [arg.encode(sys.getdefaultencoding()) for arg in main.opts.ui_args] #px+
 *     except Exception: #px+             # <<<<<<<<<<<<<<
 *         sys.excepthook(*sys.exc_info()) #px+
 *         byteslist = [] #px+
 */
    __pyx_t_13 = __Pyx_PyErr_ExceptionMatches(((PyObject *)(&((PyTypeObject*)PyExc_Exception)[0])));
    if (__pyx_t_13) {
      __Pyx_AddTraceback("_qtexec_.exec_application", __pyx_clineno, __pyx_lineno, __pyx_filename);
      if (__Pyx_GetException(&__pyx_t_4, &__pyx_t_5, &__pyx_t_6) < 0) __PYX_ERR(0, 90, __pyx_L5_except_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_GOTREF(__pyx_t_6);

      /* "_qtexec_.pyx":91
 *         byteslist = [arg.encode(sys.getdefaultencoding()) for arg in main.opts.ui_args] #px+
 *     except Exception: #px+
 *         sys.excepthook(*sys.exc_info()) #px+             # <<<<<<<<<<<<<<
 *         byteslist = [] #px+
 *     args_buffer = b'\0'.join(byteslist) + b'\0' #px+
 */
      __pyx_t_9 = __Pyx_GetModuleGlobalName(__pyx_n_s_sys); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 91, __pyx_L5_except_error)
      __Pyx_GOTREF(__pyx_t_9);
      __pyx_t_11 = __Pyx_PyObject_GetAttrStr(__pyx_t_9, __pyx_n_s_excepthook); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 91, __pyx_L5_except_error)
      __Pyx_GOTREF(__pyx_t_11);
      __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
      __pyx_t_10 = __Pyx_GetModuleGlobalName(__pyx_n_s_sys); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 91, __pyx_L5_except_error)
      __Pyx_GOTREF(__pyx_t_10);
      __pyx_t_12 = __Pyx_PyObject_GetAttrStr(__pyx_t_10, __pyx_n_s_exc_info); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 91, __pyx_L5_except_error)
      __Pyx_GOTREF(__pyx_t_12);
      __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
      __pyx_t_10 = NULL;
      if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_12))) {
        __pyx_t_10 = PyMethod_GET_SELF(__pyx_t_12);
        if (likely(__pyx_t_10)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_12);
          __Pyx_INCREF(__pyx_t_10);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_12, function);
        }
      }
      if (__pyx_t_10) {
        __pyx_t_9 = __Pyx_PyObject_CallOneArg(__pyx_t_12, __pyx_t_10); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 91, __pyx_L5_except_error)
        __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
      } else {
        __pyx_t_9 = __Pyx_PyObject_CallNoArg(__pyx_t_12); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 91, __pyx_L5_except_error)
      }
      __Pyx_GOTREF(__pyx_t_9);
      __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
      __pyx_t_12 = PySequence_Tuple(__pyx_t_9); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 91, __pyx_L5_except_error)
      __Pyx_GOTREF(__pyx_t_12);
      __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
      __pyx_t_9 = __Pyx_PyObject_Call(__pyx_t_11, __pyx_t_12, NULL); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 91, __pyx_L5_except_error)
      __Pyx_GOTREF(__pyx_t_9);
      __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
      __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
      __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;

      /* "_qtexec_.pyx":92
 *     except Exception: #px+
 *         sys.excepthook(*sys.exc_info()) #px+
 *         byteslist = [] #px+             # <<<<<<<<<<<<<<
 *     args_buffer = b'\0'.join(byteslist) + b'\0' #px+
 * 
 */
      __pyx_t_9 = PyList_New(0); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 92, __pyx_L5_except_error)
      __Pyx_GOTREF(__pyx_t_9);
      __Pyx_XDECREF_SET(__pyx_v_byteslist, ((PyObject*)__pyx_t_9));
      __pyx_t_9 = 0;
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      goto __pyx_L4_exception_handled;
    }
    goto __pyx_L5_except_error;
    __pyx_L5_except_error:;

    /* "_qtexec_.pyx":88
 *     #setAttribute(Qt.AA_UseSoftwareOpenGL)
 * 
 *     try: #px+             # <<<<<<<<<<<<<<
 *         byteslist = [arg.encode(sys.getdefaultencoding()) for arg in main.opts.ui_args] #px+
 *     except Exception: #px+
 */
    __Pyx_PyThreadState_assign
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L1_error;
    __pyx_L4_exception_handled:;
    __Pyx_PyThreadState_assign
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    __pyx_L10_try_end:;
  }

  /* "_qtexec_.pyx":93
 *         sys.excepthook(*sys.exc_info()) #px+
 *         byteslist = [] #px+
 *     args_buffer = b'\0'.join(byteslist) + b'\0' #px+             # <<<<<<<<<<<<<<
 * 
 *     ptr = int(<size_t><void*><char*>args_buffer) #px+
 */
  __pyx_t_6 = __Pyx_PyBytes_Join(__pyx_kp_b__3, __pyx_v_byteslist); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 93, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __pyx_t_5 = PyNumber_Add(__pyx_t_6, __pyx_kp_b__3); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 93, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __pyx_v_args_buffer = __pyx_t_5;
  __pyx_t_5 = 0;

  /* "_qtexec_.pyx":95
 *     args_buffer = b'\0'.join(byteslist) + b'\0' #px+
 * 
 *     ptr = int(<size_t><void*><char*>args_buffer) #px+             # <<<<<<<<<<<<<<
 *     ptrlist = [] #px+
 *     for arg in byteslist: #px+
 */
  __pyx_t_14 = __Pyx_PyObject_AsString(__pyx_v_args_buffer); if (unlikely((!__pyx_t_14) && PyErr_Occurred())) __PYX_ERR(0, 95, __pyx_L1_error)
  __pyx_t_5 = __Pyx_PyInt_FromSize_t(((size_t)((void *)((char *)__pyx_t_14)))); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 95, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_6 = PyTuple_New(1); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 95, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_GIVEREF(__pyx_t_5);
  PyTuple_SET_ITEM(__pyx_t_6, 0, __pyx_t_5);
  __pyx_t_5 = 0;
  __pyx_t_5 = __Pyx_PyObject_Call(((PyObject *)(&PyInt_Type)), __pyx_t_6, NULL); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 95, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __pyx_v_ptr = __pyx_t_5;
  __pyx_t_5 = 0;

  /* "_qtexec_.pyx":96
 * 
 *     ptr = int(<size_t><void*><char*>args_buffer) #px+
 *     ptrlist = [] #px+             # <<<<<<<<<<<<<<
 *     for arg in byteslist: #px+
 *         ptrlist.append(ptr) #px+
 */
  __pyx_t_5 = PyList_New(0); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 96, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_v_ptrlist = ((PyObject*)__pyx_t_5);
  __pyx_t_5 = 0;

  /* "_qtexec_.pyx":97
 *     ptr = int(<size_t><void*><char*>args_buffer) #px+
 *     ptrlist = [] #px+
 *     for arg in byteslist: #px+             # <<<<<<<<<<<<<<
 *         ptrlist.append(ptr) #px+
 *         ptr += len(arg)+1 #px+
 */
  __pyx_t_5 = __pyx_v_byteslist; __Pyx_INCREF(__pyx_t_5); __pyx_t_7 = 0;
  for (;;) {
    if (__pyx_t_7 >= PyList_GET_SIZE(__pyx_t_5)) break;
    #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
    __pyx_t_6 = PyList_GET_ITEM(__pyx_t_5, __pyx_t_7); __Pyx_INCREF(__pyx_t_6); __pyx_t_7++; if (unlikely(0 < 0)) __PYX_ERR(0, 97, __pyx_L1_error)
    #else
    __pyx_t_6 = PySequence_ITEM(__pyx_t_5, __pyx_t_7); __pyx_t_7++; if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 97, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    #endif
    __Pyx_XDECREF_SET(__pyx_v_arg, __pyx_t_6);
    __pyx_t_6 = 0;

    /* "_qtexec_.pyx":98
 *     ptrlist = [] #px+
 *     for arg in byteslist: #px+
 *         ptrlist.append(ptr) #px+             # <<<<<<<<<<<<<<
 *         ptr += len(arg)+1 #px+
 *     ptrlist.append(0) #px+
 */
    __pyx_t_15 = __Pyx_PyList_Append(__pyx_v_ptrlist, __pyx_v_ptr); if (unlikely(__pyx_t_15 == -1)) __PYX_ERR(0, 98, __pyx_L1_error)

    /* "_qtexec_.pyx":99
 *     for arg in byteslist: #px+
 *         ptrlist.append(ptr) #px+
 *         ptr += len(arg)+1 #px+             # <<<<<<<<<<<<<<
 *     ptrlist.append(0) #px+
 * 
 */
    __pyx_t_16 = PyObject_Length(__pyx_v_arg); if (unlikely(__pyx_t_16 == -1)) __PYX_ERR(0, 99, __pyx_L1_error)
    __pyx_t_6 = PyInt_FromSsize_t((__pyx_t_16 + 1)); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 99, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __pyx_t_4 = PyNumber_InPlaceAdd(__pyx_v_ptr, __pyx_t_6); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 99, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_DECREF_SET(__pyx_v_ptr, __pyx_t_4);
    __pyx_t_4 = 0;

    /* "_qtexec_.pyx":97
 *     ptr = int(<size_t><void*><char*>args_buffer) #px+
 *     ptrlist = [] #px+
 *     for arg in byteslist: #px+             # <<<<<<<<<<<<<<
 *         ptrlist.append(ptr) #px+
 *         ptr += len(arg)+1 #px+
 */
  }
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "_qtexec_.pyx":100
 *         ptrlist.append(ptr) #px+
 *         ptr += len(arg)+1 #px+
 *     ptrlist.append(0) #px+             # <<<<<<<<<<<<<<
 * 
 *     import struct #px+
 */
  __pyx_t_15 = __Pyx_PyList_Append(__pyx_v_ptrlist, __pyx_int_0); if (unlikely(__pyx_t_15 == -1)) __PYX_ERR(0, 100, __pyx_L1_error)

  /* "_qtexec_.pyx":102
 *     ptrlist.append(0) #px+
 * 
 *     import struct #px+             # <<<<<<<<<<<<<<
 *     argv_buffer = struct.pack('{}P'.format(len(ptrlist)), *ptrlist) #px+
 *     cdef int argc = len(byteslist) #px+
 */
  __pyx_t_5 = __Pyx_Import(__pyx_n_s_struct, 0, 0); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 102, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_v_struct = __pyx_t_5;
  __pyx_t_5 = 0;

  /* "_qtexec_.pyx":103
 * 
 *     import struct #px+
 *     argv_buffer = struct.pack('{}P'.format(len(ptrlist)), *ptrlist) #px+             # <<<<<<<<<<<<<<
 *     cdef int argc = len(byteslist) #px+
 *     cdef char **argv = <char**><void*><char*>argv_buffer #px+
 */
  __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_v_struct, __pyx_n_s_pack); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 103, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_kp_u_P, __pyx_n_s_format); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 103, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __pyx_t_7 = PyList_GET_SIZE(__pyx_v_ptrlist); if (unlikely(__pyx_t_7 == -1)) __PYX_ERR(0, 103, __pyx_L1_error)
  __pyx_t_9 = PyInt_FromSsize_t(__pyx_t_7); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 103, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  __pyx_t_12 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_6))) {
    __pyx_t_12 = PyMethod_GET_SELF(__pyx_t_6);
    if (likely(__pyx_t_12)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_6);
      __Pyx_INCREF(__pyx_t_12);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_6, function);
    }
  }
  if (!__pyx_t_12) {
    __pyx_t_4 = __Pyx_PyObject_CallOneArg(__pyx_t_6, __pyx_t_9); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 103, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
    __Pyx_GOTREF(__pyx_t_4);
  } else {
    #if CYTHON_FAST_PYCALL
    if (PyFunction_Check(__pyx_t_6)) {
      PyObject *__pyx_temp[2] = {__pyx_t_12, __pyx_t_9};
      __pyx_t_4 = __Pyx_PyFunction_FastCall(__pyx_t_6, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 103, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_12); __pyx_t_12 = 0;
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
    } else
    #endif
    #if CYTHON_FAST_PYCCALL
    if (__Pyx_PyFastCFunction_Check(__pyx_t_6)) {
      PyObject *__pyx_temp[2] = {__pyx_t_12, __pyx_t_9};
      __pyx_t_4 = __Pyx_PyCFunction_FastCall(__pyx_t_6, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 103, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_12); __pyx_t_12 = 0;
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
    } else
    #endif
    {
      __pyx_t_11 = PyTuple_New(1+1); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 103, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_11);
      __Pyx_GIVEREF(__pyx_t_12); PyTuple_SET_ITEM(__pyx_t_11, 0, __pyx_t_12); __pyx_t_12 = NULL;
      __Pyx_GIVEREF(__pyx_t_9);
      PyTuple_SET_ITEM(__pyx_t_11, 0+1, __pyx_t_9);
      __pyx_t_9 = 0;
      __pyx_t_4 = __Pyx_PyObject_Call(__pyx_t_6, __pyx_t_11, NULL); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 103, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
    }
  }
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __pyx_t_6 = PyTuple_New(1); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 103, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_GIVEREF(__pyx_t_4);
  PyTuple_SET_ITEM(__pyx_t_6, 0, __pyx_t_4);
  __pyx_t_4 = 0;
  __pyx_t_4 = PySequence_Tuple(__pyx_v_ptrlist); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 103, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_11 = PyNumber_Add(__pyx_t_6, __pyx_t_4); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 103, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_11);
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_4 = __Pyx_PyObject_Call(__pyx_t_5, __pyx_t_11, NULL); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 103, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
  __pyx_v_argv_buffer = __pyx_t_4;
  __pyx_t_4 = 0;

  /* "_qtexec_.pyx":104
 *     import struct #px+
 *     argv_buffer = struct.pack('{}P'.format(len(ptrlist)), *ptrlist) #px+
 *     cdef int argc = len(byteslist) #px+             # <<<<<<<<<<<<<<
 *     cdef char **argv = <char**><void*><char*>argv_buffer #px+
 *     cdef QApplication *app = new QApplication(argc, argv) #px/
 */
  __pyx_t_7 = PyList_GET_SIZE(__pyx_v_byteslist); if (unlikely(__pyx_t_7 == -1)) __PYX_ERR(0, 104, __pyx_L1_error)
  __pyx_v_argc = __pyx_t_7;

  /* "_qtexec_.pyx":105
 *     argv_buffer = struct.pack('{}P'.format(len(ptrlist)), *ptrlist) #px+
 *     cdef int argc = len(byteslist) #px+
 *     cdef char **argv = <char**><void*><char*>argv_buffer #px+             # <<<<<<<<<<<<<<
 *     cdef QApplication *app = new QApplication(argc, argv) #px/
 *     #app = QApplication(main.opts.ui_args)
 */
  __pyx_t_14 = __Pyx_PyObject_AsString(__pyx_v_argv_buffer); if (unlikely((!__pyx_t_14) && PyErr_Occurred())) __PYX_ERR(0, 105, __pyx_L1_error)
  __pyx_v_argv = ((char **)((void *)((char *)__pyx_t_14)));

  /* "_qtexec_.pyx":106
 *     cdef int argc = len(byteslist) #px+
 *     cdef char **argv = <char**><void*><char*>argv_buffer #px+
 *     cdef QApplication *app = new QApplication(argc, argv) #px/             # <<<<<<<<<<<<<<
 *     #app = QApplication(main.opts.ui_args)
 * 
 */
  __pyx_v_app = new QApplication(__pyx_v_argc, __pyx_v_argv);

  /* "_qtexec_.pyx":109
 *     #app = QApplication(main.opts.ui_args)
 * 
 *     qargs = app.arguments()             # <<<<<<<<<<<<<<
 *     if qargs.size() > 1: #px/
 *     #if len(qargs) > 1:
 */
  __pyx_v_qargs = __pyx_v_app->arguments();

  /* "_qtexec_.pyx":110
 * 
 *     qargs = app.arguments()
 *     if qargs.size() > 1: #px/             # <<<<<<<<<<<<<<
 *     #if len(qargs) > 1:
 *         print('Unknown arguments:')
 */
  __pyx_t_17 = ((__pyx_v_qargs.size() > 1) != 0);
  if (__pyx_t_17) {

    /* "_qtexec_.pyx":112
 *     if qargs.size() > 1: #px/
 *     #if len(qargs) > 1:
 *         print('Unknown arguments:')             # <<<<<<<<<<<<<<
 *         for i in range(1, qargs.size()): #px/
 *         #for i in range(1, len(qargs)):
 */
    __pyx_t_4 = __Pyx_PyObject_Call(__pyx_builtin_print, __pyx_tuple__4, NULL); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 112, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

    /* "_qtexec_.pyx":113
 *     #if len(qargs) > 1:
 *         print('Unknown arguments:')
 *         for i in range(1, qargs.size()): #px/             # <<<<<<<<<<<<<<
 *         #for i in range(1, len(qargs)):
 *             print(' ', q2str(qargs[i]))
 */
    __pyx_t_13 = __pyx_v_qargs.size();
    for (__pyx_t_18 = 1; __pyx_t_18 < __pyx_t_13; __pyx_t_18+=1) {
      __pyx_v_i = __pyx_t_18;

      /* "_qtexec_.pyx":115
 *         for i in range(1, qargs.size()): #px/
 *         #for i in range(1, len(qargs)):
 *             print(' ', q2str(qargs[i]))             # <<<<<<<<<<<<<<
 *         return 1
 * 
 */
      __pyx_t_4 = __pyx_f_8_qtexec__q2str((__pyx_v_qargs[__pyx_v_i])); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 115, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_11 = PyTuple_New(2); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 115, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_11);
      __Pyx_INCREF(__pyx_kp_u__5);
      __Pyx_GIVEREF(__pyx_kp_u__5);
      PyTuple_SET_ITEM(__pyx_t_11, 0, __pyx_kp_u__5);
      __Pyx_GIVEREF(__pyx_t_4);
      PyTuple_SET_ITEM(__pyx_t_11, 1, __pyx_t_4);
      __pyx_t_4 = 0;
      __pyx_t_4 = __Pyx_PyObject_Call(__pyx_builtin_print, __pyx_t_11, NULL); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 115, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    }

    /* "_qtexec_.pyx":116
 *         #for i in range(1, len(qargs)):
 *             print(' ', q2str(qargs[i]))
 *         return 1             # <<<<<<<<<<<<<<
 * 
 *     app.setOrganizationName(str2q(config_.PACKAGE))
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(__pyx_int_1);
    __pyx_r = __pyx_int_1;
    goto __pyx_L0;

    /* "_qtexec_.pyx":110
 * 
 *     qargs = app.arguments()
 *     if qargs.size() > 1: #px/             # <<<<<<<<<<<<<<
 *     #if len(qargs) > 1:
 *         print('Unknown arguments:')
 */
  }

  /* "_qtexec_.pyx":118
 *         return 1
 * 
 *     app.setOrganizationName(str2q(config_.PACKAGE))             # <<<<<<<<<<<<<<
 *     app.setApplicationName(str2q(config_.APPNAME))
 *     app.setApplicationVersion(str2q(config_.VERSION))
 */
  __pyx_t_4 = __Pyx_GetModuleGlobalName(__pyx_n_s_config); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 118, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_11 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_n_s_PACKAGE); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 118, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_11);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_v_app->setOrganizationName(__pyx_f_8_qtexec__str2q(__pyx_t_11));
  __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;

  /* "_qtexec_.pyx":119
 * 
 *     app.setOrganizationName(str2q(config_.PACKAGE))
 *     app.setApplicationName(str2q(config_.APPNAME))             # <<<<<<<<<<<<<<
 *     app.setApplicationVersion(str2q(config_.VERSION))
 *     app.setWindowIcon(QIcon(str2q(config_.APPICON_FILE)))
 */
  __pyx_t_11 = __Pyx_GetModuleGlobalName(__pyx_n_s_config); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 119, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_11);
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_t_11, __pyx_n_s_APPNAME); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 119, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
  __pyx_v_app->setApplicationName(__pyx_f_8_qtexec__str2q(__pyx_t_4));
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "_qtexec_.pyx":120
 *     app.setOrganizationName(str2q(config_.PACKAGE))
 *     app.setApplicationName(str2q(config_.APPNAME))
 *     app.setApplicationVersion(str2q(config_.VERSION))             # <<<<<<<<<<<<<<
 *     app.setWindowIcon(QIcon(str2q(config_.APPICON_FILE)))
 * 
 */
  __pyx_t_4 = __Pyx_GetModuleGlobalName(__pyx_n_s_config); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 120, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_11 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_n_s_VERSION); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 120, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_11);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_v_app->setApplicationVersion(__pyx_f_8_qtexec__str2q(__pyx_t_11));
  __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;

  /* "_qtexec_.pyx":121
 *     app.setApplicationName(str2q(config_.APPNAME))
 *     app.setApplicationVersion(str2q(config_.VERSION))
 *     app.setWindowIcon(QIcon(str2q(config_.APPICON_FILE)))             # <<<<<<<<<<<<<<
 * 
 *     # initialize translation
 */
  __pyx_t_11 = __Pyx_GetModuleGlobalName(__pyx_n_s_config); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 121, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_11);
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_t_11, __pyx_n_s_APPICON_FILE); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 121, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
  __pyx_v_app->setWindowIcon(QIcon(__pyx_f_8_qtexec__str2q(__pyx_t_4)));
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "_qtexec_.pyx":124
 * 
 *     # initialize translation
 *     language = q2str(QLocale_system().name())             # <<<<<<<<<<<<<<
 *     # standard Qt translation, used for e.g. standard buttons and shortcut names
 *     # keep the translator object for the lifetime of the app object, so that the translation works
 */
  __pyx_t_4 = __pyx_f_8_qtexec__q2str(QLocale::system().name()); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 124, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_v_language = __pyx_t_4;
  __pyx_t_4 = 0;

  /* "_qtexec_.pyx":129
 *     cdef QTranslator translator #px/
 *     #translator = QTranslator()
 *     translator.load(str2q("qt_" + language), location(TranslationsPath))             # <<<<<<<<<<<<<<
 *     app.installTranslator(&translator) #px/
 *     #app.installTranslator(translator)
 */
  __pyx_t_4 = PyNumber_Add(__pyx_n_u_qt, __pyx_v_language); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 129, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_v_translator.load(__pyx_f_8_qtexec__str2q(__pyx_t_4), QLibraryInfo::location(QLibraryInfo::TranslationsPath));
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "_qtexec_.pyx":130
 *     #translator = QTranslator()
 *     translator.load(str2q("qt_" + language), location(TranslationsPath))
 *     app.installTranslator(&translator) #px/             # <<<<<<<<<<<<<<
 *     #app.installTranslator(translator)
 *     main.cb_app_post_create(language)
 */
  __pyx_v_app->installTranslator((&__pyx_v_translator));

  /* "_qtexec_.pyx":132
 *     app.installTranslator(&translator) #px/
 *     #app.installTranslator(translator)
 *     main.cb_app_post_create(language)             # <<<<<<<<<<<<<<
 * 
 *     #XXX: needed for threaded rendering, prevents blocking on quit
 */
  __pyx_t_11 = __Pyx_PyObject_GetAttrStr(__pyx_v_main, __pyx_n_s_cb_app_post_create); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 132, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_11);
  __pyx_t_5 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_11))) {
    __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_11);
    if (likely(__pyx_t_5)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_11);
      __Pyx_INCREF(__pyx_t_5);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_11, function);
    }
  }
  if (!__pyx_t_5) {
    __pyx_t_4 = __Pyx_PyObject_CallOneArg(__pyx_t_11, __pyx_v_language); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 132, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
  } else {
    #if CYTHON_FAST_PYCALL
    if (PyFunction_Check(__pyx_t_11)) {
      PyObject *__pyx_temp[2] = {__pyx_t_5, __pyx_v_language};
      __pyx_t_4 = __Pyx_PyFunction_FastCall(__pyx_t_11, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 132, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_GOTREF(__pyx_t_4);
    } else
    #endif
    #if CYTHON_FAST_PYCCALL
    if (__Pyx_PyFastCFunction_Check(__pyx_t_11)) {
      PyObject *__pyx_temp[2] = {__pyx_t_5, __pyx_v_language};
      __pyx_t_4 = __Pyx_PyCFunction_FastCall(__pyx_t_11, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 132, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_GOTREF(__pyx_t_4);
    } else
    #endif
    {
      __pyx_t_6 = PyTuple_New(1+1); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 132, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_GIVEREF(__pyx_t_5); PyTuple_SET_ITEM(__pyx_t_6, 0, __pyx_t_5); __pyx_t_5 = NULL;
      __Pyx_INCREF(__pyx_v_language);
      __Pyx_GIVEREF(__pyx_v_language);
      PyTuple_SET_ITEM(__pyx_t_6, 0+1, __pyx_v_language);
      __pyx_t_4 = __Pyx_PyObject_Call(__pyx_t_11, __pyx_t_6, NULL); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 132, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    }
  }
  __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "_qtexec_.pyx":135
 * 
 *     #XXX: needed for threaded rendering, prevents blocking on quit
 *     connect(app, &aboutToQuit, app, &sync, Qt.DirectConnection) #px/             # <<<<<<<<<<<<<<
 *     #app.aboutToQuit.connect(app.sync, type=Qt.DirectConnection)
 * 
 */
  QObject::connect(__pyx_v_app, (&QApplication::aboutToQuit), __pyx_v_app, (&QApplication::sync), Qt::DirectConnection);

  /* "_qtexec_.pyx":138
 *     #app.aboutToQuit.connect(app.sync, type=Qt.DirectConnection)
 * 
 *     while True:             # <<<<<<<<<<<<<<
 *         pyapp = main.cb_run_app()
 *         if pyapp is None:
 */
  while (1) {

    /* "_qtexec_.pyx":139
 * 
 *     while True:
 *         pyapp = main.cb_run_app()             # <<<<<<<<<<<<<<
 *         if pyapp is None:
 *             break
 */
    __pyx_t_11 = __Pyx_PyObject_GetAttrStr(__pyx_v_main, __pyx_n_s_cb_run_app); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 139, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_11);
    __pyx_t_6 = NULL;
    if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_11))) {
      __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_11);
      if (likely(__pyx_t_6)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_11);
        __Pyx_INCREF(__pyx_t_6);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_11, function);
      }
    }
    if (__pyx_t_6) {
      __pyx_t_4 = __Pyx_PyObject_CallOneArg(__pyx_t_11, __pyx_t_6); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 139, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    } else {
      __pyx_t_4 = __Pyx_PyObject_CallNoArg(__pyx_t_11); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 139, __pyx_L1_error)
    }
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
    __Pyx_XDECREF_SET(__pyx_v_pyapp, __pyx_t_4);
    __pyx_t_4 = 0;

    /* "_qtexec_.pyx":140
 *     while True:
 *         pyapp = main.cb_run_app()
 *         if pyapp is None:             # <<<<<<<<<<<<<<
 *             break
 *         pyapp.cb_before_mainloop()
 */
    __pyx_t_17 = (__pyx_v_pyapp == Py_None);
    __pyx_t_19 = (__pyx_t_17 != 0);
    if (__pyx_t_19) {

      /* "_qtexec_.pyx":141
 *         pyapp = main.cb_run_app()
 *         if pyapp is None:
 *             break             # <<<<<<<<<<<<<<
 *         pyapp.cb_before_mainloop()
 *         app.exec()
 */
      goto __pyx_L25_break;

      /* "_qtexec_.pyx":140
 *     while True:
 *         pyapp = main.cb_run_app()
 *         if pyapp is None:             # <<<<<<<<<<<<<<
 *             break
 *         pyapp.cb_before_mainloop()
 */
    }

    /* "_qtexec_.pyx":142
 *         if pyapp is None:
 *             break
 *         pyapp.cb_before_mainloop()             # <<<<<<<<<<<<<<
 *         app.exec()
 *         pyapp.cb_after_mainloop()
 */
    __pyx_t_11 = __Pyx_PyObject_GetAttrStr(__pyx_v_pyapp, __pyx_n_s_cb_before_mainloop); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 142, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_11);
    __pyx_t_6 = NULL;
    if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_11))) {
      __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_11);
      if (likely(__pyx_t_6)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_11);
        __Pyx_INCREF(__pyx_t_6);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_11, function);
      }
    }
    if (__pyx_t_6) {
      __pyx_t_4 = __Pyx_PyObject_CallOneArg(__pyx_t_11, __pyx_t_6); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 142, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    } else {
      __pyx_t_4 = __Pyx_PyObject_CallNoArg(__pyx_t_11); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 142, __pyx_L1_error)
    }
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

    /* "_qtexec_.pyx":143
 *             break
 *         pyapp.cb_before_mainloop()
 *         app.exec()             # <<<<<<<<<<<<<<
 *         pyapp.cb_after_mainloop()
 *     del app
 */
    __pyx_v_app->exec();

    /* "_qtexec_.pyx":144
 *         pyapp.cb_before_mainloop()
 *         app.exec()
 *         pyapp.cb_after_mainloop()             # <<<<<<<<<<<<<<
 *     del app
 * 
 */
    __pyx_t_11 = __Pyx_PyObject_GetAttrStr(__pyx_v_pyapp, __pyx_n_s_cb_after_mainloop); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 144, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_11);
    __pyx_t_6 = NULL;
    if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_11))) {
      __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_11);
      if (likely(__pyx_t_6)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_11);
        __Pyx_INCREF(__pyx_t_6);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_11, function);
      }
    }
    if (__pyx_t_6) {
      __pyx_t_4 = __Pyx_PyObject_CallOneArg(__pyx_t_11, __pyx_t_6); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 144, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    } else {
      __pyx_t_4 = __Pyx_PyObject_CallNoArg(__pyx_t_11); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 144, __pyx_L1_error)
    }
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  }
  __pyx_L25_break:;

  /* "_qtexec_.pyx":145
 *         app.exec()
 *         pyapp.cb_after_mainloop()
 *     del app             # <<<<<<<<<<<<<<
 * 
 * depends = { #px+
 */
  delete __pyx_v_app;

  /* "_qtexec_.pyx":80
 *         return ''
 * 
 * def exec_application(main):             # <<<<<<<<<<<<<<
 *     ##px-
 *     #global app #http://pyqt.sourceforge.net/Docs/PyQt5/gotchas.html#crashes-on-exit
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_XDECREF(__pyx_t_10);
  __Pyx_XDECREF(__pyx_t_11);
  __Pyx_XDECREF(__pyx_t_12);
  __Pyx_AddTraceback("_qtexec_.exec_application", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_byteslist);
  __Pyx_XDECREF(__pyx_v_args_buffer);
  __Pyx_XDECREF(__pyx_v_ptr);
  __Pyx_XDECREF(__pyx_v_ptrlist);
  __Pyx_XDECREF(__pyx_v_arg);
  __Pyx_XDECREF(__pyx_v_struct);
  __Pyx_XDECREF(__pyx_v_argv_buffer);
  __Pyx_XDECREF(__pyx_v_language);
  __Pyx_XDECREF(__pyx_v_pyapp);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyMethodDef __pyx_methods[] = {
  {0, 0, 0, 0}
};

#if PY_MAJOR_VERSION >= 3
static struct PyModuleDef __pyx_moduledef = {
  #if PY_VERSION_HEX < 0x03020000
    { PyObject_HEAD_INIT(NULL) NULL, 0, NULL },
  #else
    PyModuleDef_HEAD_INIT,
  #endif
    "_qtexec_",
    0, /* m_doc */
    -1, /* m_size */
    __pyx_methods /* m_methods */,
    NULL, /* m_reload */
    NULL, /* m_traverse */
    NULL, /* m_clear */
    NULL /* m_free */
};
#endif

static __Pyx_StringTabEntry __pyx_string_tab[] = {
  {&__pyx_n_s_APPICON_FILE, __pyx_k_APPICON_FILE, sizeof(__pyx_k_APPICON_FILE), 0, 0, 1, 1},
  {&__pyx_n_s_APPNAME, __pyx_k_APPNAME, sizeof(__pyx_k_APPNAME), 0, 0, 1, 1},
  {&__pyx_n_s_DEBUG_MSG, __pyx_k_DEBUG_MSG, sizeof(__pyx_k_DEBUG_MSG), 0, 0, 1, 1},
  {&__pyx_n_s_DEBUG_MSGEXT, __pyx_k_DEBUG_MSGEXT, sizeof(__pyx_k_DEBUG_MSGEXT), 0, 0, 1, 1},
  {&__pyx_kp_u_P, __pyx_k_P, sizeof(__pyx_k_P), 0, 1, 0, 0},
  {&__pyx_n_s_PACKAGE, __pyx_k_PACKAGE, sizeof(__pyx_k_PACKAGE), 0, 0, 1, 1},
  {&__pyx_kp_u_Unknown_arguments, __pyx_k_Unknown_arguments, sizeof(__pyx_k_Unknown_arguments), 0, 1, 0, 0},
  {&__pyx_kp_u_Unknown_openGLModuleType, __pyx_k_Unknown_openGLModuleType, sizeof(__pyx_k_Unknown_openGLModuleType), 0, 1, 0, 0},
  {&__pyx_n_s_VERSION, __pyx_k_VERSION, sizeof(__pyx_k_VERSION), 0, 0, 1, 1},
  {&__pyx_kp_u__2, __pyx_k__2, sizeof(__pyx_k__2), 0, 1, 0, 0},
  {&__pyx_kp_b__3, __pyx_k__3, sizeof(__pyx_k__3), 0, 0, 0, 0},
  {&__pyx_kp_u__5, __pyx_k__5, sizeof(__pyx_k__5), 0, 1, 0, 0},
  {&__pyx_n_s_aliases, __pyx_k_aliases, sizeof(__pyx_k_aliases), 0, 0, 1, 1},
  {&__pyx_n_s_app, __pyx_k_app, sizeof(__pyx_k_app), 0, 0, 1, 1},
  {&__pyx_n_s_arg, __pyx_k_arg, sizeof(__pyx_k_arg), 0, 0, 1, 1},
  {&__pyx_n_s_argc, __pyx_k_argc, sizeof(__pyx_k_argc), 0, 0, 1, 1},
  {&__pyx_n_s_args_buffer, __pyx_k_args_buffer, sizeof(__pyx_k_args_buffer), 0, 0, 1, 1},
  {&__pyx_n_s_argv, __pyx_k_argv, sizeof(__pyx_k_argv), 0, 0, 1, 1},
  {&__pyx_n_s_argv_buffer, __pyx_k_argv_buffer, sizeof(__pyx_k_argv_buffer), 0, 0, 1, 1},
  {&__pyx_n_s_byteslist, __pyx_k_byteslist, sizeof(__pyx_k_byteslist), 0, 0, 1, 1},
  {&__pyx_n_s_cb_after_mainloop, __pyx_k_cb_after_mainloop, sizeof(__pyx_k_cb_after_mainloop), 0, 0, 1, 1},
  {&__pyx_n_s_cb_app_post_create, __pyx_k_cb_app_post_create, sizeof(__pyx_k_cb_app_post_create), 0, 0, 1, 1},
  {&__pyx_n_s_cb_before_mainloop, __pyx_k_cb_before_mainloop, sizeof(__pyx_k_cb_before_mainloop), 0, 0, 1, 1},
  {&__pyx_n_s_cb_run_app, __pyx_k_cb_run_app, sizeof(__pyx_k_cb_run_app), 0, 0, 1, 1},
  {&__pyx_n_s_compiled, __pyx_k_compiled, sizeof(__pyx_k_compiled), 0, 0, 1, 1},
  {&__pyx_n_s_config, __pyx_k_config, sizeof(__pyx_k_config), 0, 0, 1, 1},
  {&__pyx_n_s_config_2, __pyx_k_config_2, sizeof(__pyx_k_config_2), 0, 0, 1, 1},
  {&__pyx_n_u_d, __pyx_k_d, sizeof(__pyx_k_d), 0, 1, 0, 1},
  {&__pyx_n_u_debug_es2, __pyx_k_debug_es2, sizeof(__pyx_k_debug_es2), 0, 1, 0, 1},
  {&__pyx_n_u_debug_ogl, __pyx_k_debug_ogl, sizeof(__pyx_k_debug_ogl), 0, 1, 0, 1},
  {&__pyx_n_s_depends, __pyx_k_depends, sizeof(__pyx_k_depends), 0, 0, 1, 1},
  {&__pyx_n_u_dos, __pyx_k_dos, sizeof(__pyx_k_dos), 0, 1, 0, 1},
  {&__pyx_n_s_encode, __pyx_k_encode, sizeof(__pyx_k_encode), 0, 0, 1, 1},
  {&__pyx_n_u_es2, __pyx_k_es2, sizeof(__pyx_k_es2), 0, 1, 0, 1},
  {&__pyx_n_u_es2d, __pyx_k_es2d, sizeof(__pyx_k_es2d), 0, 1, 0, 1},
  {&__pyx_n_u_es2dos, __pyx_k_es2dos, sizeof(__pyx_k_es2dos), 0, 1, 0, 1},
  {&__pyx_n_u_es2os, __pyx_k_es2os, sizeof(__pyx_k_es2os), 0, 1, 0, 1},
  {&__pyx_n_s_exc_info, __pyx_k_exc_info, sizeof(__pyx_k_exc_info), 0, 0, 1, 1},
  {&__pyx_n_s_excepthook, __pyx_k_excepthook, sizeof(__pyx_k_excepthook), 0, 0, 1, 1},
  {&__pyx_n_s_exec_application, __pyx_k_exec_application, sizeof(__pyx_k_exec_application), 0, 0, 1, 1},
  {&__pyx_n_s_format, __pyx_k_format, sizeof(__pyx_k_format), 0, 0, 1, 1},
  {&__pyx_n_s_get_gl_variant, __pyx_k_get_gl_variant, sizeof(__pyx_k_get_gl_variant), 0, 0, 1, 1},
  {&__pyx_n_s_getdefaultencoding, __pyx_k_getdefaultencoding, sizeof(__pyx_k_getdefaultencoding), 0, 0, 1, 1},
  {&__pyx_n_u_glarea_es2, __pyx_k_glarea_es2, sizeof(__pyx_k_glarea_es2), 0, 1, 0, 1},
  {&__pyx_n_u_glarea_es2d, __pyx_k_glarea_es2d, sizeof(__pyx_k_glarea_es2d), 0, 1, 0, 1},
  {&__pyx_n_u_glarea_es2dos, __pyx_k_glarea_es2dos, sizeof(__pyx_k_glarea_es2dos), 0, 1, 0, 1},
  {&__pyx_n_u_glarea_es2os, __pyx_k_glarea_es2os, sizeof(__pyx_k_glarea_es2os), 0, 1, 0, 1},
  {&__pyx_n_u_glarea_ogl, __pyx_k_glarea_ogl, sizeof(__pyx_k_glarea_ogl), 0, 1, 0, 1},
  {&__pyx_n_u_glarea_ogld, __pyx_k_glarea_ogld, sizeof(__pyx_k_glarea_ogld), 0, 1, 0, 1},
  {&__pyx_n_u_glarea_ogldos, __pyx_k_glarea_ogldos, sizeof(__pyx_k_glarea_ogldos), 0, 1, 0, 1},
  {&__pyx_n_u_glarea_oglos, __pyx_k_glarea_oglos, sizeof(__pyx_k_glarea_oglos), 0, 1, 0, 1},
  {&__pyx_n_u_gldraw_es2, __pyx_k_gldraw_es2, sizeof(__pyx_k_gldraw_es2), 0, 1, 0, 1},
  {&__pyx_n_u_gldraw_es2d, __pyx_k_gldraw_es2d, sizeof(__pyx_k_gldraw_es2d), 0, 1, 0, 1},
  {&__pyx_n_u_gldraw_ogl, __pyx_k_gldraw_ogl, sizeof(__pyx_k_gldraw_ogl), 0, 1, 0, 1},
  {&__pyx_n_u_gldraw_ogld, __pyx_k_gldraw_ogld, sizeof(__pyx_k_gldraw_ogld), 0, 1, 0, 1},
  {&__pyx_kp_s_tmp, __pyx_k_tmp, sizeof(__pyx_k_tmp), 0, 0, 1, 0},
  {&__pyx_n_s_i, __pyx_k_i, sizeof(__pyx_k_i), 0, 0, 1, 1},
  {&__pyx_n_s_import, __pyx_k_import, sizeof(__pyx_k_import), 0, 0, 1, 1},
  {&__pyx_n_s_join, __pyx_k_join, sizeof(__pyx_k_join), 0, 0, 1, 1},
  {&__pyx_n_s_language, __pyx_k_language, sizeof(__pyx_k_language), 0, 0, 1, 1},
  {&__pyx_n_s_main, __pyx_k_main, sizeof(__pyx_k_main), 0, 0, 1, 1},
  {&__pyx_n_s_main_2, __pyx_k_main_2, sizeof(__pyx_k_main_2), 0, 0, 1, 1},
  {&__pyx_n_s_module, __pyx_k_module, sizeof(__pyx_k_module), 0, 0, 1, 1},
  {&__pyx_n_u_ogl, __pyx_k_ogl, sizeof(__pyx_k_ogl), 0, 1, 0, 1},
  {&__pyx_n_u_ogld, __pyx_k_ogld, sizeof(__pyx_k_ogld), 0, 1, 0, 1},
  {&__pyx_n_u_ogldos, __pyx_k_ogldos, sizeof(__pyx_k_ogldos), 0, 1, 0, 1},
  {&__pyx_n_u_oglos, __pyx_k_oglos, sizeof(__pyx_k_oglos), 0, 1, 0, 1},
  {&__pyx_n_s_opts, __pyx_k_opts, sizeof(__pyx_k_opts), 0, 0, 1, 1},
  {&__pyx_n_u_os, __pyx_k_os, sizeof(__pyx_k_os), 0, 1, 0, 1},
  {&__pyx_n_s_pack, __pyx_k_pack, sizeof(__pyx_k_pack), 0, 0, 1, 1},
  {&__pyx_n_s_print, __pyx_k_print, sizeof(__pyx_k_print), 0, 0, 1, 1},
  {&__pyx_n_s_ptr, __pyx_k_ptr, sizeof(__pyx_k_ptr), 0, 0, 1, 1},
  {&__pyx_n_s_ptrlist, __pyx_k_ptrlist, sizeof(__pyx_k_ptrlist), 0, 0, 1, 1},
  {&__pyx_n_s_pyapp, __pyx_k_pyapp, sizeof(__pyx_k_pyapp), 0, 0, 1, 1},
  {&__pyx_n_s_pybiklib, __pyx_k_pybiklib, sizeof(__pyx_k_pybiklib), 0, 0, 1, 1},
  {&__pyx_n_s_qargs, __pyx_k_qargs, sizeof(__pyx_k_qargs), 0, 0, 1, 1},
  {&__pyx_n_u_qt, __pyx_k_qt, sizeof(__pyx_k_qt), 0, 1, 0, 1},
  {&__pyx_n_u_qt_qtqes2, __pyx_k_qt_qtqes2, sizeof(__pyx_k_qt_qtqes2), 0, 1, 0, 1},
  {&__pyx_n_u_qt_qtqes2d, __pyx_k_qt_qtqes2d, sizeof(__pyx_k_qt_qtqes2d), 0, 1, 0, 1},
  {&__pyx_n_u_qt_qtqes2dos, __pyx_k_qt_qtqes2dos, sizeof(__pyx_k_qt_qtqes2dos), 0, 1, 0, 1},
  {&__pyx_n_u_qt_qtqes2os, __pyx_k_qt_qtqes2os, sizeof(__pyx_k_qt_qtqes2os), 0, 1, 0, 1},
  {&__pyx_n_u_qt_qtqogl, __pyx_k_qt_qtqogl, sizeof(__pyx_k_qt_qtqogl), 0, 1, 0, 1},
  {&__pyx_n_u_qt_qtqogld, __pyx_k_qt_qtqogld, sizeof(__pyx_k_qt_qtqogld), 0, 1, 0, 1},
  {&__pyx_n_u_qt_qtqogldos, __pyx_k_qt_qtqogldos, sizeof(__pyx_k_qt_qtqogldos), 0, 1, 0, 1},
  {&__pyx_n_u_qt_qtqoglos, __pyx_k_qt_qtqoglos, sizeof(__pyx_k_qt_qtqoglos), 0, 1, 0, 1},
  {&__pyx_n_u_qt_qtwes2, __pyx_k_qt_qtwes2, sizeof(__pyx_k_qt_qtwes2), 0, 1, 0, 1},
  {&__pyx_n_u_qt_qtwes2d, __pyx_k_qt_qtwes2d, sizeof(__pyx_k_qt_qtwes2d), 0, 1, 0, 1},
  {&__pyx_n_u_qt_qtwes2dos, __pyx_k_qt_qtwes2dos, sizeof(__pyx_k_qt_qtwes2dos), 0, 1, 0, 1},
  {&__pyx_n_u_qt_qtwes2os, __pyx_k_qt_qtwes2os, sizeof(__pyx_k_qt_qtwes2os), 0, 1, 0, 1},
  {&__pyx_n_u_qt_qtwogl, __pyx_k_qt_qtwogl, sizeof(__pyx_k_qt_qtwogl), 0, 1, 0, 1},
  {&__pyx_n_u_qt_qtwogld, __pyx_k_qt_qtwogld, sizeof(__pyx_k_qt_qtwogld), 0, 1, 0, 1},
  {&__pyx_n_u_qt_qtwogldos, __pyx_k_qt_qtwogldos, sizeof(__pyx_k_qt_qtwogldos), 0, 1, 0, 1},
  {&__pyx_n_u_qt_qtwoglos, __pyx_k_qt_qtwoglos, sizeof(__pyx_k_qt_qtwoglos), 0, 1, 0, 1},
  {&__pyx_n_s_qtexec, __pyx_k_qtexec, sizeof(__pyx_k_qtexec), 0, 0, 1, 1},
  {&__pyx_n_u_qtq, __pyx_k_qtq, sizeof(__pyx_k_qtq), 0, 1, 0, 1},
  {&__pyx_kp_u_qtq_2, __pyx_k_qtq_2, sizeof(__pyx_k_qtq_2), 0, 1, 0, 0},
  {&__pyx_kp_u_qtq_d, __pyx_k_qtq_d, sizeof(__pyx_k_qtq_d), 0, 1, 0, 0},
  {&__pyx_kp_u_qtq_dos, __pyx_k_qtq_dos, sizeof(__pyx_k_qtq_dos), 0, 1, 0, 0},
  {&__pyx_kp_u_qtq_os, __pyx_k_qtq_os, sizeof(__pyx_k_qtq_os), 0, 1, 0, 0},
  {&__pyx_n_u_qtqd, __pyx_k_qtqd, sizeof(__pyx_k_qtqd), 0, 1, 0, 1},
  {&__pyx_n_u_qtqdos, __pyx_k_qtqdos, sizeof(__pyx_k_qtqdos), 0, 1, 0, 1},
  {&__pyx_n_u_qtqes2, __pyx_k_qtqes2, sizeof(__pyx_k_qtqes2), 0, 1, 0, 1},
  {&__pyx_n_u_qtqes2d, __pyx_k_qtqes2d, sizeof(__pyx_k_qtqes2d), 0, 1, 0, 1},
  {&__pyx_n_u_qtqes2dos, __pyx_k_qtqes2dos, sizeof(__pyx_k_qtqes2dos), 0, 1, 0, 1},
  {&__pyx_n_u_qtqes2os, __pyx_k_qtqes2os, sizeof(__pyx_k_qtqes2os), 0, 1, 0, 1},
  {&__pyx_n_u_qtqogl, __pyx_k_qtqogl, sizeof(__pyx_k_qtqogl), 0, 1, 0, 1},
  {&__pyx_n_u_qtqogld, __pyx_k_qtqogld, sizeof(__pyx_k_qtqogld), 0, 1, 0, 1},
  {&__pyx_n_u_qtqogldos, __pyx_k_qtqogldos, sizeof(__pyx_k_qtqogldos), 0, 1, 0, 1},
  {&__pyx_n_u_qtqoglos, __pyx_k_qtqoglos, sizeof(__pyx_k_qtqoglos), 0, 1, 0, 1},
  {&__pyx_n_u_qtqos, __pyx_k_qtqos, sizeof(__pyx_k_qtqos), 0, 1, 0, 1},
  {&__pyx_n_u_qtui, __pyx_k_qtui, sizeof(__pyx_k_qtui), 0, 1, 0, 1},
  {&__pyx_kp_u_qtw, __pyx_k_qtw, sizeof(__pyx_k_qtw), 0, 1, 0, 0},
  {&__pyx_n_u_qtw_2, __pyx_k_qtw_2, sizeof(__pyx_k_qtw_2), 0, 1, 0, 1},
  {&__pyx_kp_u_qtw_d, __pyx_k_qtw_d, sizeof(__pyx_k_qtw_d), 0, 1, 0, 0},
  {&__pyx_kp_u_qtw_dos, __pyx_k_qtw_dos, sizeof(__pyx_k_qtw_dos), 0, 1, 0, 0},
  {&__pyx_kp_u_qtw_os, __pyx_k_qtw_os, sizeof(__pyx_k_qtw_os), 0, 1, 0, 0},
  {&__pyx_n_u_qtwd, __pyx_k_qtwd, sizeof(__pyx_k_qtwd), 0, 1, 0, 1},
  {&__pyx_n_u_qtwdos, __pyx_k_qtwdos, sizeof(__pyx_k_qtwdos), 0, 1, 0, 1},
  {&__pyx_n_u_qtwes2, __pyx_k_qtwes2, sizeof(__pyx_k_qtwes2), 0, 1, 0, 1},
  {&__pyx_n_u_qtwes2d, __pyx_k_qtwes2d, sizeof(__pyx_k_qtwes2d), 0, 1, 0, 1},
  {&__pyx_n_u_qtwes2dos, __pyx_k_qtwes2dos, sizeof(__pyx_k_qtwes2dos), 0, 1, 0, 1},
  {&__pyx_n_u_qtwes2os, __pyx_k_qtwes2os, sizeof(__pyx_k_qtwes2os), 0, 1, 0, 1},
  {&__pyx_n_u_qtwogl, __pyx_k_qtwogl, sizeof(__pyx_k_qtwogl), 0, 1, 0, 1},
  {&__pyx_n_u_qtwogld, __pyx_k_qtwogld, sizeof(__pyx_k_qtwogld), 0, 1, 0, 1},
  {&__pyx_n_u_qtwogldos, __pyx_k_qtwogldos, sizeof(__pyx_k_qtwogldos), 0, 1, 0, 1},
  {&__pyx_n_u_qtwoglos, __pyx_k_qtwoglos, sizeof(__pyx_k_qtwoglos), 0, 1, 0, 1},
  {&__pyx_n_u_qtwos, __pyx_k_qtwos, sizeof(__pyx_k_qtwos), 0, 1, 0, 1},
  {&__pyx_n_s_range, __pyx_k_range, sizeof(__pyx_k_range), 0, 0, 1, 1},
  {&__pyx_n_s_set_debug_flags, __pyx_k_set_debug_flags, sizeof(__pyx_k_set_debug_flags), 0, 0, 1, 1},
  {&__pyx_n_s_struct, __pyx_k_struct, sizeof(__pyx_k_struct), 0, 0, 1, 1},
  {&__pyx_n_s_sys, __pyx_k_sys, sizeof(__pyx_k_sys), 0, 0, 1, 1},
  {&__pyx_n_s_test, __pyx_k_test, sizeof(__pyx_k_test), 0, 0, 1, 1},
  {&__pyx_n_s_translator, __pyx_k_translator, sizeof(__pyx_k_translator), 0, 0, 1, 1},
  {&__pyx_n_s_ui_args, __pyx_k_ui_args, sizeof(__pyx_k_ui_args), 0, 0, 1, 1},
  {&__pyx_kp_u_utf_8, __pyx_k_utf_8, sizeof(__pyx_k_utf_8), 0, 1, 0, 0},
  {0, 0, 0, 0, 0, 0, 0}
};
static int __Pyx_InitCachedBuiltins(void) {
  __pyx_builtin_print = __Pyx_GetBuiltinName(__pyx_n_s_print); if (!__pyx_builtin_print) __PYX_ERR(0, 77, __pyx_L1_error)
  __pyx_builtin_range = __Pyx_GetBuiltinName(__pyx_n_s_range); if (!__pyx_builtin_range) __PYX_ERR(0, 113, __pyx_L1_error)
  return 0;
  __pyx_L1_error:;
  return -1;
}

static int __Pyx_InitCachedConstants(void) {
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__Pyx_InitCachedConstants", 0);

  /* "_qtexec_.pyx":62
 * ##pxm-FUNC P
 * cdef QString str2q(pstr):
 *     data = pstr.encode('utf-8') #px+             # <<<<<<<<<<<<<<
 *     return fromUtf8(<char*>data, len(data)) #px+
 * 
 */
  __pyx_tuple_ = PyTuple_Pack(1, __pyx_kp_u_utf_8); if (unlikely(!__pyx_tuple_)) __PYX_ERR(0, 62, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple_);
  __Pyx_GIVEREF(__pyx_tuple_);

  /* "_qtexec_.pyx":112
 *     if qargs.size() > 1: #px/
 *     #if len(qargs) > 1:
 *         print('Unknown arguments:')             # <<<<<<<<<<<<<<
 *         for i in range(1, qargs.size()): #px/
 *         #for i in range(1, len(qargs)):
 */
  __pyx_tuple__4 = PyTuple_Pack(1, __pyx_kp_u_Unknown_arguments); if (unlikely(!__pyx_tuple__4)) __PYX_ERR(0, 112, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__4);
  __Pyx_GIVEREF(__pyx_tuple__4);

  /* "_qtexec_.pyx":48
 * debug = 0
 * 
 * def set_debug_flags(module):             # <<<<<<<<<<<<<<
 *     global debug
 *     if module.DEBUG_MSG:   debug |= DEBUG_MSG
 */
  __pyx_tuple__6 = PyTuple_Pack(1, __pyx_n_s_module); if (unlikely(!__pyx_tuple__6)) __PYX_ERR(0, 48, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__6);
  __Pyx_GIVEREF(__pyx_tuple__6);
  __pyx_codeobj__7 = (PyObject*)__Pyx_PyCode_New(1, 0, 1, 0, 0, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__6, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_tmp, __pyx_n_s_set_debug_flags, 48, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__7)) __PYX_ERR(0, 48, __pyx_L1_error)

  /* "_qtexec_.pyx":68
 * #### . ####
 * 
 * def get_gl_variant():             # <<<<<<<<<<<<<<
 *     cdef int i #px+
 *     # This function requires that the app instance is already created
 */
  __pyx_tuple__8 = PyTuple_Pack(1, __pyx_n_s_i); if (unlikely(!__pyx_tuple__8)) __PYX_ERR(0, 68, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__8);
  __Pyx_GIVEREF(__pyx_tuple__8);
  __pyx_codeobj__9 = (PyObject*)__Pyx_PyCode_New(0, 0, 1, 0, 0, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__8, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_tmp, __pyx_n_s_get_gl_variant, 68, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__9)) __PYX_ERR(0, 68, __pyx_L1_error)

  /* "_qtexec_.pyx":80
 *         return ''
 * 
 * def exec_application(main):             # <<<<<<<<<<<<<<
 *     ##px-
 *     #global app #http://pyqt.sourceforge.net/Docs/PyQt5/gotchas.html#crashes-on-exit
 */
  __pyx_tuple__10 = PyTuple_Pack(16, __pyx_n_s_main_2, __pyx_n_s_byteslist, __pyx_n_s_args_buffer, __pyx_n_s_ptr, __pyx_n_s_ptrlist, __pyx_n_s_arg, __pyx_n_s_struct, __pyx_n_s_argv_buffer, __pyx_n_s_argc, __pyx_n_s_argv, __pyx_n_s_app, __pyx_n_s_qargs, __pyx_n_s_i, __pyx_n_s_language, __pyx_n_s_translator, __pyx_n_s_pyapp); if (unlikely(!__pyx_tuple__10)) __PYX_ERR(0, 80, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__10);
  __Pyx_GIVEREF(__pyx_tuple__10);
  __pyx_codeobj__11 = (PyObject*)__Pyx_PyCode_New(1, 0, 16, 0, 0, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__10, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_tmp, __pyx_n_s_exec_application, 80, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__11)) __PYX_ERR(0, 80, __pyx_L1_error)
  __Pyx_RefNannyFinishContext();
  return 0;
  __pyx_L1_error:;
  __Pyx_RefNannyFinishContext();
  return -1;
}

static int __Pyx_InitGlobals(void) {
  if (__Pyx_InitStrings(__pyx_string_tab) < 0) __PYX_ERR(0, 1, __pyx_L1_error);
  __pyx_int_0 = PyInt_FromLong(0); if (unlikely(!__pyx_int_0)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_1 = PyInt_FromLong(1); if (unlikely(!__pyx_int_1)) __PYX_ERR(0, 1, __pyx_L1_error)
  return 0;
  __pyx_L1_error:;
  return -1;
}

#if PY_MAJOR_VERSION < 3
PyMODINIT_FUNC init_qtexec_(void); /*proto*/
PyMODINIT_FUNC init_qtexec_(void)
#else
PyMODINIT_FUNC PyInit__qtexec_(void); /*proto*/
PyMODINIT_FUNC PyInit__qtexec_(void)
#endif
{
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  __Pyx_RefNannyDeclarations
  #if CYTHON_REFNANNY
  __Pyx_RefNanny = __Pyx_RefNannyImportAPI("refnanny");
  if (!__Pyx_RefNanny) {
      PyErr_Clear();
      __Pyx_RefNanny = __Pyx_RefNannyImportAPI("Cython.Runtime.refnanny");
      if (!__Pyx_RefNanny)
          Py_FatalError("failed to import 'refnanny' module");
  }
  #endif
  __Pyx_RefNannySetupContext("PyMODINIT_FUNC PyInit__qtexec_(void)", 0);
  if (__Pyx_check_binary_version() < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_empty_tuple = PyTuple_New(0); if (unlikely(!__pyx_empty_tuple)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_empty_bytes = PyBytes_FromStringAndSize("", 0); if (unlikely(!__pyx_empty_bytes)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_empty_unicode = PyUnicode_FromStringAndSize("", 0); if (unlikely(!__pyx_empty_unicode)) __PYX_ERR(0, 1, __pyx_L1_error)
  #ifdef __Pyx_CyFunction_USED
  if (__pyx_CyFunction_init() < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  #endif
  #ifdef __Pyx_FusedFunction_USED
  if (__pyx_FusedFunction_init() < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  #endif
  #ifdef __Pyx_Coroutine_USED
  if (__pyx_Coroutine_init() < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  #endif
  #ifdef __Pyx_Generator_USED
  if (__pyx_Generator_init() < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  #endif
  #ifdef __Pyx_StopAsyncIteration_USED
  if (__pyx_StopAsyncIteration_init() < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  #endif
  /*--- Library function declarations ---*/
  /*--- Threads initialization code ---*/
  #if defined(__PYX_FORCE_INIT_THREADS) && __PYX_FORCE_INIT_THREADS
  #ifdef WITH_THREAD /* Python build with threading support? */
  PyEval_InitThreads();
  #endif
  #endif
  /*--- Module creation code ---*/
  #if PY_MAJOR_VERSION < 3
  __pyx_m = Py_InitModule4("_qtexec_", __pyx_methods, 0, 0, PYTHON_API_VERSION); Py_XINCREF(__pyx_m);
  #else
  __pyx_m = PyModule_Create(&__pyx_moduledef);
  #endif
  if (unlikely(!__pyx_m)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_d = PyModule_GetDict(__pyx_m); if (unlikely(!__pyx_d)) __PYX_ERR(0, 1, __pyx_L1_error)
  Py_INCREF(__pyx_d);
  __pyx_b = PyImport_AddModule(__Pyx_BUILTIN_MODULE_NAME); if (unlikely(!__pyx_b)) __PYX_ERR(0, 1, __pyx_L1_error)
  #if CYTHON_COMPILING_IN_PYPY
  Py_INCREF(__pyx_b);
  #endif
  if (PyObject_SetAttrString(__pyx_m, "__builtins__", __pyx_b) < 0) __PYX_ERR(0, 1, __pyx_L1_error);
  /*--- Initialize various global constants etc. ---*/
  if (__Pyx_InitGlobals() < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  #if PY_MAJOR_VERSION < 3 && (__PYX_DEFAULT_STRING_ENCODING_IS_ASCII || __PYX_DEFAULT_STRING_ENCODING_IS_DEFAULT)
  if (__Pyx_init_sys_getdefaultencoding_params() < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  #endif
  if (__pyx_module_is_main__qtexec_) {
    if (PyObject_SetAttrString(__pyx_m, "__name__", __pyx_n_s_main) < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  }
  #if PY_MAJOR_VERSION >= 3
  {
    PyObject *modules = PyImport_GetModuleDict(); if (unlikely(!modules)) __PYX_ERR(0, 1, __pyx_L1_error)
    if (!PyDict_GetItemString(modules, "_qtexec_")) {
      if (unlikely(PyDict_SetItemString(modules, "_qtexec_", __pyx_m) < 0)) __PYX_ERR(0, 1, __pyx_L1_error)
    }
  }
  #endif
  /*--- Builtin init code ---*/
  if (__Pyx_InitCachedBuiltins() < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  /*--- Constants init code ---*/
  if (__Pyx_InitCachedConstants() < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  /*--- Global init code ---*/
  /*--- Variable export code ---*/
  /*--- Function export code ---*/
  /*--- Type init code ---*/
  /*--- Type import code ---*/
  /*--- Variable import code ---*/
  /*--- Function import code ---*/
  /*--- Execution code ---*/
  #if defined(__Pyx_Generator_USED) || defined(__Pyx_Coroutine_USED)
  if (__Pyx_patch_abc() < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  #endif

  /* "_qtexec_.pyx":25
 * # This line makes cython happy
 * global __name__, __package__
 * __compiled = True #px/             # <<<<<<<<<<<<<<
 * #__compiled = False
 * 
 */
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_compiled, Py_True) < 0) __PYX_ERR(0, 25, __pyx_L1_error)

  /* "_qtexec_.pyx":28
 * #__compiled = False
 * 
 * import sys             # <<<<<<<<<<<<<<
 * 
 * from pybiklib import config as config_
 */
  __pyx_t_1 = __Pyx_Import(__pyx_n_s_sys, 0, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 28, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_sys, __pyx_t_1) < 0) __PYX_ERR(0, 28, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "_qtexec_.pyx":30
 * import sys
 * 
 * from pybiklib import config as config_             # <<<<<<<<<<<<<<
 * 
 * from qt cimport * #px+
 */
  __pyx_t_1 = PyList_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 30, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF(__pyx_n_s_config_2);
  __Pyx_GIVEREF(__pyx_n_s_config_2);
  PyList_SET_ITEM(__pyx_t_1, 0, __pyx_n_s_config_2);
  __pyx_t_2 = __Pyx_Import(__pyx_n_s_pybiklib, __pyx_t_1, 0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 30, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_ImportFrom(__pyx_t_2, __pyx_n_s_config_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 30, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_config, __pyx_t_1) < 0) __PYX_ERR(0, 30, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "_qtexec_.pyx":46
 *     DEBUG_MSGEXT = 0x0020
 * cdef long debug #px+
 * debug = 0             # <<<<<<<<<<<<<<
 * 
 * def set_debug_flags(module):
 */
  __pyx_v_8_qtexec__debug = 0;

  /* "_qtexec_.pyx":48
 * debug = 0
 * 
 * def set_debug_flags(module):             # <<<<<<<<<<<<<<
 *     global debug
 *     if module.DEBUG_MSG:   debug |= DEBUG_MSG
 */
  __pyx_t_2 = PyCFunction_NewEx(&__pyx_mdef_8_qtexec__1set_debug_flags, NULL, __pyx_n_s_qtexec); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 48, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_set_debug_flags, __pyx_t_2) < 0) __PYX_ERR(0, 48, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "_qtexec_.pyx":68
 * #### . ####
 * 
 * def get_gl_variant():             # <<<<<<<<<<<<<<
 *     cdef int i #px+
 *     # This function requires that the app instance is already created
 */
  __pyx_t_2 = PyCFunction_NewEx(&__pyx_mdef_8_qtexec__3get_gl_variant, NULL, __pyx_n_s_qtexec); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 68, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_get_gl_variant, __pyx_t_2) < 0) __PYX_ERR(0, 68, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "_qtexec_.pyx":80
 *         return ''
 * 
 * def exec_application(main):             # <<<<<<<<<<<<<<
 *     ##px-
 *     #global app #http://pyqt.sourceforge.net/Docs/PyQt5/gotchas.html#crashes-on-exit
 */
  __pyx_t_2 = PyCFunction_NewEx(&__pyx_mdef_8_qtexec__5exec_application, NULL, __pyx_n_s_qtexec); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 80, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_exec_application, __pyx_t_2) < 0) __PYX_ERR(0, 80, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "_qtexec_.pyx":148
 * 
 * depends = { #px+
 *     'qtwogld':   ['_debug_ogl', '_gldraw_ogld', '_glarea_ogld', '_qtui_', '_qt_qtwogld'],             # <<<<<<<<<<<<<<
 *     'qtwogldos': ['_debug_ogl', '_gldraw_ogld', '_glarea_ogldos', '_qtui_', '_qt_qtwogldos'],
 *     'qtwes2d':   ['_debug_es2', '_gldraw_es2d', '_glarea_es2d', '_qtui_', '_qt_qtwes2d'],
 */
  __pyx_t_2 = PyDict_New(); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 148, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_1 = PyList_New(5); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 148, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF(__pyx_n_u_debug_ogl);
  __Pyx_GIVEREF(__pyx_n_u_debug_ogl);
  PyList_SET_ITEM(__pyx_t_1, 0, __pyx_n_u_debug_ogl);
  __Pyx_INCREF(__pyx_n_u_gldraw_ogld);
  __Pyx_GIVEREF(__pyx_n_u_gldraw_ogld);
  PyList_SET_ITEM(__pyx_t_1, 1, __pyx_n_u_gldraw_ogld);
  __Pyx_INCREF(__pyx_n_u_glarea_ogld);
  __Pyx_GIVEREF(__pyx_n_u_glarea_ogld);
  PyList_SET_ITEM(__pyx_t_1, 2, __pyx_n_u_glarea_ogld);
  __Pyx_INCREF(__pyx_n_u_qtui);
  __Pyx_GIVEREF(__pyx_n_u_qtui);
  PyList_SET_ITEM(__pyx_t_1, 3, __pyx_n_u_qtui);
  __Pyx_INCREF(__pyx_n_u_qt_qtwogld);
  __Pyx_GIVEREF(__pyx_n_u_qt_qtwogld);
  PyList_SET_ITEM(__pyx_t_1, 4, __pyx_n_u_qt_qtwogld);
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_u_qtwogld, __pyx_t_1) < 0) __PYX_ERR(0, 148, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "_qtexec_.pyx":149
 * depends = { #px+
 *     'qtwogld':   ['_debug_ogl', '_gldraw_ogld', '_glarea_ogld', '_qtui_', '_qt_qtwogld'],
 *     'qtwogldos': ['_debug_ogl', '_gldraw_ogld', '_glarea_ogldos', '_qtui_', '_qt_qtwogldos'],             # <<<<<<<<<<<<<<
 *     'qtwes2d':   ['_debug_es2', '_gldraw_es2d', '_glarea_es2d', '_qtui_', '_qt_qtwes2d'],
 *     'qtwes2dos': ['_debug_es2', '_gldraw_es2d', '_glarea_es2dos', '_qtui_', '_qt_qtwes2dos'],
 */
  __pyx_t_1 = PyList_New(5); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 149, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF(__pyx_n_u_debug_ogl);
  __Pyx_GIVEREF(__pyx_n_u_debug_ogl);
  PyList_SET_ITEM(__pyx_t_1, 0, __pyx_n_u_debug_ogl);
  __Pyx_INCREF(__pyx_n_u_gldraw_ogld);
  __Pyx_GIVEREF(__pyx_n_u_gldraw_ogld);
  PyList_SET_ITEM(__pyx_t_1, 1, __pyx_n_u_gldraw_ogld);
  __Pyx_INCREF(__pyx_n_u_glarea_ogldos);
  __Pyx_GIVEREF(__pyx_n_u_glarea_ogldos);
  PyList_SET_ITEM(__pyx_t_1, 2, __pyx_n_u_glarea_ogldos);
  __Pyx_INCREF(__pyx_n_u_qtui);
  __Pyx_GIVEREF(__pyx_n_u_qtui);
  PyList_SET_ITEM(__pyx_t_1, 3, __pyx_n_u_qtui);
  __Pyx_INCREF(__pyx_n_u_qt_qtwogldos);
  __Pyx_GIVEREF(__pyx_n_u_qt_qtwogldos);
  PyList_SET_ITEM(__pyx_t_1, 4, __pyx_n_u_qt_qtwogldos);
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_u_qtwogldos, __pyx_t_1) < 0) __PYX_ERR(0, 148, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "_qtexec_.pyx":150
 *     'qtwogld':   ['_debug_ogl', '_gldraw_ogld', '_glarea_ogld', '_qtui_', '_qt_qtwogld'],
 *     'qtwogldos': ['_debug_ogl', '_gldraw_ogld', '_glarea_ogldos', '_qtui_', '_qt_qtwogldos'],
 *     'qtwes2d':   ['_debug_es2', '_gldraw_es2d', '_glarea_es2d', '_qtui_', '_qt_qtwes2d'],             # <<<<<<<<<<<<<<
 *     'qtwes2dos': ['_debug_es2', '_gldraw_es2d', '_glarea_es2dos', '_qtui_', '_qt_qtwes2dos'],
 *     'qtqogld':   ['_debug_ogl', '_gldraw_ogld', '_glarea_ogld', '_qt_qtqogld'],
 */
  __pyx_t_1 = PyList_New(5); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 150, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF(__pyx_n_u_debug_es2);
  __Pyx_GIVEREF(__pyx_n_u_debug_es2);
  PyList_SET_ITEM(__pyx_t_1, 0, __pyx_n_u_debug_es2);
  __Pyx_INCREF(__pyx_n_u_gldraw_es2d);
  __Pyx_GIVEREF(__pyx_n_u_gldraw_es2d);
  PyList_SET_ITEM(__pyx_t_1, 1, __pyx_n_u_gldraw_es2d);
  __Pyx_INCREF(__pyx_n_u_glarea_es2d);
  __Pyx_GIVEREF(__pyx_n_u_glarea_es2d);
  PyList_SET_ITEM(__pyx_t_1, 2, __pyx_n_u_glarea_es2d);
  __Pyx_INCREF(__pyx_n_u_qtui);
  __Pyx_GIVEREF(__pyx_n_u_qtui);
  PyList_SET_ITEM(__pyx_t_1, 3, __pyx_n_u_qtui);
  __Pyx_INCREF(__pyx_n_u_qt_qtwes2d);
  __Pyx_GIVEREF(__pyx_n_u_qt_qtwes2d);
  PyList_SET_ITEM(__pyx_t_1, 4, __pyx_n_u_qt_qtwes2d);
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_u_qtwes2d, __pyx_t_1) < 0) __PYX_ERR(0, 148, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "_qtexec_.pyx":151
 *     'qtwogldos': ['_debug_ogl', '_gldraw_ogld', '_glarea_ogldos', '_qtui_', '_qt_qtwogldos'],
 *     'qtwes2d':   ['_debug_es2', '_gldraw_es2d', '_glarea_es2d', '_qtui_', '_qt_qtwes2d'],
 *     'qtwes2dos': ['_debug_es2', '_gldraw_es2d', '_glarea_es2dos', '_qtui_', '_qt_qtwes2dos'],             # <<<<<<<<<<<<<<
 *     'qtqogld':   ['_debug_ogl', '_gldraw_ogld', '_glarea_ogld', '_qt_qtqogld'],
 *     'qtqogldos': ['_debug_ogl', '_gldraw_ogld', '_glarea_ogldos', '_qt_qtqogldos'],
 */
  __pyx_t_1 = PyList_New(5); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 151, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF(__pyx_n_u_debug_es2);
  __Pyx_GIVEREF(__pyx_n_u_debug_es2);
  PyList_SET_ITEM(__pyx_t_1, 0, __pyx_n_u_debug_es2);
  __Pyx_INCREF(__pyx_n_u_gldraw_es2d);
  __Pyx_GIVEREF(__pyx_n_u_gldraw_es2d);
  PyList_SET_ITEM(__pyx_t_1, 1, __pyx_n_u_gldraw_es2d);
  __Pyx_INCREF(__pyx_n_u_glarea_es2dos);
  __Pyx_GIVEREF(__pyx_n_u_glarea_es2dos);
  PyList_SET_ITEM(__pyx_t_1, 2, __pyx_n_u_glarea_es2dos);
  __Pyx_INCREF(__pyx_n_u_qtui);
  __Pyx_GIVEREF(__pyx_n_u_qtui);
  PyList_SET_ITEM(__pyx_t_1, 3, __pyx_n_u_qtui);
  __Pyx_INCREF(__pyx_n_u_qt_qtwes2dos);
  __Pyx_GIVEREF(__pyx_n_u_qt_qtwes2dos);
  PyList_SET_ITEM(__pyx_t_1, 4, __pyx_n_u_qt_qtwes2dos);
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_u_qtwes2dos, __pyx_t_1) < 0) __PYX_ERR(0, 148, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "_qtexec_.pyx":152
 *     'qtwes2d':   ['_debug_es2', '_gldraw_es2d', '_glarea_es2d', '_qtui_', '_qt_qtwes2d'],
 *     'qtwes2dos': ['_debug_es2', '_gldraw_es2d', '_glarea_es2dos', '_qtui_', '_qt_qtwes2dos'],
 *     'qtqogld':   ['_debug_ogl', '_gldraw_ogld', '_glarea_ogld', '_qt_qtqogld'],             # <<<<<<<<<<<<<<
 *     'qtqogldos': ['_debug_ogl', '_gldraw_ogld', '_glarea_ogldos', '_qt_qtqogldos'],
 *     'qtqes2d':   ['_debug_es2', '_gldraw_es2d', '_glarea_es2d', '_qt_qtqes2d'],
 */
  __pyx_t_1 = PyList_New(4); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 152, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF(__pyx_n_u_debug_ogl);
  __Pyx_GIVEREF(__pyx_n_u_debug_ogl);
  PyList_SET_ITEM(__pyx_t_1, 0, __pyx_n_u_debug_ogl);
  __Pyx_INCREF(__pyx_n_u_gldraw_ogld);
  __Pyx_GIVEREF(__pyx_n_u_gldraw_ogld);
  PyList_SET_ITEM(__pyx_t_1, 1, __pyx_n_u_gldraw_ogld);
  __Pyx_INCREF(__pyx_n_u_glarea_ogld);
  __Pyx_GIVEREF(__pyx_n_u_glarea_ogld);
  PyList_SET_ITEM(__pyx_t_1, 2, __pyx_n_u_glarea_ogld);
  __Pyx_INCREF(__pyx_n_u_qt_qtqogld);
  __Pyx_GIVEREF(__pyx_n_u_qt_qtqogld);
  PyList_SET_ITEM(__pyx_t_1, 3, __pyx_n_u_qt_qtqogld);
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_u_qtqogld, __pyx_t_1) < 0) __PYX_ERR(0, 148, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "_qtexec_.pyx":153
 *     'qtwes2dos': ['_debug_es2', '_gldraw_es2d', '_glarea_es2dos', '_qtui_', '_qt_qtwes2dos'],
 *     'qtqogld':   ['_debug_ogl', '_gldraw_ogld', '_glarea_ogld', '_qt_qtqogld'],
 *     'qtqogldos': ['_debug_ogl', '_gldraw_ogld', '_glarea_ogldos', '_qt_qtqogldos'],             # <<<<<<<<<<<<<<
 *     'qtqes2d':   ['_debug_es2', '_gldraw_es2d', '_glarea_es2d', '_qt_qtqes2d'],
 *     'qtqes2dos': ['_debug_es2', '_gldraw_es2d', '_glarea_es2dos', '_qt_qtqes2dos'],
 */
  __pyx_t_1 = PyList_New(4); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 153, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF(__pyx_n_u_debug_ogl);
  __Pyx_GIVEREF(__pyx_n_u_debug_ogl);
  PyList_SET_ITEM(__pyx_t_1, 0, __pyx_n_u_debug_ogl);
  __Pyx_INCREF(__pyx_n_u_gldraw_ogld);
  __Pyx_GIVEREF(__pyx_n_u_gldraw_ogld);
  PyList_SET_ITEM(__pyx_t_1, 1, __pyx_n_u_gldraw_ogld);
  __Pyx_INCREF(__pyx_n_u_glarea_ogldos);
  __Pyx_GIVEREF(__pyx_n_u_glarea_ogldos);
  PyList_SET_ITEM(__pyx_t_1, 2, __pyx_n_u_glarea_ogldos);
  __Pyx_INCREF(__pyx_n_u_qt_qtqogldos);
  __Pyx_GIVEREF(__pyx_n_u_qt_qtqogldos);
  PyList_SET_ITEM(__pyx_t_1, 3, __pyx_n_u_qt_qtqogldos);
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_u_qtqogldos, __pyx_t_1) < 0) __PYX_ERR(0, 148, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "_qtexec_.pyx":154
 *     'qtqogld':   ['_debug_ogl', '_gldraw_ogld', '_glarea_ogld', '_qt_qtqogld'],
 *     'qtqogldos': ['_debug_ogl', '_gldraw_ogld', '_glarea_ogldos', '_qt_qtqogldos'],
 *     'qtqes2d':   ['_debug_es2', '_gldraw_es2d', '_glarea_es2d', '_qt_qtqes2d'],             # <<<<<<<<<<<<<<
 *     'qtqes2dos': ['_debug_es2', '_gldraw_es2d', '_glarea_es2dos', '_qt_qtqes2dos'],
 *     'qtwogl':    ['_gldraw_ogl', '_glarea_ogl', '_qtui_', '_qt_qtwogl'],
 */
  __pyx_t_1 = PyList_New(4); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 154, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF(__pyx_n_u_debug_es2);
  __Pyx_GIVEREF(__pyx_n_u_debug_es2);
  PyList_SET_ITEM(__pyx_t_1, 0, __pyx_n_u_debug_es2);
  __Pyx_INCREF(__pyx_n_u_gldraw_es2d);
  __Pyx_GIVEREF(__pyx_n_u_gldraw_es2d);
  PyList_SET_ITEM(__pyx_t_1, 1, __pyx_n_u_gldraw_es2d);
  __Pyx_INCREF(__pyx_n_u_glarea_es2d);
  __Pyx_GIVEREF(__pyx_n_u_glarea_es2d);
  PyList_SET_ITEM(__pyx_t_1, 2, __pyx_n_u_glarea_es2d);
  __Pyx_INCREF(__pyx_n_u_qt_qtqes2d);
  __Pyx_GIVEREF(__pyx_n_u_qt_qtqes2d);
  PyList_SET_ITEM(__pyx_t_1, 3, __pyx_n_u_qt_qtqes2d);
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_u_qtqes2d, __pyx_t_1) < 0) __PYX_ERR(0, 148, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "_qtexec_.pyx":155
 *     'qtqogldos': ['_debug_ogl', '_gldraw_ogld', '_glarea_ogldos', '_qt_qtqogldos'],
 *     'qtqes2d':   ['_debug_es2', '_gldraw_es2d', '_glarea_es2d', '_qt_qtqes2d'],
 *     'qtqes2dos': ['_debug_es2', '_gldraw_es2d', '_glarea_es2dos', '_qt_qtqes2dos'],             # <<<<<<<<<<<<<<
 *     'qtwogl':    ['_gldraw_ogl', '_glarea_ogl', '_qtui_', '_qt_qtwogl'],
 *     'qtwoglos':  ['_gldraw_ogl', '_glarea_oglos', '_qtui_', '_qt_qtwoglos'],
 */
  __pyx_t_1 = PyList_New(4); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 155, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF(__pyx_n_u_debug_es2);
  __Pyx_GIVEREF(__pyx_n_u_debug_es2);
  PyList_SET_ITEM(__pyx_t_1, 0, __pyx_n_u_debug_es2);
  __Pyx_INCREF(__pyx_n_u_gldraw_es2d);
  __Pyx_GIVEREF(__pyx_n_u_gldraw_es2d);
  PyList_SET_ITEM(__pyx_t_1, 1, __pyx_n_u_gldraw_es2d);
  __Pyx_INCREF(__pyx_n_u_glarea_es2dos);
  __Pyx_GIVEREF(__pyx_n_u_glarea_es2dos);
  PyList_SET_ITEM(__pyx_t_1, 2, __pyx_n_u_glarea_es2dos);
  __Pyx_INCREF(__pyx_n_u_qt_qtqes2dos);
  __Pyx_GIVEREF(__pyx_n_u_qt_qtqes2dos);
  PyList_SET_ITEM(__pyx_t_1, 3, __pyx_n_u_qt_qtqes2dos);
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_u_qtqes2dos, __pyx_t_1) < 0) __PYX_ERR(0, 148, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "_qtexec_.pyx":156
 *     'qtqes2d':   ['_debug_es2', '_gldraw_es2d', '_glarea_es2d', '_qt_qtqes2d'],
 *     'qtqes2dos': ['_debug_es2', '_gldraw_es2d', '_glarea_es2dos', '_qt_qtqes2dos'],
 *     'qtwogl':    ['_gldraw_ogl', '_glarea_ogl', '_qtui_', '_qt_qtwogl'],             # <<<<<<<<<<<<<<
 *     'qtwoglos':  ['_gldraw_ogl', '_glarea_oglos', '_qtui_', '_qt_qtwoglos'],
 *     'qtwes2':    ['_gldraw_es2', '_glarea_es2', '_qtui_', '_qt_qtwes2'],
 */
  __pyx_t_1 = PyList_New(4); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 156, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF(__pyx_n_u_gldraw_ogl);
  __Pyx_GIVEREF(__pyx_n_u_gldraw_ogl);
  PyList_SET_ITEM(__pyx_t_1, 0, __pyx_n_u_gldraw_ogl);
  __Pyx_INCREF(__pyx_n_u_glarea_ogl);
  __Pyx_GIVEREF(__pyx_n_u_glarea_ogl);
  PyList_SET_ITEM(__pyx_t_1, 1, __pyx_n_u_glarea_ogl);
  __Pyx_INCREF(__pyx_n_u_qtui);
  __Pyx_GIVEREF(__pyx_n_u_qtui);
  PyList_SET_ITEM(__pyx_t_1, 2, __pyx_n_u_qtui);
  __Pyx_INCREF(__pyx_n_u_qt_qtwogl);
  __Pyx_GIVEREF(__pyx_n_u_qt_qtwogl);
  PyList_SET_ITEM(__pyx_t_1, 3, __pyx_n_u_qt_qtwogl);
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_u_qtwogl, __pyx_t_1) < 0) __PYX_ERR(0, 148, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "_qtexec_.pyx":157
 *     'qtqes2dos': ['_debug_es2', '_gldraw_es2d', '_glarea_es2dos', '_qt_qtqes2dos'],
 *     'qtwogl':    ['_gldraw_ogl', '_glarea_ogl', '_qtui_', '_qt_qtwogl'],
 *     'qtwoglos':  ['_gldraw_ogl', '_glarea_oglos', '_qtui_', '_qt_qtwoglos'],             # <<<<<<<<<<<<<<
 *     'qtwes2':    ['_gldraw_es2', '_glarea_es2', '_qtui_', '_qt_qtwes2'],
 *     'qtwes2os':  ['_gldraw_es2', '_glarea_es2os', '_qtui_', '_qt_qtwes2os'],
 */
  __pyx_t_1 = PyList_New(4); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 157, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF(__pyx_n_u_gldraw_ogl);
  __Pyx_GIVEREF(__pyx_n_u_gldraw_ogl);
  PyList_SET_ITEM(__pyx_t_1, 0, __pyx_n_u_gldraw_ogl);
  __Pyx_INCREF(__pyx_n_u_glarea_oglos);
  __Pyx_GIVEREF(__pyx_n_u_glarea_oglos);
  PyList_SET_ITEM(__pyx_t_1, 1, __pyx_n_u_glarea_oglos);
  __Pyx_INCREF(__pyx_n_u_qtui);
  __Pyx_GIVEREF(__pyx_n_u_qtui);
  PyList_SET_ITEM(__pyx_t_1, 2, __pyx_n_u_qtui);
  __Pyx_INCREF(__pyx_n_u_qt_qtwoglos);
  __Pyx_GIVEREF(__pyx_n_u_qt_qtwoglos);
  PyList_SET_ITEM(__pyx_t_1, 3, __pyx_n_u_qt_qtwoglos);
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_u_qtwoglos, __pyx_t_1) < 0) __PYX_ERR(0, 148, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "_qtexec_.pyx":158
 *     'qtwogl':    ['_gldraw_ogl', '_glarea_ogl', '_qtui_', '_qt_qtwogl'],
 *     'qtwoglos':  ['_gldraw_ogl', '_glarea_oglos', '_qtui_', '_qt_qtwoglos'],
 *     'qtwes2':    ['_gldraw_es2', '_glarea_es2', '_qtui_', '_qt_qtwes2'],             # <<<<<<<<<<<<<<
 *     'qtwes2os':  ['_gldraw_es2', '_glarea_es2os', '_qtui_', '_qt_qtwes2os'],
 *     'qtqogl':    ['_gldraw_ogl', '_glarea_ogl', '_qt_qtqogl'],
 */
  __pyx_t_1 = PyList_New(4); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 158, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF(__pyx_n_u_gldraw_es2);
  __Pyx_GIVEREF(__pyx_n_u_gldraw_es2);
  PyList_SET_ITEM(__pyx_t_1, 0, __pyx_n_u_gldraw_es2);
  __Pyx_INCREF(__pyx_n_u_glarea_es2);
  __Pyx_GIVEREF(__pyx_n_u_glarea_es2);
  PyList_SET_ITEM(__pyx_t_1, 1, __pyx_n_u_glarea_es2);
  __Pyx_INCREF(__pyx_n_u_qtui);
  __Pyx_GIVEREF(__pyx_n_u_qtui);
  PyList_SET_ITEM(__pyx_t_1, 2, __pyx_n_u_qtui);
  __Pyx_INCREF(__pyx_n_u_qt_qtwes2);
  __Pyx_GIVEREF(__pyx_n_u_qt_qtwes2);
  PyList_SET_ITEM(__pyx_t_1, 3, __pyx_n_u_qt_qtwes2);
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_u_qtwes2, __pyx_t_1) < 0) __PYX_ERR(0, 148, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "_qtexec_.pyx":159
 *     'qtwoglos':  ['_gldraw_ogl', '_glarea_oglos', '_qtui_', '_qt_qtwoglos'],
 *     'qtwes2':    ['_gldraw_es2', '_glarea_es2', '_qtui_', '_qt_qtwes2'],
 *     'qtwes2os':  ['_gldraw_es2', '_glarea_es2os', '_qtui_', '_qt_qtwes2os'],             # <<<<<<<<<<<<<<
 *     'qtqogl':    ['_gldraw_ogl', '_glarea_ogl', '_qt_qtqogl'],
 *     'qtqoglos':  ['_gldraw_ogl', '_glarea_oglos', '_qt_qtqoglos'],
 */
  __pyx_t_1 = PyList_New(4); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 159, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF(__pyx_n_u_gldraw_es2);
  __Pyx_GIVEREF(__pyx_n_u_gldraw_es2);
  PyList_SET_ITEM(__pyx_t_1, 0, __pyx_n_u_gldraw_es2);
  __Pyx_INCREF(__pyx_n_u_glarea_es2os);
  __Pyx_GIVEREF(__pyx_n_u_glarea_es2os);
  PyList_SET_ITEM(__pyx_t_1, 1, __pyx_n_u_glarea_es2os);
  __Pyx_INCREF(__pyx_n_u_qtui);
  __Pyx_GIVEREF(__pyx_n_u_qtui);
  PyList_SET_ITEM(__pyx_t_1, 2, __pyx_n_u_qtui);
  __Pyx_INCREF(__pyx_n_u_qt_qtwes2os);
  __Pyx_GIVEREF(__pyx_n_u_qt_qtwes2os);
  PyList_SET_ITEM(__pyx_t_1, 3, __pyx_n_u_qt_qtwes2os);
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_u_qtwes2os, __pyx_t_1) < 0) __PYX_ERR(0, 148, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "_qtexec_.pyx":160
 *     'qtwes2':    ['_gldraw_es2', '_glarea_es2', '_qtui_', '_qt_qtwes2'],
 *     'qtwes2os':  ['_gldraw_es2', '_glarea_es2os', '_qtui_', '_qt_qtwes2os'],
 *     'qtqogl':    ['_gldraw_ogl', '_glarea_ogl', '_qt_qtqogl'],             # <<<<<<<<<<<<<<
 *     'qtqoglos':  ['_gldraw_ogl', '_glarea_oglos', '_qt_qtqoglos'],
 *     'qtqes2':    ['_gldraw_es2', '_glarea_es2', '_qt_qtqes2'],
 */
  __pyx_t_1 = PyList_New(3); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 160, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF(__pyx_n_u_gldraw_ogl);
  __Pyx_GIVEREF(__pyx_n_u_gldraw_ogl);
  PyList_SET_ITEM(__pyx_t_1, 0, __pyx_n_u_gldraw_ogl);
  __Pyx_INCREF(__pyx_n_u_glarea_ogl);
  __Pyx_GIVEREF(__pyx_n_u_glarea_ogl);
  PyList_SET_ITEM(__pyx_t_1, 1, __pyx_n_u_glarea_ogl);
  __Pyx_INCREF(__pyx_n_u_qt_qtqogl);
  __Pyx_GIVEREF(__pyx_n_u_qt_qtqogl);
  PyList_SET_ITEM(__pyx_t_1, 2, __pyx_n_u_qt_qtqogl);
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_u_qtqogl, __pyx_t_1) < 0) __PYX_ERR(0, 148, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "_qtexec_.pyx":161
 *     'qtwes2os':  ['_gldraw_es2', '_glarea_es2os', '_qtui_', '_qt_qtwes2os'],
 *     'qtqogl':    ['_gldraw_ogl', '_glarea_ogl', '_qt_qtqogl'],
 *     'qtqoglos':  ['_gldraw_ogl', '_glarea_oglos', '_qt_qtqoglos'],             # <<<<<<<<<<<<<<
 *     'qtqes2':    ['_gldraw_es2', '_glarea_es2', '_qt_qtqes2'],
 *     'qtqes2os':  ['_gldraw_es2', '_glarea_es2os', '_qt_qtqes2os'],
 */
  __pyx_t_1 = PyList_New(3); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 161, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF(__pyx_n_u_gldraw_ogl);
  __Pyx_GIVEREF(__pyx_n_u_gldraw_ogl);
  PyList_SET_ITEM(__pyx_t_1, 0, __pyx_n_u_gldraw_ogl);
  __Pyx_INCREF(__pyx_n_u_glarea_oglos);
  __Pyx_GIVEREF(__pyx_n_u_glarea_oglos);
  PyList_SET_ITEM(__pyx_t_1, 1, __pyx_n_u_glarea_oglos);
  __Pyx_INCREF(__pyx_n_u_qt_qtqoglos);
  __Pyx_GIVEREF(__pyx_n_u_qt_qtqoglos);
  PyList_SET_ITEM(__pyx_t_1, 2, __pyx_n_u_qt_qtqoglos);
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_u_qtqoglos, __pyx_t_1) < 0) __PYX_ERR(0, 148, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "_qtexec_.pyx":162
 *     'qtqogl':    ['_gldraw_ogl', '_glarea_ogl', '_qt_qtqogl'],
 *     'qtqoglos':  ['_gldraw_ogl', '_glarea_oglos', '_qt_qtqoglos'],
 *     'qtqes2':    ['_gldraw_es2', '_glarea_es2', '_qt_qtqes2'],             # <<<<<<<<<<<<<<
 *     'qtqes2os':  ['_gldraw_es2', '_glarea_es2os', '_qt_qtqes2os'],
 *   }
 */
  __pyx_t_1 = PyList_New(3); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 162, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF(__pyx_n_u_gldraw_es2);
  __Pyx_GIVEREF(__pyx_n_u_gldraw_es2);
  PyList_SET_ITEM(__pyx_t_1, 0, __pyx_n_u_gldraw_es2);
  __Pyx_INCREF(__pyx_n_u_glarea_es2);
  __Pyx_GIVEREF(__pyx_n_u_glarea_es2);
  PyList_SET_ITEM(__pyx_t_1, 1, __pyx_n_u_glarea_es2);
  __Pyx_INCREF(__pyx_n_u_qt_qtqes2);
  __Pyx_GIVEREF(__pyx_n_u_qt_qtqes2);
  PyList_SET_ITEM(__pyx_t_1, 2, __pyx_n_u_qt_qtqes2);
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_u_qtqes2, __pyx_t_1) < 0) __PYX_ERR(0, 148, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "_qtexec_.pyx":163
 *     'qtqoglos':  ['_gldraw_ogl', '_glarea_oglos', '_qt_qtqoglos'],
 *     'qtqes2':    ['_gldraw_es2', '_glarea_es2', '_qt_qtqes2'],
 *     'qtqes2os':  ['_gldraw_es2', '_glarea_es2os', '_qt_qtqes2os'],             # <<<<<<<<<<<<<<
 *   }
 * aliases = { #px+
 */
  __pyx_t_1 = PyList_New(3); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 163, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF(__pyx_n_u_gldraw_es2);
  __Pyx_GIVEREF(__pyx_n_u_gldraw_es2);
  PyList_SET_ITEM(__pyx_t_1, 0, __pyx_n_u_gldraw_es2);
  __Pyx_INCREF(__pyx_n_u_glarea_es2os);
  __Pyx_GIVEREF(__pyx_n_u_glarea_es2os);
  PyList_SET_ITEM(__pyx_t_1, 1, __pyx_n_u_glarea_es2os);
  __Pyx_INCREF(__pyx_n_u_qt_qtqes2os);
  __Pyx_GIVEREF(__pyx_n_u_qt_qtqes2os);
  PyList_SET_ITEM(__pyx_t_1, 2, __pyx_n_u_qt_qtqes2os);
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_u_qtqes2os, __pyx_t_1) < 0) __PYX_ERR(0, 148, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_depends, __pyx_t_2) < 0) __PYX_ERR(0, 147, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "_qtexec_.pyx":166
 *   }
 * aliases = { #px+
 *     '':          'qtw???',             # <<<<<<<<<<<<<<
 *     'qtw':       'qtw???',
 *     'qtq':       'qtq???',
 */
  __pyx_t_2 = PyDict_New(); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 166, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_2, __pyx_kp_u__2, __pyx_kp_u_qtw) < 0) __PYX_ERR(0, 166, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_u_qtw_2, __pyx_kp_u_qtw) < 0) __PYX_ERR(0, 166, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_u_qtq, __pyx_kp_u_qtq_2) < 0) __PYX_ERR(0, 166, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_u_ogl, __pyx_n_u_qtwogl) < 0) __PYX_ERR(0, 166, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_u_es2, __pyx_n_u_qtwes2) < 0) __PYX_ERR(0, 166, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_u_d, __pyx_kp_u_qtw_d) < 0) __PYX_ERR(0, 166, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_u_qtwd, __pyx_kp_u_qtw_d) < 0) __PYX_ERR(0, 166, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_u_qtqd, __pyx_kp_u_qtq_d) < 0) __PYX_ERR(0, 166, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_u_ogld, __pyx_n_u_qtwogld) < 0) __PYX_ERR(0, 166, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_u_es2d, __pyx_n_u_qtwes2d) < 0) __PYX_ERR(0, 166, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_u_os, __pyx_kp_u_qtw_os) < 0) __PYX_ERR(0, 166, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_u_qtwos, __pyx_kp_u_qtw_os) < 0) __PYX_ERR(0, 166, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_u_qtqos, __pyx_kp_u_qtq_os) < 0) __PYX_ERR(0, 166, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_u_oglos, __pyx_n_u_qtwoglos) < 0) __PYX_ERR(0, 166, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_u_es2os, __pyx_n_u_qtwes2os) < 0) __PYX_ERR(0, 166, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_u_dos, __pyx_kp_u_qtw_dos) < 0) __PYX_ERR(0, 166, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_u_qtwdos, __pyx_kp_u_qtw_dos) < 0) __PYX_ERR(0, 166, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_u_qtqdos, __pyx_kp_u_qtq_dos) < 0) __PYX_ERR(0, 166, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_u_ogldos, __pyx_n_u_qtwogldos) < 0) __PYX_ERR(0, 166, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_u_es2dos, __pyx_n_u_qtwes2dos) < 0) __PYX_ERR(0, 166, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_aliases, __pyx_t_2) < 0) __PYX_ERR(0, 165, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "_qtexec_.pyx":1
 * # -*- coding: utf-8 -*-             # <<<<<<<<<<<<<<
 * # cython: profile=False
 * 
 */
  __pyx_t_2 = PyDict_New(); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_test, __pyx_t_2) < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /*--- Wrapped vars code ---*/

  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  if (__pyx_m) {
    if (__pyx_d) {
      __Pyx_AddTraceback("init _qtexec_", __pyx_clineno, __pyx_lineno, __pyx_filename);
    }
    Py_DECREF(__pyx_m); __pyx_m = 0;
  } else if (!PyErr_Occurred()) {
    PyErr_SetString(PyExc_ImportError, "init _qtexec_");
  }
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  #if PY_MAJOR_VERSION < 3
  return;
  #else
  return __pyx_m;
  #endif
}

/* --- Runtime support code --- */
/* Refnanny */
#if CYTHON_REFNANNY
static __Pyx_RefNannyAPIStruct *__Pyx_RefNannyImportAPI(const char *modname) {
    PyObject *m = NULL, *p = NULL;
    void *r = NULL;
    m = PyImport_ImportModule((char *)modname);
    if (!m) goto end;
    p = PyObject_GetAttrString(m, (char *)"RefNannyAPI");
    if (!p) goto end;
    r = PyLong_AsVoidPtr(p);
end:
    Py_XDECREF(p);
    Py_XDECREF(m);
    return (__Pyx_RefNannyAPIStruct *)r;
}
#endif

/* GetBuiltinName */
static PyObject *__Pyx_GetBuiltinName(PyObject *name) {
    PyObject* result = __Pyx_PyObject_GetAttrStr(__pyx_b, name);
    if (unlikely(!result)) {
        PyErr_Format(PyExc_NameError,
#if PY_MAJOR_VERSION >= 3
            "name '%U' is not defined", name);
#else
            "name '%.200s' is not defined", PyString_AS_STRING(name));
#endif
    }
    return result;
}

/* decode_c_string */
static CYTHON_INLINE PyObject* __Pyx_decode_c_string(
         const char* cstring, Py_ssize_t start, Py_ssize_t stop,
         const char* encoding, const char* errors,
         PyObject* (*decode_func)(const char *s, Py_ssize_t size, const char *errors)) {
    Py_ssize_t length;
    if (unlikely((start < 0) | (stop < 0))) {
        size_t slen = strlen(cstring);
        if (unlikely(slen > (size_t) PY_SSIZE_T_MAX)) {
            PyErr_SetString(PyExc_OverflowError,
                            "c-string too long to convert to Python");
            return NULL;
        }
        length = (Py_ssize_t) slen;
        if (start < 0) {
            start += length;
            if (start < 0)
                start = 0;
        }
        if (stop < 0)
            stop += length;
    }
    length = stop - start;
    if (unlikely(length <= 0))
        return PyUnicode_FromUnicode(NULL, 0);
    cstring += start;
    if (decode_func) {
        return decode_func(cstring, length, errors);
    } else {
        return PyUnicode_Decode(cstring, length, encoding, errors);
    }
}

/* PyObjectCall */
#if CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE PyObject* __Pyx_PyObject_Call(PyObject *func, PyObject *arg, PyObject *kw) {
    PyObject *result;
    ternaryfunc call = func->ob_type->tp_call;
    if (unlikely(!call))
        return PyObject_Call(func, arg, kw);
    if (unlikely(Py_EnterRecursiveCall((char*)" while calling a Python object")))
        return NULL;
    result = (*call)(func, arg, kw);
    Py_LeaveRecursiveCall();
    if (unlikely(!result) && unlikely(!PyErr_Occurred())) {
        PyErr_SetString(
            PyExc_SystemError,
            "NULL result without error in PyObject_Call");
    }
    return result;
}
#endif

/* PyErrFetchRestore */
#if CYTHON_FAST_THREAD_STATE
static CYTHON_INLINE void __Pyx_ErrRestoreInState(PyThreadState *tstate, PyObject *type, PyObject *value, PyObject *tb) {
    PyObject *tmp_type, *tmp_value, *tmp_tb;
    tmp_type = tstate->curexc_type;
    tmp_value = tstate->curexc_value;
    tmp_tb = tstate->curexc_traceback;
    tstate->curexc_type = type;
    tstate->curexc_value = value;
    tstate->curexc_traceback = tb;
    Py_XDECREF(tmp_type);
    Py_XDECREF(tmp_value);
    Py_XDECREF(tmp_tb);
}
static CYTHON_INLINE void __Pyx_ErrFetchInState(PyThreadState *tstate, PyObject **type, PyObject **value, PyObject **tb) {
    *type = tstate->curexc_type;
    *value = tstate->curexc_value;
    *tb = tstate->curexc_traceback;
    tstate->curexc_type = 0;
    tstate->curexc_value = 0;
    tstate->curexc_traceback = 0;
}
#endif

/* WriteUnraisableException */
static void __Pyx_WriteUnraisable(const char *name, CYTHON_UNUSED int clineno,
                                  CYTHON_UNUSED int lineno, CYTHON_UNUSED const char *filename,
                                  int full_traceback, CYTHON_UNUSED int nogil) {
    PyObject *old_exc, *old_val, *old_tb;
    PyObject *ctx;
    __Pyx_PyThreadState_declare
#ifdef WITH_THREAD
    PyGILState_STATE state;
    if (nogil)
        state = PyGILState_Ensure();
#ifdef _MSC_VER
    else state = (PyGILState_STATE)-1;
#endif
#endif
    __Pyx_PyThreadState_assign
    __Pyx_ErrFetch(&old_exc, &old_val, &old_tb);
    if (full_traceback) {
        Py_XINCREF(old_exc);
        Py_XINCREF(old_val);
        Py_XINCREF(old_tb);
        __Pyx_ErrRestore(old_exc, old_val, old_tb);
        PyErr_PrintEx(1);
    }
    #if PY_MAJOR_VERSION < 3
    ctx = PyString_FromString(name);
    #else
    ctx = PyUnicode_FromString(name);
    #endif
    __Pyx_ErrRestore(old_exc, old_val, old_tb);
    if (!ctx) {
        PyErr_WriteUnraisable(Py_None);
    } else {
        PyErr_WriteUnraisable(ctx);
        Py_DECREF(ctx);
    }
#ifdef WITH_THREAD
    if (nogil)
        PyGILState_Release(state);
#endif
}

/* GetModuleGlobalName */
static CYTHON_INLINE PyObject *__Pyx_GetModuleGlobalName(PyObject *name) {
    PyObject *result;
#if !CYTHON_AVOID_BORROWED_REFS
    result = PyDict_GetItem(__pyx_d, name);
    if (likely(result)) {
        Py_INCREF(result);
    } else {
#else
    result = PyObject_GetItem(__pyx_d, name);
    if (!result) {
        PyErr_Clear();
#endif
        result = __Pyx_GetBuiltinName(name);
    }
    return result;
}

/* PyCFunctionFastCall */
  #if CYTHON_FAST_PYCCALL
static CYTHON_INLINE PyObject * __Pyx_PyCFunction_FastCall(PyObject *func_obj, PyObject **args, Py_ssize_t nargs) {
    PyCFunctionObject *func = (PyCFunctionObject*)func_obj;
    PyCFunction meth = PyCFunction_GET_FUNCTION(func);
    PyObject *self = PyCFunction_GET_SELF(func);
    assert(PyCFunction_Check(func));
    assert(METH_FASTCALL == (PyCFunction_GET_FLAGS(func) & ~(METH_CLASS | METH_STATIC | METH_COEXIST)));
    assert(nargs >= 0);
    assert(nargs == 0 || args != NULL);
    /* _PyCFunction_FastCallDict() must not be called with an exception set,
       because it may clear it (directly or indirectly) and so the
       caller loses its exception */
    assert(!PyErr_Occurred());
    return (*((__Pyx_PyCFunctionFast)meth)) (self, args, nargs, NULL);
}
#endif  // CYTHON_FAST_PYCCALL

/* PyFunctionFastCall */
  #if CYTHON_FAST_PYCALL
#include "frameobject.h"
static PyObject* __Pyx_PyFunction_FastCallNoKw(PyCodeObject *co, PyObject **args, Py_ssize_t na,
                                               PyObject *globals) {
    PyFrameObject *f;
    PyThreadState *tstate = PyThreadState_GET();
    PyObject **fastlocals;
    Py_ssize_t i;
    PyObject *result;
    assert(globals != NULL);
    /* XXX Perhaps we should create a specialized
       PyFrame_New() that doesn't take locals, but does
       take builtins without sanity checking them.
       */
    assert(tstate != NULL);
    f = PyFrame_New(tstate, co, globals, NULL);
    if (f == NULL) {
        return NULL;
    }
    fastlocals = f->f_localsplus;
    for (i = 0; i < na; i++) {
        Py_INCREF(*args);
        fastlocals[i] = *args++;
    }
    result = PyEval_EvalFrameEx(f,0);
    ++tstate->recursion_depth;
    Py_DECREF(f);
    --tstate->recursion_depth;
    return result;
}
#if 1 || PY_VERSION_HEX < 0x030600B1
static PyObject *__Pyx_PyFunction_FastCallDict(PyObject *func, PyObject **args, int nargs, PyObject *kwargs) {
    PyCodeObject *co = (PyCodeObject *)PyFunction_GET_CODE(func);
    PyObject *globals = PyFunction_GET_GLOBALS(func);
    PyObject *argdefs = PyFunction_GET_DEFAULTS(func);
    PyObject *closure;
#if PY_MAJOR_VERSION >= 3
    PyObject *kwdefs;
#endif
    PyObject *kwtuple, **k;
    PyObject **d;
    Py_ssize_t nd;
    Py_ssize_t nk;
    PyObject *result;
    assert(kwargs == NULL || PyDict_Check(kwargs));
    nk = kwargs ? PyDict_Size(kwargs) : 0;
    if (Py_EnterRecursiveCall((char*)" while calling a Python object")) {
        return NULL;
    }
    if (
#if PY_MAJOR_VERSION >= 3
            co->co_kwonlyargcount == 0 &&
#endif
            likely(kwargs == NULL || nk == 0) &&
            co->co_flags == (CO_OPTIMIZED | CO_NEWLOCALS | CO_NOFREE)) {
        if (argdefs == NULL && co->co_argcount == nargs) {
            result = __Pyx_PyFunction_FastCallNoKw(co, args, nargs, globals);
            goto done;
        }
        else if (nargs == 0 && argdefs != NULL
                 && co->co_argcount == Py_SIZE(argdefs)) {
            /* function called with no arguments, but all parameters have
               a default value: use default values as arguments .*/
            args = &PyTuple_GET_ITEM(argdefs, 0);
            result =__Pyx_PyFunction_FastCallNoKw(co, args, Py_SIZE(argdefs), globals);
            goto done;
        }
    }
    if (kwargs != NULL) {
        Py_ssize_t pos, i;
        kwtuple = PyTuple_New(2 * nk);
        if (kwtuple == NULL) {
            result = NULL;
            goto done;
        }
        k = &PyTuple_GET_ITEM(kwtuple, 0);
        pos = i = 0;
        while (PyDict_Next(kwargs, &pos, &k[i], &k[i+1])) {
            Py_INCREF(k[i]);
            Py_INCREF(k[i+1]);
            i += 2;
        }
        nk = i / 2;
    }
    else {
        kwtuple = NULL;
        k = NULL;
    }
    closure = PyFunction_GET_CLOSURE(func);
#if PY_MAJOR_VERSION >= 3
    kwdefs = PyFunction_GET_KW_DEFAULTS(func);
#endif
    if (argdefs != NULL) {
        d = &PyTuple_GET_ITEM(argdefs, 0);
        nd = Py_SIZE(argdefs);
    }
    else {
        d = NULL;
        nd = 0;
    }
#if PY_MAJOR_VERSION >= 3
    result = PyEval_EvalCodeEx((PyObject*)co, globals, (PyObject *)NULL,
                               args, nargs,
                               k, (int)nk,
                               d, (int)nd, kwdefs, closure);
#else
    result = PyEval_EvalCodeEx(co, globals, (PyObject *)NULL,
                               args, nargs,
                               k, (int)nk,
                               d, (int)nd, closure);
#endif
    Py_XDECREF(kwtuple);
done:
    Py_LeaveRecursiveCall();
    return result;
}
#endif  // CPython < 3.6
#endif  // CYTHON_FAST_PYCALL

/* PyObjectCallMethO */
  #if CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE PyObject* __Pyx_PyObject_CallMethO(PyObject *func, PyObject *arg) {
    PyObject *self, *result;
    PyCFunction cfunc;
    cfunc = PyCFunction_GET_FUNCTION(func);
    self = PyCFunction_GET_SELF(func);
    if (unlikely(Py_EnterRecursiveCall((char*)" while calling a Python object")))
        return NULL;
    result = cfunc(self, arg);
    Py_LeaveRecursiveCall();
    if (unlikely(!result) && unlikely(!PyErr_Occurred())) {
        PyErr_SetString(
            PyExc_SystemError,
            "NULL result without error in PyObject_Call");
    }
    return result;
}
#endif

/* PyObjectCallOneArg */
  #if CYTHON_COMPILING_IN_CPYTHON
static PyObject* __Pyx__PyObject_CallOneArg(PyObject *func, PyObject *arg) {
    PyObject *result;
    PyObject *args = PyTuple_New(1);
    if (unlikely(!args)) return NULL;
    Py_INCREF(arg);
    PyTuple_SET_ITEM(args, 0, arg);
    result = __Pyx_PyObject_Call(func, args, NULL);
    Py_DECREF(args);
    return result;
}
static CYTHON_INLINE PyObject* __Pyx_PyObject_CallOneArg(PyObject *func, PyObject *arg) {
#if CYTHON_FAST_PYCALL
    if (PyFunction_Check(func)) {
        return __Pyx_PyFunction_FastCall(func, &arg, 1);
    }
#endif
#ifdef __Pyx_CyFunction_USED
    if (likely(PyCFunction_Check(func) || PyObject_TypeCheck(func, __pyx_CyFunctionType))) {
#else
    if (likely(PyCFunction_Check(func))) {
#endif
        if (likely(PyCFunction_GET_FLAGS(func) & METH_O)) {
            return __Pyx_PyObject_CallMethO(func, arg);
#if CYTHON_FAST_PYCCALL
        } else if (PyCFunction_GET_FLAGS(func) & METH_FASTCALL) {
            return __Pyx_PyCFunction_FastCall(func, &arg, 1);
#endif
        }
    }
    return __Pyx__PyObject_CallOneArg(func, arg);
}
#else
static CYTHON_INLINE PyObject* __Pyx_PyObject_CallOneArg(PyObject *func, PyObject *arg) {
    PyObject *result;
    PyObject *args = PyTuple_Pack(1, arg);
    if (unlikely(!args)) return NULL;
    result = __Pyx_PyObject_Call(func, args, NULL);
    Py_DECREF(args);
    return result;
}
#endif

/* PyObjectCallNoArg */
    #if CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE PyObject* __Pyx_PyObject_CallNoArg(PyObject *func) {
#if CYTHON_FAST_PYCALL
    if (PyFunction_Check(func)) {
        return __Pyx_PyFunction_FastCall(func, NULL, 0);
    }
#endif
#ifdef __Pyx_CyFunction_USED
    if (likely(PyCFunction_Check(func) || PyObject_TypeCheck(func, __pyx_CyFunctionType))) {
#else
    if (likely(PyCFunction_Check(func))) {
#endif
        if (likely(PyCFunction_GET_FLAGS(func) & METH_NOARGS)) {
            return __Pyx_PyObject_CallMethO(func, NULL);
        }
    }
    return __Pyx_PyObject_Call(func, __pyx_empty_tuple, NULL);
}
#endif

/* SaveResetException */
      #if CYTHON_FAST_THREAD_STATE
static CYTHON_INLINE void __Pyx__ExceptionSave(PyThreadState *tstate, PyObject **type, PyObject **value, PyObject **tb) {
    *type = tstate->exc_type;
    *value = tstate->exc_value;
    *tb = tstate->exc_traceback;
    Py_XINCREF(*type);
    Py_XINCREF(*value);
    Py_XINCREF(*tb);
}
static CYTHON_INLINE void __Pyx__ExceptionReset(PyThreadState *tstate, PyObject *type, PyObject *value, PyObject *tb) {
    PyObject *tmp_type, *tmp_value, *tmp_tb;
    tmp_type = tstate->exc_type;
    tmp_value = tstate->exc_value;
    tmp_tb = tstate->exc_traceback;
    tstate->exc_type = type;
    tstate->exc_value = value;
    tstate->exc_traceback = tb;
    Py_XDECREF(tmp_type);
    Py_XDECREF(tmp_value);
    Py_XDECREF(tmp_tb);
}
#endif

/* PyErrExceptionMatches */
      #if CYTHON_FAST_THREAD_STATE
static CYTHON_INLINE int __Pyx_PyErr_ExceptionMatchesInState(PyThreadState* tstate, PyObject* err) {
    PyObject *exc_type = tstate->curexc_type;
    if (exc_type == err) return 1;
    if (unlikely(!exc_type)) return 0;
    return PyErr_GivenExceptionMatches(exc_type, err);
}
#endif

/* GetException */
      #if CYTHON_FAST_THREAD_STATE
static int __Pyx__GetException(PyThreadState *tstate, PyObject **type, PyObject **value, PyObject **tb) {
#else
static int __Pyx_GetException(PyObject **type, PyObject **value, PyObject **tb) {
#endif
    PyObject *local_type, *local_value, *local_tb;
#if CYTHON_FAST_THREAD_STATE
    PyObject *tmp_type, *tmp_value, *tmp_tb;
    local_type = tstate->curexc_type;
    local_value = tstate->curexc_value;
    local_tb = tstate->curexc_traceback;
    tstate->curexc_type = 0;
    tstate->curexc_value = 0;
    tstate->curexc_traceback = 0;
#else
    PyErr_Fetch(&local_type, &local_value, &local_tb);
#endif
    PyErr_NormalizeException(&local_type, &local_value, &local_tb);
#if CYTHON_FAST_THREAD_STATE
    if (unlikely(tstate->curexc_type))
#else
    if (unlikely(PyErr_Occurred()))
#endif
        goto bad;
    #if PY_MAJOR_VERSION >= 3
    if (local_tb) {
        if (unlikely(PyException_SetTraceback(local_value, local_tb) < 0))
            goto bad;
    }
    #endif
    Py_XINCREF(local_tb);
    Py_XINCREF(local_type);
    Py_XINCREF(local_value);
    *type = local_type;
    *value = local_value;
    *tb = local_tb;
#if CYTHON_FAST_THREAD_STATE
    tmp_type = tstate->exc_type;
    tmp_value = tstate->exc_value;
    tmp_tb = tstate->exc_traceback;
    tstate->exc_type = local_type;
    tstate->exc_value = local_value;
    tstate->exc_traceback = local_tb;
    Py_XDECREF(tmp_type);
    Py_XDECREF(tmp_value);
    Py_XDECREF(tmp_tb);
#else
    PyErr_SetExcInfo(local_type, local_value, local_tb);
#endif
    return 0;
bad:
    *type = 0;
    *value = 0;
    *tb = 0;
    Py_XDECREF(local_type);
    Py_XDECREF(local_value);
    Py_XDECREF(local_tb);
    return -1;
}

/* StringJoin */
        #if !CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE PyObject* __Pyx_PyBytes_Join(PyObject* sep, PyObject* values) {
    return PyObject_CallMethodObjArgs(sep, __pyx_n_s_join, values, NULL);
}
#endif

/* Import */
        static PyObject *__Pyx_Import(PyObject *name, PyObject *from_list, int level) {
    PyObject *empty_list = 0;
    PyObject *module = 0;
    PyObject *global_dict = 0;
    PyObject *empty_dict = 0;
    PyObject *list;
    #if PY_VERSION_HEX < 0x03030000
    PyObject *py_import;
    py_import = __Pyx_PyObject_GetAttrStr(__pyx_b, __pyx_n_s_import);
    if (!py_import)
        goto bad;
    #endif
    if (from_list)
        list = from_list;
    else {
        empty_list = PyList_New(0);
        if (!empty_list)
            goto bad;
        list = empty_list;
    }
    global_dict = PyModule_GetDict(__pyx_m);
    if (!global_dict)
        goto bad;
    empty_dict = PyDict_New();
    if (!empty_dict)
        goto bad;
    {
        #if PY_MAJOR_VERSION >= 3
        if (level == -1) {
            if (strchr(__Pyx_MODULE_NAME, '.')) {
                #if PY_VERSION_HEX < 0x03030000
                PyObject *py_level = PyInt_FromLong(1);
                if (!py_level)
                    goto bad;
                module = PyObject_CallFunctionObjArgs(py_import,
                    name, global_dict, empty_dict, list, py_level, NULL);
                Py_DECREF(py_level);
                #else
                module = PyImport_ImportModuleLevelObject(
                    name, global_dict, empty_dict, list, 1);
                #endif
                if (!module) {
                    if (!PyErr_ExceptionMatches(PyExc_ImportError))
                        goto bad;
                    PyErr_Clear();
                }
            }
            level = 0;
        }
        #endif
        if (!module) {
            #if PY_VERSION_HEX < 0x03030000
            PyObject *py_level = PyInt_FromLong(level);
            if (!py_level)
                goto bad;
            module = PyObject_CallFunctionObjArgs(py_import,
                name, global_dict, empty_dict, list, py_level, NULL);
            Py_DECREF(py_level);
            #else
            module = PyImport_ImportModuleLevelObject(
                name, global_dict, empty_dict, list, level);
            #endif
        }
    }
bad:
    #if PY_VERSION_HEX < 0x03030000
    Py_XDECREF(py_import);
    #endif
    Py_XDECREF(empty_list);
    Py_XDECREF(empty_dict);
    return module;
}

/* ImportFrom */
        static PyObject* __Pyx_ImportFrom(PyObject* module, PyObject* name) {
    PyObject* value = __Pyx_PyObject_GetAttrStr(module, name);
    if (unlikely(!value) && PyErr_ExceptionMatches(PyExc_AttributeError)) {
        PyErr_Format(PyExc_ImportError,
        #if PY_MAJOR_VERSION < 3
            "cannot import name %.230s", PyString_AS_STRING(name));
        #else
            "cannot import name %S", name);
        #endif
    }
    return value;
}

/* CodeObjectCache */
        static int __pyx_bisect_code_objects(__Pyx_CodeObjectCacheEntry* entries, int count, int code_line) {
    int start = 0, mid = 0, end = count - 1;
    if (end >= 0 && code_line > entries[end].code_line) {
        return count;
    }
    while (start < end) {
        mid = start + (end - start) / 2;
        if (code_line < entries[mid].code_line) {
            end = mid;
        } else if (code_line > entries[mid].code_line) {
             start = mid + 1;
        } else {
            return mid;
        }
    }
    if (code_line <= entries[mid].code_line) {
        return mid;
    } else {
        return mid + 1;
    }
}
static PyCodeObject *__pyx_find_code_object(int code_line) {
    PyCodeObject* code_object;
    int pos;
    if (unlikely(!code_line) || unlikely(!__pyx_code_cache.entries)) {
        return NULL;
    }
    pos = __pyx_bisect_code_objects(__pyx_code_cache.entries, __pyx_code_cache.count, code_line);
    if (unlikely(pos >= __pyx_code_cache.count) || unlikely(__pyx_code_cache.entries[pos].code_line != code_line)) {
        return NULL;
    }
    code_object = __pyx_code_cache.entries[pos].code_object;
    Py_INCREF(code_object);
    return code_object;
}
static void __pyx_insert_code_object(int code_line, PyCodeObject* code_object) {
    int pos, i;
    __Pyx_CodeObjectCacheEntry* entries = __pyx_code_cache.entries;
    if (unlikely(!code_line)) {
        return;
    }
    if (unlikely(!entries)) {
        entries = (__Pyx_CodeObjectCacheEntry*)PyMem_Malloc(64*sizeof(__Pyx_CodeObjectCacheEntry));
        if (likely(entries)) {
            __pyx_code_cache.entries = entries;
            __pyx_code_cache.max_count = 64;
            __pyx_code_cache.count = 1;
            entries[0].code_line = code_line;
            entries[0].code_object = code_object;
            Py_INCREF(code_object);
        }
        return;
    }
    pos = __pyx_bisect_code_objects(__pyx_code_cache.entries, __pyx_code_cache.count, code_line);
    if ((pos < __pyx_code_cache.count) && unlikely(__pyx_code_cache.entries[pos].code_line == code_line)) {
        PyCodeObject* tmp = entries[pos].code_object;
        entries[pos].code_object = code_object;
        Py_DECREF(tmp);
        return;
    }
    if (__pyx_code_cache.count == __pyx_code_cache.max_count) {
        int new_max = __pyx_code_cache.max_count + 64;
        entries = (__Pyx_CodeObjectCacheEntry*)PyMem_Realloc(
            __pyx_code_cache.entries, (size_t)new_max*sizeof(__Pyx_CodeObjectCacheEntry));
        if (unlikely(!entries)) {
            return;
        }
        __pyx_code_cache.entries = entries;
        __pyx_code_cache.max_count = new_max;
    }
    for (i=__pyx_code_cache.count; i>pos; i--) {
        entries[i] = entries[i-1];
    }
    entries[pos].code_line = code_line;
    entries[pos].code_object = code_object;
    __pyx_code_cache.count++;
    Py_INCREF(code_object);
}

/* AddTraceback */
        #include "compile.h"
#include "frameobject.h"
#include "traceback.h"
static PyCodeObject* __Pyx_CreateCodeObjectForTraceback(
            const char *funcname, int c_line,
            int py_line, const char *filename) {
    PyCodeObject *py_code = 0;
    PyObject *py_srcfile = 0;
    PyObject *py_funcname = 0;
    #if PY_MAJOR_VERSION < 3
    py_srcfile = PyString_FromString(filename);
    #else
    py_srcfile = PyUnicode_FromString(filename);
    #endif
    if (!py_srcfile) goto bad;
    if (c_line) {
        #if PY_MAJOR_VERSION < 3
        py_funcname = PyString_FromFormat( "%s (%s:%d)", funcname, __pyx_cfilenm, c_line);
        #else
        py_funcname = PyUnicode_FromFormat( "%s (%s:%d)", funcname, __pyx_cfilenm, c_line);
        #endif
    }
    else {
        #if PY_MAJOR_VERSION < 3
        py_funcname = PyString_FromString(funcname);
        #else
        py_funcname = PyUnicode_FromString(funcname);
        #endif
    }
    if (!py_funcname) goto bad;
    py_code = __Pyx_PyCode_New(
        0,
        0,
        0,
        0,
        0,
        __pyx_empty_bytes, /*PyObject *code,*/
        __pyx_empty_tuple, /*PyObject *consts,*/
        __pyx_empty_tuple, /*PyObject *names,*/
        __pyx_empty_tuple, /*PyObject *varnames,*/
        __pyx_empty_tuple, /*PyObject *freevars,*/
        __pyx_empty_tuple, /*PyObject *cellvars,*/
        py_srcfile,   /*PyObject *filename,*/
        py_funcname,  /*PyObject *name,*/
        py_line,
        __pyx_empty_bytes  /*PyObject *lnotab*/
    );
    Py_DECREF(py_srcfile);
    Py_DECREF(py_funcname);
    return py_code;
bad:
    Py_XDECREF(py_srcfile);
    Py_XDECREF(py_funcname);
    return NULL;
}
static void __Pyx_AddTraceback(const char *funcname, int c_line,
                               int py_line, const char *filename) {
    PyCodeObject *py_code = 0;
    PyFrameObject *py_frame = 0;
    py_code = __pyx_find_code_object(c_line ? c_line : py_line);
    if (!py_code) {
        py_code = __Pyx_CreateCodeObjectForTraceback(
            funcname, c_line, py_line, filename);
        if (!py_code) goto bad;
        __pyx_insert_code_object(c_line ? c_line : py_line, py_code);
    }
    py_frame = PyFrame_New(
        PyThreadState_GET(), /*PyThreadState *tstate,*/
        py_code,             /*PyCodeObject *code,*/
        __pyx_d,      /*PyObject *globals,*/
        0                    /*PyObject *locals*/
    );
    if (!py_frame) goto bad;
    __Pyx_PyFrame_SetLineNumber(py_frame, py_line);
    PyTraceBack_Here(py_frame);
bad:
    Py_XDECREF(py_code);
    Py_XDECREF(py_frame);
}

/* CIntToPy */
        static CYTHON_INLINE PyObject* __Pyx_PyInt_From_int(int value) {
    const int neg_one = (int) -1, const_zero = (int) 0;
    const int is_unsigned = neg_one > const_zero;
    if (is_unsigned) {
        if (sizeof(int) < sizeof(long)) {
            return PyInt_FromLong((long) value);
        } else if (sizeof(int) <= sizeof(unsigned long)) {
            return PyLong_FromUnsignedLong((unsigned long) value);
#ifdef HAVE_LONG_LONG
        } else if (sizeof(int) <= sizeof(unsigned PY_LONG_LONG)) {
            return PyLong_FromUnsignedLongLong((unsigned PY_LONG_LONG) value);
#endif
        }
    } else {
        if (sizeof(int) <= sizeof(long)) {
            return PyInt_FromLong((long) value);
#ifdef HAVE_LONG_LONG
        } else if (sizeof(int) <= sizeof(PY_LONG_LONG)) {
            return PyLong_FromLongLong((PY_LONG_LONG) value);
#endif
        }
    }
    {
        int one = 1; int little = (int)*(unsigned char *)&one;
        unsigned char *bytes = (unsigned char *)&value;
        return _PyLong_FromByteArray(bytes, sizeof(int),
                                     little, !is_unsigned);
    }
}

/* CIntFromPyVerify */
        #define __PYX_VERIFY_RETURN_INT(target_type, func_type, func_value)\
    __PYX__VERIFY_RETURN_INT(target_type, func_type, func_value, 0)
#define __PYX_VERIFY_RETURN_INT_EXC(target_type, func_type, func_value)\
    __PYX__VERIFY_RETURN_INT(target_type, func_type, func_value, 1)
#define __PYX__VERIFY_RETURN_INT(target_type, func_type, func_value, exc)\
    {\
        func_type value = func_value;\
        if (sizeof(target_type) < sizeof(func_type)) {\
            if (unlikely(value != (func_type) (target_type) value)) {\
                func_type zero = 0;\
                if (exc && unlikely(value == (func_type)-1 && PyErr_Occurred()))\
                    return (target_type) -1;\
                if (is_unsigned && unlikely(value < zero))\
                    goto raise_neg_overflow;\
                else\
                    goto raise_overflow;\
            }\
        }\
        return (target_type) value;\
    }

/* CIntFromPy */
        static CYTHON_INLINE long __Pyx_PyInt_As_long(PyObject *x) {
    const long neg_one = (long) -1, const_zero = (long) 0;
    const int is_unsigned = neg_one > const_zero;
#if PY_MAJOR_VERSION < 3
    if (likely(PyInt_Check(x))) {
        if (sizeof(long) < sizeof(long)) {
            __PYX_VERIFY_RETURN_INT(long, long, PyInt_AS_LONG(x))
        } else {
            long val = PyInt_AS_LONG(x);
            if (is_unsigned && unlikely(val < 0)) {
                goto raise_neg_overflow;
            }
            return (long) val;
        }
    } else
#endif
    if (likely(PyLong_Check(x))) {
        if (is_unsigned) {
#if CYTHON_USE_PYLONG_INTERNALS
            const digit* digits = ((PyLongObject*)x)->ob_digit;
            switch (Py_SIZE(x)) {
                case  0: return (long) 0;
                case  1: __PYX_VERIFY_RETURN_INT(long, digit, digits[0])
                case 2:
                    if (8 * sizeof(long) > 1 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 2 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(long, unsigned long, (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(long) >= 2 * PyLong_SHIFT) {
                            return (long) (((((long)digits[1]) << PyLong_SHIFT) | (long)digits[0]));
                        }
                    }
                    break;
                case 3:
                    if (8 * sizeof(long) > 2 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 3 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(long, unsigned long, (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(long) >= 3 * PyLong_SHIFT) {
                            return (long) (((((((long)digits[2]) << PyLong_SHIFT) | (long)digits[1]) << PyLong_SHIFT) | (long)digits[0]));
                        }
                    }
                    break;
                case 4:
                    if (8 * sizeof(long) > 3 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 4 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(long, unsigned long, (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(long) >= 4 * PyLong_SHIFT) {
                            return (long) (((((((((long)digits[3]) << PyLong_SHIFT) | (long)digits[2]) << PyLong_SHIFT) | (long)digits[1]) << PyLong_SHIFT) | (long)digits[0]));
                        }
                    }
                    break;
            }
#endif
#if CYTHON_COMPILING_IN_CPYTHON
            if (unlikely(Py_SIZE(x) < 0)) {
                goto raise_neg_overflow;
            }
#else
            {
                int result = PyObject_RichCompareBool(x, Py_False, Py_LT);
                if (unlikely(result < 0))
                    return (long) -1;
                if (unlikely(result == 1))
                    goto raise_neg_overflow;
            }
#endif
            if (sizeof(long) <= sizeof(unsigned long)) {
                __PYX_VERIFY_RETURN_INT_EXC(long, unsigned long, PyLong_AsUnsignedLong(x))
#ifdef HAVE_LONG_LONG
            } else if (sizeof(long) <= sizeof(unsigned PY_LONG_LONG)) {
                __PYX_VERIFY_RETURN_INT_EXC(long, unsigned PY_LONG_LONG, PyLong_AsUnsignedLongLong(x))
#endif
            }
        } else {
#if CYTHON_USE_PYLONG_INTERNALS
            const digit* digits = ((PyLongObject*)x)->ob_digit;
            switch (Py_SIZE(x)) {
                case  0: return (long) 0;
                case -1: __PYX_VERIFY_RETURN_INT(long, sdigit, (sdigit) (-(sdigit)digits[0]))
                case  1: __PYX_VERIFY_RETURN_INT(long,  digit, +digits[0])
                case -2:
                    if (8 * sizeof(long) - 1 > 1 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 2 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(long, long, -(long) (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(long) - 1 > 2 * PyLong_SHIFT) {
                            return (long) (((long)-1)*(((((long)digits[1]) << PyLong_SHIFT) | (long)digits[0])));
                        }
                    }
                    break;
                case 2:
                    if (8 * sizeof(long) > 1 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 2 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(long, unsigned long, (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(long) - 1 > 2 * PyLong_SHIFT) {
                            return (long) ((((((long)digits[1]) << PyLong_SHIFT) | (long)digits[0])));
                        }
                    }
                    break;
                case -3:
                    if (8 * sizeof(long) - 1 > 2 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 3 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(long, long, -(long) (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(long) - 1 > 3 * PyLong_SHIFT) {
                            return (long) (((long)-1)*(((((((long)digits[2]) << PyLong_SHIFT) | (long)digits[1]) << PyLong_SHIFT) | (long)digits[0])));
                        }
                    }
                    break;
                case 3:
                    if (8 * sizeof(long) > 2 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 3 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(long, unsigned long, (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(long) - 1 > 3 * PyLong_SHIFT) {
                            return (long) ((((((((long)digits[2]) << PyLong_SHIFT) | (long)digits[1]) << PyLong_SHIFT) | (long)digits[0])));
                        }
                    }
                    break;
                case -4:
                    if (8 * sizeof(long) - 1 > 3 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 4 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(long, long, -(long) (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(long) - 1 > 4 * PyLong_SHIFT) {
                            return (long) (((long)-1)*(((((((((long)digits[3]) << PyLong_SHIFT) | (long)digits[2]) << PyLong_SHIFT) | (long)digits[1]) << PyLong_SHIFT) | (long)digits[0])));
                        }
                    }
                    break;
                case 4:
                    if (8 * sizeof(long) > 3 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 4 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(long, unsigned long, (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(long) - 1 > 4 * PyLong_SHIFT) {
                            return (long) ((((((((((long)digits[3]) << PyLong_SHIFT) | (long)digits[2]) << PyLong_SHIFT) | (long)digits[1]) << PyLong_SHIFT) | (long)digits[0])));
                        }
                    }
                    break;
            }
#endif
            if (sizeof(long) <= sizeof(long)) {
                __PYX_VERIFY_RETURN_INT_EXC(long, long, PyLong_AsLong(x))
#ifdef HAVE_LONG_LONG
            } else if (sizeof(long) <= sizeof(PY_LONG_LONG)) {
                __PYX_VERIFY_RETURN_INT_EXC(long, PY_LONG_LONG, PyLong_AsLongLong(x))
#endif
            }
        }
        {
#if CYTHON_COMPILING_IN_PYPY && !defined(_PyLong_AsByteArray)
            PyErr_SetString(PyExc_RuntimeError,
                            "_PyLong_AsByteArray() not available in PyPy, cannot convert large numbers");
#else
            long val;
            PyObject *v = __Pyx_PyNumber_IntOrLong(x);
 #if PY_MAJOR_VERSION < 3
            if (likely(v) && !PyLong_Check(v)) {
                PyObject *tmp = v;
                v = PyNumber_Long(tmp);
                Py_DECREF(tmp);
            }
 #endif
            if (likely(v)) {
                int one = 1; int is_little = (int)*(unsigned char *)&one;
                unsigned char *bytes = (unsigned char *)&val;
                int ret = _PyLong_AsByteArray((PyLongObject *)v,
                                              bytes, sizeof(val),
                                              is_little, !is_unsigned);
                Py_DECREF(v);
                if (likely(!ret))
                    return val;
            }
#endif
            return (long) -1;
        }
    } else {
        long val;
        PyObject *tmp = __Pyx_PyNumber_IntOrLong(x);
        if (!tmp) return (long) -1;
        val = __Pyx_PyInt_As_long(tmp);
        Py_DECREF(tmp);
        return val;
    }
raise_overflow:
    PyErr_SetString(PyExc_OverflowError,
        "value too large to convert to long");
    return (long) -1;
raise_neg_overflow:
    PyErr_SetString(PyExc_OverflowError,
        "can't convert negative value to long");
    return (long) -1;
}

/* CIntToPy */
        static CYTHON_INLINE PyObject* __Pyx_PyInt_From_long(long value) {
    const long neg_one = (long) -1, const_zero = (long) 0;
    const int is_unsigned = neg_one > const_zero;
    if (is_unsigned) {
        if (sizeof(long) < sizeof(long)) {
            return PyInt_FromLong((long) value);
        } else if (sizeof(long) <= sizeof(unsigned long)) {
            return PyLong_FromUnsignedLong((unsigned long) value);
#ifdef HAVE_LONG_LONG
        } else if (sizeof(long) <= sizeof(unsigned PY_LONG_LONG)) {
            return PyLong_FromUnsignedLongLong((unsigned PY_LONG_LONG) value);
#endif
        }
    } else {
        if (sizeof(long) <= sizeof(long)) {
            return PyInt_FromLong((long) value);
#ifdef HAVE_LONG_LONG
        } else if (sizeof(long) <= sizeof(PY_LONG_LONG)) {
            return PyLong_FromLongLong((PY_LONG_LONG) value);
#endif
        }
    }
    {
        int one = 1; int little = (int)*(unsigned char *)&one;
        unsigned char *bytes = (unsigned char *)&value;
        return _PyLong_FromByteArray(bytes, sizeof(long),
                                     little, !is_unsigned);
    }
}

/* CIntFromPy */
        static CYTHON_INLINE int __Pyx_PyInt_As_int(PyObject *x) {
    const int neg_one = (int) -1, const_zero = (int) 0;
    const int is_unsigned = neg_one > const_zero;
#if PY_MAJOR_VERSION < 3
    if (likely(PyInt_Check(x))) {
        if (sizeof(int) < sizeof(long)) {
            __PYX_VERIFY_RETURN_INT(int, long, PyInt_AS_LONG(x))
        } else {
            long val = PyInt_AS_LONG(x);
            if (is_unsigned && unlikely(val < 0)) {
                goto raise_neg_overflow;
            }
            return (int) val;
        }
    } else
#endif
    if (likely(PyLong_Check(x))) {
        if (is_unsigned) {
#if CYTHON_USE_PYLONG_INTERNALS
            const digit* digits = ((PyLongObject*)x)->ob_digit;
            switch (Py_SIZE(x)) {
                case  0: return (int) 0;
                case  1: __PYX_VERIFY_RETURN_INT(int, digit, digits[0])
                case 2:
                    if (8 * sizeof(int) > 1 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 2 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(int, unsigned long, (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(int) >= 2 * PyLong_SHIFT) {
                            return (int) (((((int)digits[1]) << PyLong_SHIFT) | (int)digits[0]));
                        }
                    }
                    break;
                case 3:
                    if (8 * sizeof(int) > 2 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 3 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(int, unsigned long, (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(int) >= 3 * PyLong_SHIFT) {
                            return (int) (((((((int)digits[2]) << PyLong_SHIFT) | (int)digits[1]) << PyLong_SHIFT) | (int)digits[0]));
                        }
                    }
                    break;
                case 4:
                    if (8 * sizeof(int) > 3 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 4 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(int, unsigned long, (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(int) >= 4 * PyLong_SHIFT) {
                            return (int) (((((((((int)digits[3]) << PyLong_SHIFT) | (int)digits[2]) << PyLong_SHIFT) | (int)digits[1]) << PyLong_SHIFT) | (int)digits[0]));
                        }
                    }
                    break;
            }
#endif
#if CYTHON_COMPILING_IN_CPYTHON
            if (unlikely(Py_SIZE(x) < 0)) {
                goto raise_neg_overflow;
            }
#else
            {
                int result = PyObject_RichCompareBool(x, Py_False, Py_LT);
                if (unlikely(result < 0))
                    return (int) -1;
                if (unlikely(result == 1))
                    goto raise_neg_overflow;
            }
#endif
            if (sizeof(int) <= sizeof(unsigned long)) {
                __PYX_VERIFY_RETURN_INT_EXC(int, unsigned long, PyLong_AsUnsignedLong(x))
#ifdef HAVE_LONG_LONG
            } else if (sizeof(int) <= sizeof(unsigned PY_LONG_LONG)) {
                __PYX_VERIFY_RETURN_INT_EXC(int, unsigned PY_LONG_LONG, PyLong_AsUnsignedLongLong(x))
#endif
            }
        } else {
#if CYTHON_USE_PYLONG_INTERNALS
            const digit* digits = ((PyLongObject*)x)->ob_digit;
            switch (Py_SIZE(x)) {
                case  0: return (int) 0;
                case -1: __PYX_VERIFY_RETURN_INT(int, sdigit, (sdigit) (-(sdigit)digits[0]))
                case  1: __PYX_VERIFY_RETURN_INT(int,  digit, +digits[0])
                case -2:
                    if (8 * sizeof(int) - 1 > 1 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 2 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(int, long, -(long) (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(int) - 1 > 2 * PyLong_SHIFT) {
                            return (int) (((int)-1)*(((((int)digits[1]) << PyLong_SHIFT) | (int)digits[0])));
                        }
                    }
                    break;
                case 2:
                    if (8 * sizeof(int) > 1 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 2 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(int, unsigned long, (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(int) - 1 > 2 * PyLong_SHIFT) {
                            return (int) ((((((int)digits[1]) << PyLong_SHIFT) | (int)digits[0])));
                        }
                    }
                    break;
                case -3:
                    if (8 * sizeof(int) - 1 > 2 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 3 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(int, long, -(long) (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(int) - 1 > 3 * PyLong_SHIFT) {
                            return (int) (((int)-1)*(((((((int)digits[2]) << PyLong_SHIFT) | (int)digits[1]) << PyLong_SHIFT) | (int)digits[0])));
                        }
                    }
                    break;
                case 3:
                    if (8 * sizeof(int) > 2 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 3 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(int, unsigned long, (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(int) - 1 > 3 * PyLong_SHIFT) {
                            return (int) ((((((((int)digits[2]) << PyLong_SHIFT) | (int)digits[1]) << PyLong_SHIFT) | (int)digits[0])));
                        }
                    }
                    break;
                case -4:
                    if (8 * sizeof(int) - 1 > 3 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 4 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(int, long, -(long) (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(int) - 1 > 4 * PyLong_SHIFT) {
                            return (int) (((int)-1)*(((((((((int)digits[3]) << PyLong_SHIFT) | (int)digits[2]) << PyLong_SHIFT) | (int)digits[1]) << PyLong_SHIFT) | (int)digits[0])));
                        }
                    }
                    break;
                case 4:
                    if (8 * sizeof(int) > 3 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 4 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(int, unsigned long, (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(int) - 1 > 4 * PyLong_SHIFT) {
                            return (int) ((((((((((int)digits[3]) << PyLong_SHIFT) | (int)digits[2]) << PyLong_SHIFT) | (int)digits[1]) << PyLong_SHIFT) | (int)digits[0])));
                        }
                    }
                    break;
            }
#endif
            if (sizeof(int) <= sizeof(long)) {
                __PYX_VERIFY_RETURN_INT_EXC(int, long, PyLong_AsLong(x))
#ifdef HAVE_LONG_LONG
            } else if (sizeof(int) <= sizeof(PY_LONG_LONG)) {
                __PYX_VERIFY_RETURN_INT_EXC(int, PY_LONG_LONG, PyLong_AsLongLong(x))
#endif
            }
        }
        {
#if CYTHON_COMPILING_IN_PYPY && !defined(_PyLong_AsByteArray)
            PyErr_SetString(PyExc_RuntimeError,
                            "_PyLong_AsByteArray() not available in PyPy, cannot convert large numbers");
#else
            int val;
            PyObject *v = __Pyx_PyNumber_IntOrLong(x);
 #if PY_MAJOR_VERSION < 3
            if (likely(v) && !PyLong_Check(v)) {
                PyObject *tmp = v;
                v = PyNumber_Long(tmp);
                Py_DECREF(tmp);
            }
 #endif
            if (likely(v)) {
                int one = 1; int is_little = (int)*(unsigned char *)&one;
                unsigned char *bytes = (unsigned char *)&val;
                int ret = _PyLong_AsByteArray((PyLongObject *)v,
                                              bytes, sizeof(val),
                                              is_little, !is_unsigned);
                Py_DECREF(v);
                if (likely(!ret))
                    return val;
            }
#endif
            return (int) -1;
        }
    } else {
        int val;
        PyObject *tmp = __Pyx_PyNumber_IntOrLong(x);
        if (!tmp) return (int) -1;
        val = __Pyx_PyInt_As_int(tmp);
        Py_DECREF(tmp);
        return val;
    }
raise_overflow:
    PyErr_SetString(PyExc_OverflowError,
        "value too large to convert to int");
    return (int) -1;
raise_neg_overflow:
    PyErr_SetString(PyExc_OverflowError,
        "can't convert negative value to int");
    return (int) -1;
}

/* CheckBinaryVersion */
        static int __Pyx_check_binary_version(void) {
    char ctversion[4], rtversion[4];
    PyOS_snprintf(ctversion, 4, "%d.%d", PY_MAJOR_VERSION, PY_MINOR_VERSION);
    PyOS_snprintf(rtversion, 4, "%s", Py_GetVersion());
    if (ctversion[0] != rtversion[0] || ctversion[2] != rtversion[2]) {
        char message[200];
        PyOS_snprintf(message, sizeof(message),
                      "compiletime version %s of module '%.100s' "
                      "does not match runtime version %s",
                      ctversion, __Pyx_MODULE_NAME, rtversion);
        return PyErr_WarnEx(NULL, message, 1);
    }
    return 0;
}

/* InitStrings */
        static int __Pyx_InitStrings(__Pyx_StringTabEntry *t) {
    while (t->p) {
        #if PY_MAJOR_VERSION < 3
        if (t->is_unicode) {
            *t->p = PyUnicode_DecodeUTF8(t->s, t->n - 1, NULL);
        } else if (t->intern) {
            *t->p = PyString_InternFromString(t->s);
        } else {
            *t->p = PyString_FromStringAndSize(t->s, t->n - 1);
        }
        #else
        if (t->is_unicode | t->is_str) {
            if (t->intern) {
                *t->p = PyUnicode_InternFromString(t->s);
            } else if (t->encoding) {
                *t->p = PyUnicode_Decode(t->s, t->n - 1, t->encoding, NULL);
            } else {
                *t->p = PyUnicode_FromStringAndSize(t->s, t->n - 1);
            }
        } else {
            *t->p = PyBytes_FromStringAndSize(t->s, t->n - 1);
        }
        #endif
        if (!*t->p)
            return -1;
        ++t;
    }
    return 0;
}

static CYTHON_INLINE PyObject* __Pyx_PyUnicode_FromString(const char* c_str) {
    return __Pyx_PyUnicode_FromStringAndSize(c_str, (Py_ssize_t)strlen(c_str));
}
static CYTHON_INLINE char* __Pyx_PyObject_AsString(PyObject* o) {
    Py_ssize_t ignore;
    return __Pyx_PyObject_AsStringAndSize(o, &ignore);
}
static CYTHON_INLINE char* __Pyx_PyObject_AsStringAndSize(PyObject* o, Py_ssize_t *length) {
#if CYTHON_COMPILING_IN_CPYTHON && (__PYX_DEFAULT_STRING_ENCODING_IS_ASCII || __PYX_DEFAULT_STRING_ENCODING_IS_DEFAULT)
    if (
#if PY_MAJOR_VERSION < 3 && __PYX_DEFAULT_STRING_ENCODING_IS_ASCII
            __Pyx_sys_getdefaultencoding_not_ascii &&
#endif
            PyUnicode_Check(o)) {
#if PY_VERSION_HEX < 0x03030000
        char* defenc_c;
        PyObject* defenc = _PyUnicode_AsDefaultEncodedString(o, NULL);
        if (!defenc) return NULL;
        defenc_c = PyBytes_AS_STRING(defenc);
#if __PYX_DEFAULT_STRING_ENCODING_IS_ASCII
        {
            char* end = defenc_c + PyBytes_GET_SIZE(defenc);
            char* c;
            for (c = defenc_c; c < end; c++) {
                if ((unsigned char) (*c) >= 128) {
                    PyUnicode_AsASCIIString(o);
                    return NULL;
                }
            }
        }
#endif
        *length = PyBytes_GET_SIZE(defenc);
        return defenc_c;
#else
        if (__Pyx_PyUnicode_READY(o) == -1) return NULL;
#if __PYX_DEFAULT_STRING_ENCODING_IS_ASCII
        if (PyUnicode_IS_ASCII(o)) {
            *length = PyUnicode_GET_LENGTH(o);
            return PyUnicode_AsUTF8(o);
        } else {
            PyUnicode_AsASCIIString(o);
            return NULL;
        }
#else
        return PyUnicode_AsUTF8AndSize(o, length);
#endif
#endif
    } else
#endif
#if (!CYTHON_COMPILING_IN_PYPY) || (defined(PyByteArray_AS_STRING) && defined(PyByteArray_GET_SIZE))
    if (PyByteArray_Check(o)) {
        *length = PyByteArray_GET_SIZE(o);
        return PyByteArray_AS_STRING(o);
    } else
#endif
    {
        char* result;
        int r = PyBytes_AsStringAndSize(o, &result, length);
        if (unlikely(r < 0)) {
            return NULL;
        } else {
            return result;
        }
    }
}
static CYTHON_INLINE int __Pyx_PyObject_IsTrue(PyObject* x) {
   int is_true = x == Py_True;
   if (is_true | (x == Py_False) | (x == Py_None)) return is_true;
   else return PyObject_IsTrue(x);
}
static CYTHON_INLINE PyObject* __Pyx_PyNumber_IntOrLong(PyObject* x) {
#if CYTHON_USE_TYPE_SLOTS
  PyNumberMethods *m;
#endif
  const char *name = NULL;
  PyObject *res = NULL;
#if PY_MAJOR_VERSION < 3
  if (PyInt_Check(x) || PyLong_Check(x))
#else
  if (PyLong_Check(x))
#endif
    return __Pyx_NewRef(x);
#if CYTHON_USE_TYPE_SLOTS
  m = Py_TYPE(x)->tp_as_number;
  #if PY_MAJOR_VERSION < 3
  if (m && m->nb_int) {
    name = "int";
    res = PyNumber_Int(x);
  }
  else if (m && m->nb_long) {
    name = "long";
    res = PyNumber_Long(x);
  }
  #else
  if (m && m->nb_int) {
    name = "int";
    res = PyNumber_Long(x);
  }
  #endif
#else
  res = PyNumber_Int(x);
#endif
  if (res) {
#if PY_MAJOR_VERSION < 3
    if (!PyInt_Check(res) && !PyLong_Check(res)) {
#else
    if (!PyLong_Check(res)) {
#endif
      PyErr_Format(PyExc_TypeError,
                   "__%.4s__ returned non-%.4s (type %.200s)",
                   name, name, Py_TYPE(res)->tp_name);
      Py_DECREF(res);
      return NULL;
    }
  }
  else if (!PyErr_Occurred()) {
    PyErr_SetString(PyExc_TypeError,
                    "an integer is required");
  }
  return res;
}
static CYTHON_INLINE Py_ssize_t __Pyx_PyIndex_AsSsize_t(PyObject* b) {
  Py_ssize_t ival;
  PyObject *x;
#if PY_MAJOR_VERSION < 3
  if (likely(PyInt_CheckExact(b))) {
    if (sizeof(Py_ssize_t) >= sizeof(long))
        return PyInt_AS_LONG(b);
    else
        return PyInt_AsSsize_t(x);
  }
#endif
  if (likely(PyLong_CheckExact(b))) {
    #if CYTHON_USE_PYLONG_INTERNALS
    const digit* digits = ((PyLongObject*)b)->ob_digit;
    const Py_ssize_t size = Py_SIZE(b);
    if (likely(__Pyx_sst_abs(size) <= 1)) {
        ival = likely(size) ? digits[0] : 0;
        if (size == -1) ival = -ival;
        return ival;
    } else {
      switch (size) {
         case 2:
           if (8 * sizeof(Py_ssize_t) > 2 * PyLong_SHIFT) {
             return (Py_ssize_t) (((((size_t)digits[1]) << PyLong_SHIFT) | (size_t)digits[0]));
           }
           break;
         case -2:
           if (8 * sizeof(Py_ssize_t) > 2 * PyLong_SHIFT) {
             return -(Py_ssize_t) (((((size_t)digits[1]) << PyLong_SHIFT) | (size_t)digits[0]));
           }
           break;
         case 3:
           if (8 * sizeof(Py_ssize_t) > 3 * PyLong_SHIFT) {
             return (Py_ssize_t) (((((((size_t)digits[2]) << PyLong_SHIFT) | (size_t)digits[1]) << PyLong_SHIFT) | (size_t)digits[0]));
           }
           break;
         case -3:
           if (8 * sizeof(Py_ssize_t) > 3 * PyLong_SHIFT) {
             return -(Py_ssize_t) (((((((size_t)digits[2]) << PyLong_SHIFT) | (size_t)digits[1]) << PyLong_SHIFT) | (size_t)digits[0]));
           }
           break;
         case 4:
           if (8 * sizeof(Py_ssize_t) > 4 * PyLong_SHIFT) {
             return (Py_ssize_t) (((((((((size_t)digits[3]) << PyLong_SHIFT) | (size_t)digits[2]) << PyLong_SHIFT) | (size_t)digits[1]) << PyLong_SHIFT) | (size_t)digits[0]));
           }
           break;
         case -4:
           if (8 * sizeof(Py_ssize_t) > 4 * PyLong_SHIFT) {
             return -(Py_ssize_t) (((((((((size_t)digits[3]) << PyLong_SHIFT) | (size_t)digits[2]) << PyLong_SHIFT) | (size_t)digits[1]) << PyLong_SHIFT) | (size_t)digits[0]));
           }
           break;
      }
    }
    #endif
    return PyLong_AsSsize_t(b);
  }
  x = PyNumber_Index(b);
  if (!x) return -1;
  ival = PyInt_AsSsize_t(x);
  Py_DECREF(x);
  return ival;
}
static CYTHON_INLINE PyObject * __Pyx_PyInt_FromSize_t(size_t ival) {
    return PyInt_FromSize_t(ival);
}


#endif /* Py_PYTHON_H */
